%%
%% This is file `sfonts.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% slifonts.fdd  (with options: `main')
%% 
%% This is a generated file.
%% 
%% Copyright 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2003/12/01 or later.
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% Details of how to use a configuration file to modify this part of
%% the system are in the document `cfgguide.tex'.
%% 
%% 
\ProvidesFile{sfonts.def}
        [1998/06/12 v2.2e Standard LaTeX slide font definitions]
\DeclareErrorFont{OT1}{lcmss}{m}{n}{19.907}
\DeclareFontSubstitution{OT1}{lcmss}{m}{n}
\input ot1lcmss.fd
\endinput
%%
%% End of file `sfonts.def'.
