%%
%% This is file `isolatin.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% umlaute.dtx  (with options: `isolatin')
%% 
%% Copyright (C) 1994-95 Harald Axel Sommerfeldt
%% 
\ProvidesFile{isolatin.def}[1995/02/03 %
  Input encoding file (Harald_Sommerfeldt@w.maus.de)]
\chardef\atcode=\catcode`\@
\catcode`\@=11
\providecommand*{\@as@active}[1]{%
  \ifx\protect\relax\else\ifx\protect\empty\else%
  \expandafter\expandafter\expandafter\protect\fi\fi%
  \as@active{#1}}
\providecommand*{\as@active}[1]{\csname @as@@#1\endcsname}
\def\@as@@aa{\aa}\def\@as@@AA{\AA}
\def\@as@@ae{\ae}\def\@as@@AE{\AE}
\def\@as@@ic{\^{\i}}\def\@as@@IC{\^I}
\def\@as@@id{\'{\i}}\def\@as@@ID{\'I}
\def\@as@@ig{\`{\i}}\def\@as@@IG{\`I}
\def\@as@@iq{\"{\i}}\def\@as@@IQ{\"I}
\def\@as@@o{\o}\def\@as@@O{\O}
\def\@as@@ss{\ss}\def\@as@@SS{\SS}
\def\@as@@oe{\oe}\def\@as@@OE{\OE}
\def\@as@@dh{\dh}\def\@as@@DH{\DH}
\def\@as@@th{\th}\def\@as@@TH{\TH}
\ProvideTextCommandDefault{\textonequarter}{$\frac14$}
\ProvideTextCommandDefault{\textonehalf}{$\frac12$}
\ProvideTextCommandDefault{\textthreequarters}{$\frac34$}
\ProvideTextCommandDefault{\texttrademark}{$^\mathrm{TM}$}
\def\as@msa#1{{\fontencoding{U}\fontfamily{msa}\selectfont\char#1}}
\ProvideTextCommandDefault{\textblacksquare}{\as@msa{4}}
\ProvideTextCommandDefault{\textyen}{\as@msa{85}}
\ProvideTextCommandDefault{\textulcorner}{\as@msa{112}}
\ProvideTextCommandDefault{\texturcorner}{\as@msa{113}}
\ProvideTextCommandDefault{\textregistered}{\as@msa{114}}
\ProvideTextCommandDefault{\textllcorner}{\as@msa{120}}
\ProvideTextCommandDefault{\textlrcorner}{\as@msa{121}}
\def\as@wasy#1{{\fontencoding{U}\fontfamily{wasy}\selectfont\char#1}}
\ProvideTextCommandDefault{\textcurrency}{\as@wasy{27}}
\ProvideTextCommandDefault{\textcent}{\as@wasy{103}}
\ProvideTextCommandDefault{\textpermil}{\as@wasy{104}}
\ProvideTextCommandDefault{\textbrokenbar}{\as@wasy{124}}
\providecommand*{\mathbullet}{{{}^\bullet}}
\providecommand*{\mathdegree}{{{}^\circ}}
\providecommand*{\mathordmasculine}{{{}^a}}
\providecommand*{\mathordfeminine}{{{}^o}}
\providecommand*{\mathonesuperior}{{{}^1}}
\providecommand*{\mathtwosuperior}{{{}^2}}
\providecommand*{\maththreesuperior}{{{}^3}}
\providecommand*{\DeclareInputTextEx}[4]{%
  \DeclareInputText{#1}{#2}%
  \lccode#1=#3\uccode#1=#4}
\providecommand*{\DeclareInputMathEx}[2]{%
  \DeclareInputMath{#1}{#2}%
  \lccode#1=#1\uccode#1=#1}
\DeclareInputTextEx{"80}{\@as@active{SS}}{"0DF}{"80}
\DeclareInputTextEx{"81}{\"Y}{"0FF}{"81}
\DeclareInputTextEx{"0A0}{~}{"0A0}{"0A0}
\DeclareInputTextEx{"0A1}{\textexclamdown}{"0A1}{"0A1}
\DeclareInputTextEx{"0A2}{\textcent}{"0A2}{"0A2}
\DeclareInputTextEx{"0A3}{\textsterling}{"0A3}{"0A3}
\DeclareInputTextEx{"0A4}{\textcurrency}{"0A4}{"0A4}
\DeclareInputTextEx{"0A5}{\textyen}{"0A5}{"0A5}
\DeclareInputTextEx{"0A6}{\textbrokenbar}{"0A6}{"0A6}
\DeclareInputTextEx{"0A7}{\S}{"0A7}{"0A7}
\DeclareInputTextEx{"0A8}{\"{}}{"0A8}{"0A8}
\DeclareInputTextEx{"0A9}{\copyright}{"0A9}{"0A9}
\DeclareInputMathEx{"0AA}{\mathordmasculine}
\DeclareInputTextEx{"0AB}{\guillemotleft}{"0AB}{"0AB}
\DeclareInputMathEx{"0AC}{\neg}
\DeclareInputTextEx{"0AD}{\textendash}{"0AD}{"0AD}
\DeclareInputTextEx{"0AE}{\textregistered}{"0AE}{"0AE}
\DeclareInputTextEx{"0AF}{\={}}{"0AF}{"0AF}
\DeclareInputMathEx{"0B0}{\mathdegree}
\DeclareInputMathEx{"0B1}{\pm}
\DeclareInputMathEx{"0B2}{\mathtwosuperior}
\DeclareInputMathEx{"0B3}{\maththreesuperior}
\DeclareInputTextEx{"0B4}{\'{}}{"0B4}{"0B4}
\DeclareInputMathEx{"0B5}{\mu}
\DeclareInputTextEx{"0B6}{\P}{"0B6}{"0B6}
\DeclareInputMathEx{"0B7}{\cdot}
\DeclareInputTextEx{"0B8}{\c{}}{"0B8}{"0B8}
\DeclareInputMathEx{"0B9}{\mathonesuperior}
\DeclareInputMathEx{"0BA}{\mathordfeminine}
\DeclareInputTextEx{"0BB}{\guillemotright}{"0BB}{"0BB}
\DeclareInputTextEx{"0BC}{\textonequarter}{"0BC}{"0BC}
\DeclareInputTextEx{"0BD}{\textonehalf}{"0BD}{"0BD}
\DeclareInputTextEx{"0BE}{\textthreequarters}{"0BE}{"0BE}
\DeclareInputTextEx{"0BF}{\textquestiondown}{"0BF}{"0BF}
\DeclareInputTextEx{"0C0}{\`A}{"0E0}{"0C0}
\DeclareInputTextEx{"0C1}{\'A}{"0E1}{"0C1}
\DeclareInputTextEx{"0C2}{\^A}{"0E2}{"0C2}
\DeclareInputTextEx{"0C3}{\~A}{"0E3}{"0C3}
\DeclareInputTextEx{"0C4}{\"A}{"0E4}{"0C4}
\DeclareInputTextEx{"0C5}{\@as@active{AA}}{"0E5}{"0C5}
\DeclareInputTextEx{"0C6}{\@as@active{AE}}{"0E6}{"0C6}
\DeclareInputTextEx{"0C7}{\c C}{"0E7}{"0C7}
\DeclareInputTextEx{"0C8}{\`E}{"0E8}{"0C8}
\DeclareInputTextEx{"0C9}{\'E}{"0E9}{"0C9}
\DeclareInputTextEx{"0CA}{\^E}{"0EA}{"0CA}
\DeclareInputTextEx{"0CB}{\"E}{"0EB}{"0CB}
\DeclareInputTextEx{"0CC}{\@as@active{IG}}{"0EC}{"0CC}
\DeclareInputTextEx{"0CD}{\@as@active{ID}}{"0ED}{"0CD}
\DeclareInputTextEx{"0CE}{\@as@active{IC}}{"0EE}{"0CE}
\DeclareInputTextEx{"0CF}{\@as@active{IQ}}{"0EF}{"0CF}
\DeclareInputTextEx{"0D0}{\@as@active{DH}}{"0F0}{"0D0}
\DeclareInputTextEx{"0D1}{\~N}{"0F1}{"0D1}
\DeclareInputTextEx{"0D2}{\`O}{"0F2}{"0D2}
\DeclareInputTextEx{"0D3}{\'O}{"0F3}{"0D3}
\DeclareInputTextEx{"0D4}{\^O}{"0F4}{"0D4}
\DeclareInputTextEx{"0D5}{\~O}{"0F5}{"0D5}
\DeclareInputTextEx{"0D6}{\"O}{"0F6}{"0D6}
\DeclareInputMathEx{"0D7}{\times}
\DeclareInputTextEx{"0D8}{\@as@active{O}}{"0F8}{"0D8}
\DeclareInputTextEx{"0D9}{\`U}{"0F9}{"0D9}
\DeclareInputTextEx{"0DA}{\'U}{"0FA}{"0DA}
\DeclareInputTextEx{"0DB}{\^U}{"0FB}{"0DB}
\DeclareInputTextEx{"0DC}{\"U}{"0FC}{"0DC}
\DeclareInputTextEx{"0DD}{\'Y}{"0FD}{"0DD}
\DeclareInputTextEx{"0DE}{\@as@active{TH}}{"0FE}{"0DE}
\DeclareInputTextEx{"0DF}{\@as@active{ss}}{"0DF}{"80}
\DeclareInputTextEx{"0E0}{\`a}{"0E0}{"0C0}
\DeclareInputTextEx{"0E1}{\'a}{"0E1}{"0C1}
\DeclareInputTextEx{"0E2}{\^a}{"0E2}{"0C2}
\DeclareInputTextEx{"0E3}{\~a}{"0E3}{"0C3}
\DeclareInputTextEx{"0E4}{\"a}{"0E4}{"0C4}
\DeclareInputTextEx{"0E5}{\@as@active{aa}}{"0E5}{"0C5}
\DeclareInputTextEx{"0E6}{\@as@active{ae}}{"0E6}{"0C6}
\DeclareInputTextEx{"0E7}{\c c}{"0E7}{"0C7}
\DeclareInputTextEx{"0E8}{\`e}{"0E8}{"0C8}
\DeclareInputTextEx{"0E9}{\'e}{"0E9}{"0C9}
\DeclareInputTextEx{"0EA}{\^e}{"0EA}{"0CA}
\DeclareInputTextEx{"0EB}{\"e}{"0EB}{"0CB}
\DeclareInputTextEx{"0EC}{\@as@active{ig}}{"0EC}{"0CC}
\DeclareInputTextEx{"0ED}{\@as@active{id}}{"0ED}{"0CD}
\DeclareInputTextEx{"0EE}{\@as@active{ic}}{"0EE}{"0CE}
\DeclareInputTextEx{"0EF}{\@as@active{iq}}{"0EF}{"0CF}
\DeclareInputTextEx{"0F0}{\@as@active{dh}}{"0F0}{"0D0}
\DeclareInputTextEx{"0F1}{\~n}{"0F1}{"0D1}
\DeclareInputTextEx{"0F2}{\`o}{"0F2}{"0D2}
\DeclareInputTextEx{"0F3}{\'o}{"0F3}{"0D3}
\DeclareInputTextEx{"0F4}{\^o}{"0F4}{"0D4}
\DeclareInputTextEx{"0F5}{\~o}{"0F5}{"0D5}
\DeclareInputTextEx{"0F6}{\"o}{"0F6}{"0D6}
\DeclareInputMathEx{"0F7}{\div}
\DeclareInputTextEx{"0F8}{\@as@active{o}}{"0F8}{"0D8}
\DeclareInputTextEx{"0F9}{\`u}{"0F9}{"0D9}
\DeclareInputTextEx{"0FA}{\'u}{"0FA}{"0DA}
\DeclareInputTextEx{"0FB}{\^u}{"0FB}{"0DB}
\DeclareInputTextEx{"0FC}{\"u}{"0FC}{"0DC}
\DeclareInputTextEx{"0FD}{\'y}{"0FD}{"0DD}
\DeclareInputTextEx{"0FE}{\@as@active{th}}{"0FE}{"0DE}
\DeclareInputTextEx{"0FF}{\"y}{"0FF}{"81}
\catcode`\@=\atcode
\endinput
%%
%% End of file `isolatin.def'.
