%%
%% This is file `pctexhp.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% drivers.dtx  (with options: `pctexhp,nops')
%% 
%% drivers.dtx Copyright (C) 1994      David Carlisle Sebastian Rahtz
%%             Copyright (C) 1995 1996 1997 1998 1999 David Carlisle
%%
%% This file is part of the Standard LaTeX `Graphics Bundle'.
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%%
\ProvidesFile{pctexhp.def}
        [1999/02/16 v3.0i Driver-dependant file (DPC,SPQR)]
\def\Ginclude@pcl#1{%
\message{<#1>}%
   \ifGin@clip
     \typeout{no clipping support in pctexhp}%
   \fi
   \hbox{\kern-\Gin@llx bp\raise-\Gin@lly bp\hbox{\special{pcl:#1}}}%
   \typeout{WARNING: pctexhp does not permit graphics to be scaled}}
\@namedef{Gin@rule@.pcl}#1{{pcl}{}{#1}}
\def\Gin@extensions{.pcl}
\def\Gin@PS@raw#1{}
\def\Gin@PS@restored#1{}
\def\Gin@PS@literal@header#1{}
\def\Gin@PS@file@header#1{}
\endinput
%%
%% End of file `pctexhp.def'.
