%%
%% This is file `roman8.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% umlaute.dtx  (with options: `roman8')
%% 
%% Copyright (C) 1994-95 Harald Axel Sommerfeldt
%% 
\ProvidesFile{roman8.def}[1995/02/05 %
  Input encoding file (Harald_Sommerfeldt@w.maus.de)]
\chardef\atcode=\catcode`\@
\catcode`\@=11
\providecommand*{\@as@active}[1]{%
  \ifx\protect\relax\else\ifx\protect\empty\else%
  \expandafter\expandafter\expandafter\protect\fi\fi%
  \as@active{#1}}
\providecommand*{\as@active}[1]{\csname @as@@#1\endcsname}
\def\@as@@aa{\aa}\def\@as@@AA{\AA}
\def\@as@@ae{\ae}\def\@as@@AE{\AE}
\def\@as@@ic{\^{\i}}\def\@as@@IC{\^I}
\def\@as@@id{\'{\i}}\def\@as@@ID{\'I}
\def\@as@@ig{\`{\i}}\def\@as@@IG{\`I}
\def\@as@@iq{\"{\i}}\def\@as@@IQ{\"I}
\def\@as@@o{\o}\def\@as@@O{\O}
\def\@as@@ss{\ss}\def\@as@@SS{\SS}
\def\@as@@oe{\oe}\def\@as@@OE{\OE}
\def\@as@@dh{\dh}\def\@as@@DH{\DH}
\def\@as@@th{\th}\def\@as@@TH{\TH}
\ProvideTextCommandDefault{\textonequarter}{$\frac14$}
\ProvideTextCommandDefault{\textonehalf}{$\frac12$}
\ProvideTextCommandDefault{\textthreequarters}{$\frac34$}
\ProvideTextCommandDefault{\texttrademark}{$^\mathrm{TM}$}
\def\as@msa#1{{\fontencoding{U}\fontfamily{msa}\selectfont\char#1}}
\ProvideTextCommandDefault{\textblacksquare}{\as@msa{4}}
\ProvideTextCommandDefault{\textyen}{\as@msa{85}}
\ProvideTextCommandDefault{\textulcorner}{\as@msa{112}}
\ProvideTextCommandDefault{\texturcorner}{\as@msa{113}}
\ProvideTextCommandDefault{\textregistered}{\as@msa{114}}
\ProvideTextCommandDefault{\textllcorner}{\as@msa{120}}
\ProvideTextCommandDefault{\textlrcorner}{\as@msa{121}}
\def\as@wasy#1{{\fontencoding{U}\fontfamily{wasy}\selectfont\char#1}}
\ProvideTextCommandDefault{\textcurrency}{\as@wasy{27}}
\ProvideTextCommandDefault{\textcent}{\as@wasy{103}}
\ProvideTextCommandDefault{\textpermil}{\as@wasy{104}}
\ProvideTextCommandDefault{\textbrokenbar}{\as@wasy{124}}
\providecommand*{\mathbullet}{{{}^\bullet}}
\providecommand*{\mathdegree}{{{}^\circ}}
\providecommand*{\mathordmasculine}{{{}^a}}
\providecommand*{\mathordfeminine}{{{}^o}}
\providecommand*{\mathonesuperior}{{{}^1}}
\providecommand*{\mathtwosuperior}{{{}^2}}
\providecommand*{\maththreesuperior}{{{}^3}}
\providecommand*{\DeclareInputTextEx}[4]{%
  \DeclareInputText{#1}{#2}%
  \lccode#1=#3\uccode#1=#4}
\providecommand*{\DeclareInputMathEx}[2]{%
  \DeclareInputMath{#1}{#2}%
  \lccode#1=#1\uccode#1=#1}
\DeclareInputTextEx{"0A0}{~}{"0A0}{"0A0}
\DeclareInputTextEx{"0A1}{\`A}{"0C8}{"0A1}
\DeclareInputTextEx{"0A2}{\^A}{"0C0}{"0A2}
\DeclareInputTextEx{"0A3}{\`E}{"0C9}{"0A3}
\DeclareInputTextEx{"0A4}{\^E}{"0C1}{"0A4}
\DeclareInputTextEx{"0A5}{\"E}{"0CD}{"0A5}
\DeclareInputTextEx{"0A6}{\@as@active{IC}}{"0D1}{"0A6}
\DeclareInputTextEx{"0A7}{\@as@active{IQ}}{"0DD}{"0A7}
\DeclareInputTextEx{"0A8}{\'{}}{"0A8}{"0A8}
\DeclareInputTextEx{"0A9}{\`{}}{"0A9}{"0A9}
\DeclareInputTextEx{"0AA}{\^{}}{"0AA}{"0AA}
\DeclareInputTextEx{"0AB}{\"{}}{"0AB}{"0AB}
\DeclareInputTextEx{"0AC}{\~{}}{"0AC}{"0AC}
\DeclareInputTextEx{"0AD}{\`U}{"0CB}{"0AD}
\DeclareInputTextEx{"0AE}{\^U}{"0C3}{"0AE}
\DeclareInputTextEx{"0AF}{\textsterling}{"0AF}{"0AF} % eigentlich: Lira
\DeclareInputTextEx{"0B0}{\={}}{"0B0}{"0B0}
\DeclareInputTextEx{"0B1}{\'Y}{"0B2}{"0B1}
\DeclareInputTextEx{"0B2}{\'y}{"0B2}{"0B1}
\DeclareInputMathEx{"0B3}{\mathdegree}
\DeclareInputTextEx{"0B4}{\c C}{"0B5}{"0B4}
\DeclareInputTextEx{"0B5}{\c c}{"0B5}{"0B4}
\DeclareInputTextEx{"0B6}{\~N}{"0B7}{"0B6}
\DeclareInputTextEx{"0B7}{\~n}{"0B7}{"0B6}
\DeclareInputTextEx{"0B8}{\textexclamdown}{"0B8}{"0B8}
\DeclareInputTextEx{"0B9}{\textquestiondown}{"0B9}{"0B9}
\DeclareInputTextEx{"0BA}{\textcurrency}{"0BA}{"0BA}
\DeclareInputTextEx{"0BB}{\textsterling}{"0BB}{"0BB}
\DeclareInputTextEx{"0BC}{\textyen}{"0BC}{"0BC}
\DeclareInputTextEx{"0BD}{\S}{"0BD}{"0BD}
\DeclareInputTextEx{"0BE}{\NotImplemented}{"0BE}{"0BE} % holl. Gulden
\DeclareInputTextEx{"0BF}{\textcent}{"0BF}{"0BF}
\DeclareInputTextEx{"0C0}{\^a}{"0C0}{"0A2}
\DeclareInputTextEx{"0C1}{\^e}{"0C1}{"0A4}
\DeclareInputTextEx{"0C2}{\^o}{"0C2}{"0DF}
\DeclareInputTextEx{"0C3}{\^u}{"0C3}{"0AE}
\DeclareInputTextEx{"0C4}{\'a}{"0C4}{"0E0}
\DeclareInputTextEx{"0C5}{\'e}{"0C5}{"0DC}
\DeclareInputTextEx{"0C6}{\'o}{"0C6}{"0E7}
\DeclareInputTextEx{"0C7}{\'u}{"0C7}{"0ED}
\DeclareInputTextEx{"0C8}{\`a}{"0C8}{"0A1}
\DeclareInputTextEx{"0C9}{\`e}{"0C9}{"0A3}
\DeclareInputTextEx{"0CA}{\`o}{"0CA}{"0E8}
\DeclareInputTextEx{"0CB}{\`u}{"0CB}{"0AD}
\DeclareInputTextEx{"0CC}{\"a}{"0CC}{"0D8}
\DeclareInputTextEx{"0CD}{\"e}{"0CD}{"0A5}
\DeclareInputTextEx{"0CE}{\"o}{"0CE}{"0DA}
\DeclareInputTextEx{"0CF}{\"u}{"0CF}{"0DB}
\DeclareInputTextEx{"0D0}{\@as@active{AA}}{"0D4}{"0D0}
\DeclareInputTextEx{"0D1}{\@as@active{ic}}{"0D1}{"0A6}
\DeclareInputTextEx{"0D2}{\@as@active{O}}{"0D6}{"0D2}
\DeclareInputTextEx{"0D3}{\@as@active{AE}}{"0D7}{"0D3}
\DeclareInputTextEx{"0D4}{\@as@active{aa}}{"0D4}{"0D0}
\DeclareInputTextEx{"0D5}{\@as@active{id}}{"0D5}{"0E5}
\DeclareInputTextEx{"0D6}{\@as@active{o}}{"0D6}{"0D2}
\DeclareInputTextEx{"0D7}{\@as@active{ae}}{"0D7}{"0D3}
\DeclareInputTextEx{"0D8}{\"A}{"0CC}{"0D8}
\DeclareInputTextEx{"0D9}{\@as@active{ig}}{"0D9}{"0E6}
\DeclareInputTextEx{"0DA}{\"O}{"0CE}{"0DA}
\DeclareInputTextEx{"0DB}{\"U}{"0CF}{"0DB}
\DeclareInputTextEx{"0DC}{\'E}{"0C5}{"0DC}
\DeclareInputTextEx{"0DD}{\@as@active{iq}}{"0DD}{"0A7}
\DeclareInputTextEx{"0DE}{\@as@active{ss}}{"0DE}{"0FF}
\DeclareInputTextEx{"0DF}{\^O}{"0C2}{"0DF}
\DeclareInputTextEx{"0E0}{\'A}{"0C4}{"0E0}
\DeclareInputTextEx{"0E1}{\~A}{"0E2}{"0E1}
\DeclareInputTextEx{"0E2}{\~a}{"0E2}{"0E1}
\DeclareInputTextEx{"0E3}{\@as@active{DH}}{"0E4}{"0E3}
\DeclareInputTextEx{"0E4}{\@as@active{dh}}{"0E4}{"0E3}
\DeclareInputTextEx{"0E5}{\@as@active{ID}}{"0D5}{"0E5}
\DeclareInputTextEx{"0E6}{\@as@active{IG}}{"0D9}{"0E6}
\DeclareInputTextEx{"0E7}{\'O}{"0C6}{"0E7}
\DeclareInputTextEx{"0E8}{\`O}{"0CA}{"0E8}
\DeclareInputTextEx{"0E9}{\~O}{"0EA}{"0E9}
\DeclareInputTextEx{"0EA}{\~o}{"0EA}{"0E9}
\DeclareInputTextEx{"0EB}{\v{S}}{"0EC}{"0EB}
\DeclareInputTextEx{"0EC}{\v{s}}{"0EC}{"0EB}
\DeclareInputTextEx{"0ED}{\'U}{"0C7}{"0ED}
\DeclareInputTextEx{"0EE}{\"Y}{"0EF}{"0EE}
\DeclareInputTextEx{"0EF}{\"y}{"0EF}{"0EE}
\DeclareInputTextEx{"0F0}{\@as@active{TH}}{"0F1}{"0F0}
\DeclareInputTextEx{"0F1}{\@as@active{th}}{"0F1}{"0F0}
\DeclareInputTextEx{"0F2}{\textperiodcentered}{"0F2}{"0F2}
\DeclareInputMathEx{"0F3}{\mu}
\DeclareInputTextEx{"0F4}{\P}{"0F4}{"0F4}
\DeclareInputTextEx{"0F5}{\textthreequarters}{"0F5}{"0F5}
\DeclareInputTextEx{"0F6}{\textemdash}{"0F6}{"0F6}
\DeclareInputTextEx{"0F7}{\textonequarter}{"0F7}{"0F7}
\DeclareInputTextEx{"0F8}{\textonehalf}{"0F8}{"0F8}
\DeclareInputMathEx{"0F9}{\mathordmasculine}
\DeclareInputMathEx{"0FA}{\mathordfeminine}
\DeclareInputTextEx{"0FB}{\guillemotleft}{"0FB}{"0FB}
\DeclareInputTextEx{"0FC}{\textblacksquare}{"0FC}{"0FC}
\DeclareInputTextEx{"0FD}{\guillemotright}{"0FD}{"0FD}
\DeclareInputMathEx{"0FE}{\pm}
\DeclareInputTextEx{"0FF}{\@as@active{SS}}{"0DE}{"0FF}
\catcode`\@=\atcode
\endinput
%%
%% End of file `roman8.def'.
