( cd usr/share/texmf/bin ; rm -rf uniqleaf )
( cd usr/share/texmf/bin ; ln -sf texexec uniqleaf )
( cd usr/share/texmf/bin ; rm -rf allec )
( cd usr/share/texmf/bin ; ln -sf allcm allec )
( cd usr/share/texmf/bin ; rm -rf lamed )
( cd usr/share/texmf/bin ; ln -sf aleph lamed )
( cd usr/share/texmf/bin ; rm -rf latex )
( cd usr/share/texmf/bin ; ln -sf pdfetex latex )
( cd usr/share/texmf/bin ; rm -rf oxdvi )
( cd usr/share/texmf/bin ; ln -sf xdvi oxdvi )
( cd usr/share/texmf/bin ; rm -rf pdfjadetex )
( cd usr/share/texmf/bin ; ln -sf pdfetex pdfjadetex )
( cd usr/share/texmf/bin ; rm -rf kpsexpand )
( cd usr/share/texmf/bin ; ln -sf kpsetool kpsexpand )
( cd usr/share/texmf/bin ; rm -rf makempy )
( cd usr/share/texmf/bin ; ln -sf texexec makempy )
( cd usr/share/texmf/bin ; rm -rf fdf2tan )
( cd usr/share/texmf/bin ; ln -sf texexec fdf2tan )
( cd usr/share/texmf/bin ; rm -rf fdf2tex )
( cd usr/share/texmf/bin ; ln -sf texexec fdf2tex )
( cd usr/share/texmf/bin ; rm -rf texfind )
( cd usr/share/texmf/bin ; ln -sf texexec texfind )
( cd usr/share/texmf/bin ; rm -rf texfont )
( cd usr/share/texmf/bin ; ln -sf texexec texfont )
( cd usr/share/texmf/bin ; rm -rf texhash )
( cd usr/share/texmf/bin ; ln -sf mktexlsr texhash )
( cd usr/share/texmf/bin ; rm -rf texshow )
( cd usr/share/texmf/bin ; ln -sf texexec texshow )
( cd usr/share/texmf/bin ; rm -rf texutil )
( cd usr/share/texmf/bin ; ln -sf texexec texutil )
( cd usr/share/texmf/bin ; rm -rf amstex )
( cd usr/share/texmf/bin ; ln -sf pdfetex amstex )
( cd usr/share/texmf/bin ; rm -rf bplain )
( cd usr/share/texmf/bin ; ln -sf pdfetex bplain )
( cd usr/share/texmf/bin ; rm -rf kpsepath )
( cd usr/share/texmf/bin ; ln -sf kpsetool kpsepath )
( cd usr/share/texmf/bin ; rm -rf dvigif )
( cd usr/share/texmf/bin ; ln -sf dvipng dvigif )
( cd usr/share/texmf/bin ; rm -rf dvilj6 )
( cd usr/share/texmf/bin ; ln -sf dvilj4 dvilj6 )
( cd usr/share/texmf/bin ; rm -rf mptopdf )
( cd usr/share/texmf/bin ; ln -sf texexec mptopdf )
( cd usr/share/texmf/bin ; rm -rf lambda )
( cd usr/share/texmf/bin ; ln -sf omega lambda )
( cd usr/share/texmf/bin ; rm -rf odvips )
( cd usr/share/texmf/bin ; ln -sf dvips odvips )
( cd usr/share/texmf/bin ; rm -rf pdftex )
( cd usr/share/texmf/bin ; ln -sf pdfetex pdftex )
( cd usr/share/texmf/bin ; rm -rf pdflatex )
( cd usr/share/texmf/bin ; ln -sf pdfetex pdflatex )
( cd usr/share/texmf/bin ; rm -rf ofm2opl )
( cd usr/share/texmf/bin ; ln -sf omfonts ofm2opl )
( cd usr/share/texmf/bin ; rm -rf bamstex )
( cd usr/share/texmf/bin ; ln -sf pdfetex bamstex )
( cd usr/share/texmf/bin ; rm -rf pdfcrop )
( cd usr/share/texmf/bin ; ln -sf texexec pdfcrop )
( cd usr/share/texmf/bin ; rm -rf opl2ofm )
( cd usr/share/texmf/bin ; ln -sf omfonts opl2ofm )
( cd usr/share/texmf/bin ; rm -rf thumbpdf )
( cd usr/share/texmf/bin ; ln -sf texexec thumbpdf )
( cd usr/share/texmf/bin ; rm -rf jadetex )
( cd usr/share/texmf/bin ; ln -sf latex jadetex )
( cd usr/share/texmf/bin ; rm -rf ovf2ovp )
( cd usr/share/texmf/bin ; ln -sf omfonts ovf2ovp )
( cd usr/share/texmf/bin ; rm -rf ovp2ovf )
( cd usr/share/texmf/bin ; ln -sf omfonts ovp2ovf )
( cd usr/share/texmf/bin ; rm -rf mktexfmt )
( cd usr/share/texmf/bin ; ln -sf fmtutil mktexfmt )
( cd usr/share/texmf/man/man1 ; rm -rf odvips.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf dvips.1.gz odvips.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf dvilj2p.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf dvilj.1.gz dvilj2p.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf dvilj4.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf dvilj.1.gz dvilj4.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf mktexfmt.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf fmtutil.1.gz mktexfmt.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf dvilj6.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf dvilj.1.gz dvilj6.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf odvicopy.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf dvicopy.1.gz odvicopy.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf ctangle.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf cweb.1.gz ctangle.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf cweave.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf cweb.1.gz cweave.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf updmap-sys.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf updmap.1.gz updmap-sys.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf kpsepath.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf kpsetool.1.gz kpsepath.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf texconfig-sys.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf texconfig.1.gz texconfig-sys.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf dvilj4l.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf dvilj.1.gz dvilj4l.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf allec.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf allcm.1.gz allec.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf texhash.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf mktexlsr.1.gz texhash.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf mf-nowin.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf mf.1.gz mf-nowin.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf fmtutil-sys.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf fmtutil.1.gz fmtutil-sys.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf kpsexpand.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf kpsetool.1.gz kpsexpand.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf oxdvi.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf xdvi.1.gz oxdvi.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf pdflatex.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf pdfetex.1.gz pdflatex.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf odvitype.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf dvitype.1.gz odvitype.1.gz )
( cd usr/share/texmf/man/man1 ; rm -rf lambda.1.gz )
( cd usr/share/texmf/man/man1 ; ln -sf omega.1.gz lambda.1.gz )
( cd usr/share/texmf ; rm -rf info )
( cd usr/share/texmf ; ln -sf /usr/info info )
( cd usr/share/texmf-var/fonts/map/dvips/updmap ; rm -rf psfonts.map )
( cd usr/share/texmf-var/fonts/map/dvips/updmap ; ln -sf psfonts_t1.map psfonts.map )
( cd usr/share/texmf-var/fonts/map/dvipdfm/updmap ; rm -rf dvipdfm.map )
( cd usr/share/texmf-var/fonts/map/dvipdfm/updmap ; ln -sf dvipdfm_dl14.map dvipdfm.map )
( cd usr/share/texmf-var/fonts/map/pdftex/updmap ; rm -rf pdftex.map )
( cd usr/share/texmf-var/fonts/map/pdftex/updmap ; ln -sf pdftex_dl14.map pdftex.map )
