%%
%% This is file `t2cenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyoutenc.dtx  (with options: `T2C')
%% This file is a generated file from the sources of the `cyrillic' bundle
%% in the LaTeX2e distribution.
%% 
%% This is a generated file.
%% 
%% Copyright 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the Standard LaTeX `Cyrillic Bundle'.
%% -----------------------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2003/12/01 or later.
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% `Cyrillic Bundle'. You may however distribute the LaTeX `Cyrillic
%% Bundle' without such generated files.
%% 
%% The list of all files belonging to the `Cyrillic Bundle' is
%% given in the file `manifest.txt'.
%% 
\NeedsTeXFormat{LaTeX2e}[1998/12/01]
\ProvidesFile{t2cenc.def}
  [2004/01/26 v1.0g Cyrillic encoding definition file]
\DeclareFontEncoding{T2C}{}{}
\DeclareFontSubstitution{\LastDeclaredEncoding}{cmr}{m}{n}
\DeclareTextAccent{\`}{\LastDeclaredEncoding}{0}
\DeclareTextAccent{\'}{\LastDeclaredEncoding}{1}
\DeclareTextAccent{\^}{\LastDeclaredEncoding}{2}
\DeclareTextAccent{\~}{\LastDeclaredEncoding}{3}
\DeclareTextAccent{\"}{\LastDeclaredEncoding}{4}
\DeclareTextAccent{\H}{\LastDeclaredEncoding}{5}
\DeclareTextAccent{\r}{\LastDeclaredEncoding}{6}
\DeclareTextAccent{\v}{\LastDeclaredEncoding}{7}
\DeclareTextAccent{\u}{\LastDeclaredEncoding}{8}
\DeclareTextAccent{\=}{\LastDeclaredEncoding}{9}
\DeclareTextAccent{\.}{\LastDeclaredEncoding}{10}
\DeclareTextAccent{\f}{\LastDeclaredEncoding}{18}
\DeclareTextAccent{\C}{\LastDeclaredEncoding}{19}
\DeclareTextAccent{\U}{\LastDeclaredEncoding}{20}
\DeclareTextCommand{\b}{\LastDeclaredEncoding}[1]
   {\hmode@bgroup\o@lign{\relax#1\crcr\hidewidth\sh@ft{29}%
     \vbox to.2ex{\hbox{\char9}\vss}\hidewidth}\egroup}
\DeclareTextCommand{\c}{\LastDeclaredEncoding}[1]
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
     \else{\ooalign{\hidewidth\char11\hidewidth
        \crcr\unhbox\z@}}\fi}
\DeclareTextCommand{\d}{\LastDeclaredEncoding}[1]
   {\hmode@bgroup
    \o@lign{\relax#1\crcr\hidewidth\sh@ft{10}.\hidewidth}\egroup}
\DeclareTextCommand{\k}{\LastDeclaredEncoding}[1]
   {\oalign{\null#1\crcr\hidewidth\char12}}
\DeclareTextCommand{\textperthousand}{\LastDeclaredEncoding}
   {\%\char 24 }
\DeclareTextCommand{\textpertenthousand}{\LastDeclaredEncoding}
   {\%\char 24\char 24 }
\DeclareTextCompositeCommand{\r}{\LastDeclaredEncoding}{A}
   {\leavevmode\setbox\z@\hbox{!}\dimen@\ht\z@\advance\dimen@-1ex%
    \rlap{\raise.67\dimen@\hbox{\char6}}A}
\DeclareTextSymbol{\textendash}{\LastDeclaredEncoding}{21}
\DeclareTextSymbol{\cyrdash}{\LastDeclaredEncoding}{22}
\DeclareTextSymbol{\textemdash}{\LastDeclaredEncoding}{22}
\DeclareTextSymbol{\textcompwordmark}{\LastDeclaredEncoding}{23}
\DeclareTextSymbol{\textvisiblespace}{\LastDeclaredEncoding}{32}
\DeclareTextSymbol{\textdollar}{\LastDeclaredEncoding}{36}
\DeclareTextSymbol{\textless}{\LastDeclaredEncoding}{60}
\DeclareTextSymbol{\textgreater}{\LastDeclaredEncoding}{62}
\DeclareTextSymbol{\textbackslash}{\LastDeclaredEncoding}{92}
\DeclareTextSymbol{\textasciicircum}{\LastDeclaredEncoding}{94}
\DeclareTextSymbol{\textunderscore}{\LastDeclaredEncoding}{95}
\DeclareTextSymbol{\textbraceleft}{\LastDeclaredEncoding}{123}
\DeclareTextSymbol{\textbar}{\LastDeclaredEncoding}{124}
\DeclareTextSymbol{\textbraceright}{\LastDeclaredEncoding}{125}
\DeclareTextSymbol{\textasciitilde}{\LastDeclaredEncoding}{126}
\DeclareTextSymbol{\textnumero}{\LastDeclaredEncoding}{157}
\DeclareTextSymbol{\textcurrency}{\LastDeclaredEncoding}{158}
\DeclareTextSymbol{\textsection}{\LastDeclaredEncoding}{159}
\DeclareTextSymbol{\textquotedbl}{\LastDeclaredEncoding}{34}
\DeclareTextSymbol{\textquoteleft}{\LastDeclaredEncoding}{96}
\DeclareTextSymbol{\textquoteright}{\LastDeclaredEncoding}{39}
\DeclareTextSymbol{\textquotedblleft}{\LastDeclaredEncoding}{16}
\DeclareTextSymbol{\textquotedblright}{\LastDeclaredEncoding}{17}
\DeclareTextSymbol{\quotedblbase}{\LastDeclaredEncoding}{189}
\DeclareTextSymbol{\CYRpalochka}{\LastDeclaredEncoding}{13}
\DeclareTextSymbol{\cyrlangle}{\LastDeclaredEncoding}{14}
\DeclareTextSymbol{\cyrrangle}{\LastDeclaredEncoding}{15}
\DeclareTextSymbol{\guillemotleft}{\LastDeclaredEncoding}{190}
\DeclareTextSymbol{\guillemotright}{\LastDeclaredEncoding}{191}
\DeclareTextSymbol{\i}{\LastDeclaredEncoding}{25}
\DeclareTextSymbol{\j}{\LastDeclaredEncoding}{26}
\DeclareTextComposite{\.}{\LastDeclaredEncoding}{i}{`\i}
\DeclareTextSymbol{\CYRA}{\LastDeclaredEncoding}{192}
\DeclareTextSymbol{\cyra}{\LastDeclaredEncoding}{224}
\DeclareTextSymbol{\CYRB}{\LastDeclaredEncoding}{193}
\DeclareTextSymbol{\cyrb}{\LastDeclaredEncoding}{225}
\DeclareTextSymbol{\CYRV}{\LastDeclaredEncoding}{194}
\DeclareTextSymbol{\cyrv}{\LastDeclaredEncoding}{226}
\DeclareTextSymbol{\CYRG}{\LastDeclaredEncoding}{195}
\DeclareTextSymbol{\cyrg}{\LastDeclaredEncoding}{227}
\DeclareTextSymbol{\CYRD}{\LastDeclaredEncoding}{196}
\DeclareTextSymbol{\cyrd}{\LastDeclaredEncoding}{228}
\DeclareTextSymbol{\CYRE}{\LastDeclaredEncoding}{197}
\DeclareTextSymbol{\cyre}{\LastDeclaredEncoding}{229}
\DeclareTextSymbol{\CYRZH}{\LastDeclaredEncoding}{198}
\DeclareTextSymbol{\cyrzh}{\LastDeclaredEncoding}{230}
\DeclareTextSymbol{\CYRZ}{\LastDeclaredEncoding}{199}
\DeclareTextSymbol{\cyrz}{\LastDeclaredEncoding}{231}
\DeclareTextSymbol{\CYRI}{\LastDeclaredEncoding}{200}
\DeclareTextSymbol{\cyri}{\LastDeclaredEncoding}{232}
\DeclareTextSymbol{\CYRISHRT}{\LastDeclaredEncoding}{201}
\DeclareTextSymbol{\cyrishrt}{\LastDeclaredEncoding}{233}
\DeclareTextSymbol{\CYRK}{\LastDeclaredEncoding}{202}
\DeclareTextSymbol{\cyrk}{\LastDeclaredEncoding}{234}
\DeclareTextSymbol{\CYRL}{\LastDeclaredEncoding}{203}
\DeclareTextSymbol{\cyrl}{\LastDeclaredEncoding}{235}
\DeclareTextSymbol{\CYRM}{\LastDeclaredEncoding}{204}
\DeclareTextSymbol{\cyrm}{\LastDeclaredEncoding}{236}
\DeclareTextSymbol{\CYRN}{\LastDeclaredEncoding}{205}
\DeclareTextSymbol{\cyrn}{\LastDeclaredEncoding}{237}
\DeclareTextSymbol{\CYRO}{\LastDeclaredEncoding}{206}
\DeclareTextSymbol{\cyro}{\LastDeclaredEncoding}{238}
\DeclareTextSymbol{\CYRP}{\LastDeclaredEncoding}{207}
\DeclareTextSymbol{\cyrp}{\LastDeclaredEncoding}{239}
\DeclareTextSymbol{\CYRR}{\LastDeclaredEncoding}{208}
\DeclareTextSymbol{\cyrr}{\LastDeclaredEncoding}{240}
\DeclareTextSymbol{\CYRS}{\LastDeclaredEncoding}{209}
\DeclareTextSymbol{\cyrs}{\LastDeclaredEncoding}{241}
\DeclareTextSymbol{\CYRT}{\LastDeclaredEncoding}{210}
\DeclareTextSymbol{\cyrt}{\LastDeclaredEncoding}{242}
\DeclareTextSymbol{\CYRU}{\LastDeclaredEncoding}{211}
\DeclareTextSymbol{\cyru}{\LastDeclaredEncoding}{243}
\DeclareTextSymbol{\CYRF}{\LastDeclaredEncoding}{212}
\DeclareTextSymbol{\cyrf}{\LastDeclaredEncoding}{244}
\DeclareTextSymbol{\CYRH}{\LastDeclaredEncoding}{213}
\DeclareTextSymbol{\cyrh}{\LastDeclaredEncoding}{245}
\DeclareTextSymbol{\CYRC}{\LastDeclaredEncoding}{214}
\DeclareTextSymbol{\cyrc}{\LastDeclaredEncoding}{246}
\DeclareTextSymbol{\CYRCH}{\LastDeclaredEncoding}{215}
\DeclareTextSymbol{\cyrch}{\LastDeclaredEncoding}{247}
\DeclareTextSymbol{\CYRSH}{\LastDeclaredEncoding}{216}
\DeclareTextSymbol{\cyrsh}{\LastDeclaredEncoding}{248}
\DeclareTextSymbol{\CYRSHCH}{\LastDeclaredEncoding}{217}
\DeclareTextSymbol{\cyrshch}{\LastDeclaredEncoding}{249}
\DeclareTextSymbol{\CYRHRDSN}{\LastDeclaredEncoding}{218}
\DeclareTextSymbol{\cyrhrdsn}{\LastDeclaredEncoding}{250}
\DeclareTextSymbol{\CYRERY}{\LastDeclaredEncoding}{219}
\DeclareTextSymbol{\cyrery}{\LastDeclaredEncoding}{251}
\DeclareTextSymbol{\CYRSFTSN}{\LastDeclaredEncoding}{220}
\DeclareTextSymbol{\cyrsftsn}{\LastDeclaredEncoding}{252}
\DeclareTextSymbol{\CYREREV}{\LastDeclaredEncoding}{221}
\DeclareTextSymbol{\cyrerev}{\LastDeclaredEncoding}{253}
\DeclareTextSymbol{\CYRYU}{\LastDeclaredEncoding}{222}
\DeclareTextSymbol{\cyryu}{\LastDeclaredEncoding}{254}
\DeclareTextSymbol{\CYRYA}{\LastDeclaredEncoding}{223}
\DeclareTextSymbol{\cyrya}{\LastDeclaredEncoding}{255}
\DeclareTextSymbol{\CYRPHK}{T2C}{128}
\DeclareTextSymbol{\cyrphk}{T2C}{160}
\DeclareTextSymbol{\CYRTETSE}{T2C}{129}
\DeclareTextSymbol{\cyrtetse}{T2C}{161}
\DeclareTextSymbol{\CYRTDSC}{T2C}{130}
\DeclareTextSymbol{\cyrtdsc}{T2C}{162}
\DeclareTextSymbol{\CYRGHK}{T2C}{131}
\DeclareTextSymbol{\cyrghk}{T2C}{163}
\DeclareTextSymbol{\CYRSHHA}{T2C}{132}
\DeclareTextSymbol{\cyrshha}{T2C}{164}
\DeclareTextSymbol{\CYRRDSC}{T2C}{133}
\DeclareTextSymbol{\cyrrdsc}{T2C}{165}
\DeclareTextSymbol{\CYRRTICK}{T2C}{134}
\DeclareTextSymbol{\cyrrtick}{T2C}{166}
\DeclareTextSymbol{\CYRABHDZE}{T2C}{135}
\DeclareTextSymbol{\cyrabhdze}{T2C}{167}
\DeclareTextSymbol{\CYRMDSC}{T2C}{136}
\DeclareTextSymbol{\cyrmdsc}{T2C}{168}
\DeclareTextSymbol{\CYRKDSC}{T2C}{137}
\DeclareTextSymbol{\cyrkdsc}{T2C}{169}
\DeclareTextSymbol{\CYRLDSC}{T2C}{138}
\DeclareTextSymbol{\cyrldsc}{T2C}{170}
\DeclareTextSymbol{\CYRKHCRS}{T2C}{139}
\DeclareTextSymbol{\cyrkhcrs}{T2C}{171}
\DeclareTextSymbol{\CYRLHK}{T2C}{140}
\DeclareTextSymbol{\cyrlhk}{T2C}{172}
\DeclareTextSymbol{\CYRNDSC}{T2C}{141}
\DeclareTextSymbol{\cyrndsc}{T2C}{173}
\DeclareTextSymbol{\CYRMHK}{T2C}{142}
\DeclareTextSymbol{\cyrmhk}{T2C}{174}
\DeclareTextSymbol{\CYRNHK}{T2C}{143}
\DeclareTextSymbol{\cyrnhk}{T2C}{175}
\DeclareTextSymbol{\CYROTLD}{T2C}{144}
\DeclareTextSymbol{\cyrotld}{T2C}{176}
\DeclareTextSymbol{\CYRABHCH}{T2C}{145}
\DeclareTextSymbol{\cyrabhch}{T2C}{177}
\DeclareTextSymbol{\CYRABHCHDSC}{T2C}{146}
\DeclareTextSymbol{\cyrabhchdsc}{T2C}{178}
\DeclareTextSymbol{\CYRSEMISFTSN}{T2C}{147}
\DeclareTextSymbol{\cyrsemisftsn}{T2C}{179}
\DeclareTextSymbol{\CYRISHRTDSC}{T2C}{148}
\DeclareTextSymbol{\cyrishrtdsc}{T2C}{180}
\DeclareTextSymbol{\CYRHDSC}{T2C}{149}
\DeclareTextSymbol{\cyrhdsc}{T2C}{181}
\DeclareTextSymbol{\CYRDZHE}{T2C}{150}
\DeclareTextSymbol{\cyrdzhe}{T2C}{182}
\DeclareTextSymbol{\CYRABHHA}{T2C}{151}
\DeclareTextSymbol{\cyrabhha}{T2C}{183}
\DeclareTextSymbol{\CYRCHRDSC}{T2C}{152}
\DeclareTextSymbol{\cyrchrdsc}{T2C}{184}
\DeclareTextSymbol{\CYRNLHK}{T2C}{153}
\DeclareTextSymbol{\cyrnlhk}{T2C}{185}
\DeclareTextSymbol{\CYRSCHWA}{T2C}{154}
\DeclareTextSymbol{\cyrschwa}{T2C}{186}
\DeclareTextSymbol{\CYRRHK}{T2C}{155}
\DeclareTextSymbol{\cyrrhk}{T2C}{187}
\DeclareTextSymbol{\CYRYO}{\LastDeclaredEncoding}{156}
\DeclareTextSymbol{\cyryo}{\LastDeclaredEncoding}{188}
\DeclareTextSymbol{\CYRII}{\LastDeclaredEncoding}{73}
\DeclareTextSymbol{\cyrii}{\LastDeclaredEncoding}{105}
\DeclareTextSymbol{\CYRJE}{\LastDeclaredEncoding}{74}
\DeclareTextSymbol{\cyrje}{\LastDeclaredEncoding}{106}
\DeclareTextSymbol{\CYRQ}{\LastDeclaredEncoding}{81}
\DeclareTextSymbol{\cyrq}{\LastDeclaredEncoding}{113}
\DeclareTextSymbol{\CYRDZE}{\LastDeclaredEncoding}{83}
\DeclareTextSymbol{\cyrdze}{\LastDeclaredEncoding}{115}
\DeclareTextSymbol{\CYRW}{\LastDeclaredEncoding}{87}
\DeclareTextSymbol{\cyrw}{\LastDeclaredEncoding}{119}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\CYRE}{156}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\cyre}{188}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\CYRI}{201}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\cyri}{233}
\DeclareTextComposite{\k}{T2C}{\CYRABHCH}{146}
\DeclareTextComposite{\k}{T2C}{\cyrabhch}{178}
\endinput
%%
%% End of file `t2cenc.def'.
