%%
%% This is file `koi8-u.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyinpenc.dtx  (with options: `koi8,koi8u')
%% This file is a generated file from the sources of the `cyrillic' bundle
%% in the LaTeX2e distribution.
%% 
%% This is a generated file.
%% 
%% Copyright 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the Standard LaTeX `Cyrillic Bundle'.
%% -----------------------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2003/12/01 or later.
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% `Cyrillic Bundle'. You may however distribute the LaTeX `Cyrillic
%% Bundle' without such generated files.
%% 
%% The list of all files belonging to the `Cyrillic Bundle' is
%% given in the file `manifest.txt'.
%% 
\ProvidesFile{koi8-u.def}
  [1999/11/16 v1.0d Input encoding file]
\makeatletter
\DeclareInputText{225}{\CYRA}
\DeclareInputText{226}{\CYRB}
\DeclareInputText{247}{\CYRV}
\DeclareInputText{231}{\CYRG}
\DeclareInputText{228}{\CYRD}
\DeclareInputText{229}{\CYRE}
\DeclareInputText{179}{\CYRYO}
\DeclareInputText{246}{\CYRZH}
\DeclareInputText{250}{\CYRZ}
\DeclareInputText{233}{\CYRI}
\DeclareInputText{234}{\CYRISHRT}
\DeclareInputText{235}{\CYRK}
\DeclareInputText{236}{\CYRL}
\DeclareInputText{237}{\CYRM}
\DeclareInputText{238}{\CYRN}
\DeclareInputText{239}{\CYRO}
\DeclareInputText{240}{\CYRP}
\DeclareInputText{242}{\CYRR}
\DeclareInputText{243}{\CYRS}
\DeclareInputText{244}{\CYRT}
\DeclareInputText{245}{\CYRU}
\DeclareInputText{230}{\CYRF}
\DeclareInputText{232}{\CYRH}
\DeclareInputText{227}{\CYRC}
\DeclareInputText{254}{\CYRCH}
\DeclareInputText{251}{\CYRSH}
\DeclareInputText{253}{\CYRSHCH}
\DeclareInputText{255}{\CYRHRDSN}
\DeclareInputText{249}{\CYRERY}
\DeclareInputText{248}{\CYRSFTSN}
\DeclareInputText{252}{\CYREREV}
\DeclareInputText{224}{\CYRYU}
\DeclareInputText{241}{\CYRYA}
\DeclareInputText{193}{\cyra}
\DeclareInputText{194}{\cyrb}
\DeclareInputText{215}{\cyrv}
\DeclareInputText{199}{\cyrg}
\DeclareInputText{196}{\cyrd}
\DeclareInputText{197}{\cyre}
\DeclareInputText{163}{\cyryo}
\DeclareInputText{214}{\cyrzh}
\DeclareInputText{218}{\cyrz}
\DeclareInputText{201}{\cyri}
\DeclareInputText{202}{\cyrishrt}
\DeclareInputText{203}{\cyrk}
\DeclareInputText{204}{\cyrl}
\DeclareInputText{205}{\cyrm}
\DeclareInputText{206}{\cyrn}
\DeclareInputText{207}{\cyro}
\DeclareInputText{208}{\cyrp}
\DeclareInputText{210}{\cyrr}
\DeclareInputText{211}{\cyrs}
\DeclareInputText{212}{\cyrt}
\DeclareInputText{213}{\cyru}
\DeclareInputText{198}{\cyrf}
\DeclareInputText{200}{\cyrh}
\DeclareInputText{195}{\cyrc}
\DeclareInputText{222}{\cyrch}
\DeclareInputText{219}{\cyrsh}
\DeclareInputText{221}{\cyrshch}
\DeclareInputText{223}{\cyrhrdsn}
\DeclareInputText{217}{\cyrery}
\DeclareInputText{216}{\cyrsftsn}
\DeclareInputText{220}{\cyrerev}
\DeclareInputText{192}{\cyryu}
\DeclareInputText{209}{\cyrya}
\DeclareInputText{164}{\cyrie}
\DeclareInputText{166}{\cyrii}
\DeclareInputText{167}{\cyryi}
\DeclareInputText{173}{\cyrgup}
\DeclareInputText{180}{\CYRIE}
\DeclareInputText{182}{\CYRII}
\DeclareInputText{183}{\CYRYI}
\DeclareInputText{189}{\CYRGUP}
\makeatother
\endinput
%%
%% End of file `koi8-u.def'.
