\ProvidesFile{ut1enc.def}
 [1999/05/08 v0.1
         Standard Omega file]
\DeclareFontEncoding{UT1}{}{}
\DeclareTextAccent{\`}{UT1}{"0300}
\DeclareTextAccent{\'}{UT1}{"0301}
\DeclareTextAccent{\^}{UT1}{"0302}
\DeclareTextAccent{\~}{UT1}{"0303}
\DeclareTextAccent{\=}{UT1}{"0304}
\DeclareTextAccent{\u}{UT1}{"0306}
\DeclareTextAccent{\.}{UT1}{"0307}
\DeclareTextAccent{\"}{UT1}{"0308}
\DeclareTextAccent{\r}{UT1}{"030A}
\DeclareTextAccent{\H}{UT1}{"030B}
\DeclareTextAccent{\v}{UT1}{"030C}
\DeclareTextCommand{\b}{UT1}[1]
   {{\o@lign{\relax#1\crcr\hidewidth\sh@ft{29}%
     \vbox to.2ex{\hbox{\char"0304}\vss}\hidewidth}}}
\DeclareTextCommand{\c}{UT1}[1]
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
     \else{\ooalign{\hidewidth\char"0327\hidewidth
        \crcr\unhbox\z@}}\fi}
\DeclareTextCommand{\d}{UT1}[1]
   {{\o@lign{\relax#1\crcr\hidewidth\sh@ft{10}.\hidewidth}}}
\DeclareTextCommand{\k}{UT1}[1]
   {\oalign{\null#1\crcr\hidewidth\char"0328}}
\DeclareTextSymbol{\textperthousand}{UT1}{"2030}
\DeclareTextSymbol{\textpertenthousand}{UT1}{"2031}
\DeclareTextSymbol{\AE}{UT1}{"00C6}
\DeclareTextSymbol{\DH}{UT1}{"00D6}
\DeclareTextSymbol{\DJ}{UT1}{"0110}
\DeclareTextSymbol{\L}{UT1}{"0141}
\DeclareTextSymbol{\NG}{UT1}{"014A}
\DeclareTextSymbol{\OE}{UT1}{"0152}
\DeclareTextSymbol{\O}{UT1}{"00D8}
\DeclareTextCommand{\SS}{UT1}{SS}
\DeclareTextSymbol{\TH}{UT1}{"00DE}
\DeclareTextSymbol{\ae}{UT1}{"00E6}
\DeclareTextSymbol{\dh}{UT1}{"00F0}
\DeclareTextSymbol{\dj}{UT1}{"0111}
\DeclareTextSymbol{\guillemotleft}{UT1}{"00AB}
\DeclareTextSymbol{\guillemotright}{UT1}{"00BB}
\DeclareTextSymbol{\guilsinglleft}{UT1}{"2039}
\DeclareTextSymbol{\guilsinglright}{UT1}{"203A}
\DeclareTextSymbol{\i}{UT1}{"0131}
\DeclareTextSymbol{\j}{UT1}{"0087}
\DeclareTextSymbol{\l}{UT1}{"0142}
\DeclareTextSymbol{\ng}{UT1}{"014B}
\DeclareTextSymbol{\oe}{UT1}{"0153}
\DeclareTextSymbol{\o}{UT1}{"00F8}
\DeclareTextSymbol{\quotedblbase}{UT1}{"201E}
\DeclareTextSymbol{\quotesinglbase}{UT1}{"201A}
\DeclareTextSymbol{\ss}{UT1}{"00FE}
\DeclareTextSymbol{\textasciicircum}{UT1}{"008E}
\DeclareTextSymbol{\textasciitilde}{UT1}{"0080}
\DeclareTextSymbol{\textbackslash}{UT1}{"008C}
\DeclareTextSymbol{\textbar}{UT1}{"007C}
\DeclareTextSymbol{\textbraceleft}{UT1}{"008B}
\DeclareTextSymbol{\textbraceright}{UT1}{"008D}
\DeclareTextSymbol{\textcompwordmark}{UT1}{`\-}
\DeclareTextSymbol{\textdollar}{UT1}{"0084}
\DeclareTextSymbol{\textemdash}{UT1}{"2014}
\DeclareTextSymbol{\textendash}{UT1}{"2013}
\DeclareTextSymbol{\textexclamdown}{UT1}{"00A1}
\DeclareTextSymbol{\textgreater}{UT1}{`\>}
\DeclareTextSymbol{\textless}{UT1}{`\<}
\DeclareTextSymbol{\textquestiondown}{UT1}{"00BF}
\DeclareTextSymbol{\textquotedblleft}{UT1}{"201C}
\DeclareTextSymbol{\textquotedblright}{UT1}{"201D}
\DeclareTextSymbol{\textquotedbl}{UT1}{`\"}
\DeclareTextSymbol{\textquoteleft}{UT1}{"2018}
\DeclareTextSymbol{\textquoteright}{UT1}{"2019}
\DeclareTextSymbol{\S}{UT1}{"00A7}
\DeclareTextSymbol{\textsection}{UT1}{"00A7}
\DeclareTextSymbol{\textsterling}{UT1}{"00A3}
\DeclareTextSymbol{\textunderscore}{UT1}{"008F}
\DeclareTextSymbol{\textvisiblespace}{UT1}{"2423}
\DeclareTextSymbol{\th}{UT1}{"00FE}
\DeclareTextComposite{\.}{UT1}{i}{`\i}
\DeclareTextComposite{\u}{UT1}{A}{"0102}
\DeclareTextComposite{\k}{UT1}{A}{"0104}
\DeclareTextComposite{\'}{UT1}{C}{"0106}
\DeclareTextComposite{\v}{UT1}{C}{"0108}
\DeclareTextComposite{\v}{UT1}{D}{"010E}
\DeclareTextComposite{\v}{UT1}{E}{"011A}
\DeclareTextComposite{\k}{UT1}{E}{"0118}
\DeclareTextComposite{\u}{UT1}{G}{"011E}
\DeclareTextComposite{\'}{UT1}{L}{"0139}
\DeclareTextComposite{\v}{UT1}{L}{"013D}
\DeclareTextComposite{\'}{UT1}{N}{"0143}
\DeclareTextComposite{\v}{UT1}{N}{"0147}
\DeclareTextComposite{\H}{UT1}{O}{"0150}
\DeclareTextComposite{\'}{UT1}{R}{"0154}
\DeclareTextComposite{\v}{UT1}{R}{"0158}
\DeclareTextComposite{\'}{UT1}{S}{"015A}
\DeclareTextComposite{\v}{UT1}{S}{"0160}
\DeclareTextComposite{\c}{UT1}{S}{"015E}
\DeclareTextComposite{\v}{UT1}{T}{"0164}
\DeclareTextComposite{\c}{UT1}{T}{"0162}
\DeclareTextComposite{\H}{UT1}{U}{"0170}
\DeclareTextComposite{\r}{UT1}{U}{"016E}
\DeclareTextComposite{\"}{UT1}{Y}{"0178}
\DeclareTextComposite{\'}{UT1}{Z}{"0179}
\DeclareTextComposite{\v}{UT1}{Z}{"017D}
\DeclareTextComposite{\.}{UT1}{Z}{"017B}
\DeclareTextComposite{\.}{UT1}{I}{"0130}
\DeclareTextComposite{\u}{UT1}{a}{"0103}
\DeclareTextComposite{\k}{UT1}{a}{"0105}
\DeclareTextComposite{\'}{UT1}{c}{"0107}
\DeclareTextComposite{\v}{UT1}{c}{"010D}
\DeclareTextComposite{\v}{UT1}{d}{"010F}
\DeclareTextComposite{\v}{UT1}{e}{"011B}
\DeclareTextComposite{\k}{UT1}{e}{"0119}
\DeclareTextComposite{\u}{UT1}{g}{"011F}
\DeclareTextComposite{\'}{UT1}{l}{"013A}
\DeclareTextComposite{\v}{UT1}{l}{"013E}
\DeclareTextComposite{\'}{UT1}{n}{"0144}
\DeclareTextComposite{\v}{UT1}{n}{"0148}
\DeclareTextComposite{\H}{UT1}{o}{"0151}
\DeclareTextComposite{\'}{UT1}{r}{"0155}
\DeclareTextComposite{\v}{UT1}{r}{"0159}
\DeclareTextComposite{\'}{UT1}{s}{"015B}
\DeclareTextComposite{\v}{UT1}{s}{"0161}
\DeclareTextComposite{\c}{UT1}{s}{"015F}
\DeclareTextComposite{\v}{UT1}{t}{"0165}
\DeclareTextComposite{\c}{UT1}{t}{"0163}
\DeclareTextComposite{\H}{UT1}{u}{"0171}
\DeclareTextComposite{\r}{UT1}{u}{"016F}
\DeclareTextComposite{\"}{UT1}{y}{"00FF}
\DeclareTextComposite{\'}{UT1}{z}{"017A}
\DeclareTextComposite{\v}{UT1}{z}{"017E}
\DeclareTextComposite{\.}{UT1}{z}{"017C}
\DeclareTextComposite{\`}{UT1}{A}{"00C0}
\DeclareTextComposite{\'}{UT1}{A}{"00C1}
\DeclareTextComposite{\^}{UT1}{A}{"00C2}
\DeclareTextComposite{\~}{UT1}{A}{"00C3}
\DeclareTextComposite{\"}{UT1}{A}{"00C4}
\DeclareTextComposite{\r}{UT1}{A}{"00C5}
\DeclareTextComposite{\c}{UT1}{C}{"00C7}
\DeclareTextComposite{\`}{UT1}{E}{"00C8}
\DeclareTextComposite{\'}{UT1}{E}{"00C9}
\DeclareTextComposite{\^}{UT1}{E}{"00CA}
\DeclareTextComposite{\"}{UT1}{E}{"00CB}
\DeclareTextComposite{\`}{UT1}{I}{"00CC}
\DeclareTextComposite{\'}{UT1}{I}{"00CD}
\DeclareTextComposite{\^}{UT1}{I}{"00CE}
\DeclareTextComposite{\"}{UT1}{I}{"00CF}
\DeclareTextComposite{\~}{UT1}{N}{"00D1}
\DeclareTextComposite{\`}{UT1}{O}{"00D2}
\DeclareTextComposite{\'}{UT1}{O}{"00D3}
\DeclareTextComposite{\^}{UT1}{O}{"00D4}
\DeclareTextComposite{\~}{UT1}{O}{"00D5}
\DeclareTextComposite{\"}{UT1}{O}{"00D6}
\DeclareTextComposite{\`}{UT1}{U}{"00D9}
\DeclareTextComposite{\'}{UT1}{U}{"00DA}
\DeclareTextComposite{\^}{UT1}{U}{"00DB}
\DeclareTextComposite{\"}{UT1}{U}{"00DC}
\DeclareTextComposite{\'}{UT1}{Y}{"00DD}
\DeclareTextComposite{\`}{UT1}{a}{"00E0}
\DeclareTextComposite{\'}{UT1}{a}{"00E1}
\DeclareTextComposite{\^}{UT1}{a}{"00E2}
\DeclareTextComposite{\~}{UT1}{a}{"00E3}
\DeclareTextComposite{\"}{UT1}{a}{"00E4}
\DeclareTextComposite{\r}{UT1}{a}{"00E5}
\DeclareTextComposite{\c}{UT1}{c}{"00E7}
\DeclareTextComposite{\`}{UT1}{e}{"00E8}
\DeclareTextComposite{\'}{UT1}{e}{"00E9}
\DeclareTextComposite{\^}{UT1}{e}{"00EA}
\DeclareTextComposite{\"}{UT1}{e}{"00EB}
\DeclareTextComposite{\`}{UT1}{i}{"00EC}
\DeclareTextComposite{\`}{UT1}{\i}{"00EC}
\DeclareTextComposite{\'}{UT1}{i}{"00ED}
\DeclareTextComposite{\'}{UT1}{\i}{"00ED}
\DeclareTextComposite{\^}{UT1}{i}{"00EE}
\DeclareTextComposite{\^}{UT1}{\i}{"00EE}
\DeclareTextComposite{\"}{UT1}{i}{"00EF}
\DeclareTextComposite{\"}{UT1}{\i}{"00EF}
\DeclareTextComposite{\~}{UT1}{n}{"00F1}
\DeclareTextComposite{\`}{UT1}{o}{"00F2}
\DeclareTextComposite{\'}{UT1}{o}{"00F3}
\DeclareTextComposite{\^}{UT1}{o}{"00F4}
\DeclareTextComposite{\~}{UT1}{o}{"00F5}
\DeclareTextComposite{\"}{UT1}{o}{"00F6}
\DeclareTextComposite{\`}{UT1}{u}{"00F9}
\DeclareTextComposite{\'}{UT1}{u}{"00FA}
\DeclareTextComposite{\^}{UT1}{u}{"00FB}
\DeclareTextComposite{\"}{UT1}{u}{"00FC}
\DeclareTextComposite{\'}{UT1}{y}{"00FD}
\DeclareTextCommand{\capitalcedilla}{UT1}[1]
   {{\ooalign{\null#1\crcr\hidewidth\char"0327\hidewidth}}}
\DeclareTextCommand{\capitalogonek}{UT1}[1]
   {{\ooalign{\null#1\crcr\hidewidth\char"0328\hidewidth}}}
\DeclareTextAccent{\capitalgrave}{UT1}{"0300}
\DeclareTextAccent{\capitalacute}{UT1}{"0301}
\DeclareTextAccent{\capitalcircumflex}{UT1}{"0302}
\DeclareTextAccent{\capitaltilde}{UT1}{"0303}
\DeclareTextAccent{\capitaldieresis}{UT1}{"0308}
\DeclareTextAccent{\capitalhungarumlaut}{UT1}{"030B}
\DeclareTextAccent{\capitalring}{UT1}{"030A}
\DeclareTextAccent{\capitalcaron}{UT1}{"030C}
\DeclareTextAccent{\capitalbreve}{UT1}{"0306}
\DeclareTextAccent{\capitalmacron}{UT1}{"0304}
\DeclareTextAccent{\capitaldotaccent}{UT1}{"0307}
\DeclareTextAccent{\t}{UT1}{"0360}
\DeclareTextAccent{\capitaltie}{UT1}{"0360}
\DeclareTextAccent{\newtie}{UT1}{"0360}
\DeclareTextAccent{\capitalnewtie}{UT1}{"0360}
\DeclareTextSymbol{\textcapitalcompwordmark}{UT1}{`\-}
\DeclareTextSymbol{\textascendercompwordmark}{UT1}{`\-}
\DeclareTextSymbol{\textquotestraightbase}{UT1}{`\'} %%% TO BE FIXED
\DeclareTextSymbol{\textquotestraightdblbase}{UT1}{`\"} %%% TO BE FIXED
\DeclareTextSymbol{\texttwelveudash}{UT1}{"2013} %%% TO BE FIXED
\DeclareTextSymbol{\textthreequartersemdash}{UT1}{"2014} %%% TO BE FIXED
\DeclareTextCommand{\textleftarrow}{UT1}{\ensuremath{\from}}
\DeclareTextCommand{\textrightarrow}{UT1}{\ensuremath{\to}}
\DeclareTextSymbol{\textblank}{UT1}{"2422} %%% TO BE FIXED
\DeclareTextSymbol{\textdollar}{UT1}{"0084}
\DeclareTextSymbol{\textquotesingle}{UT1}{`\'}
\DeclareTextCommand{\textasteriskcentered}{UT1}{\ensuremath{*}} %%% TO BE FIXED
\DeclareTextSymbol{\textdblhyphen}{UT1}{`\=} %%% TO BE FIXED
\DeclareTextSymbol{\textfractionsolidus}{UT1}{`\/} %%% TO BE FIXED
\DeclareTextSymbol{\textzerooldstyle}{UT1}{48}
\DeclareTextSymbol{\textoneoldstyle}{UT1}{49}
\DeclareTextSymbol{\texttwooldstyle}{UT1}{50}
\DeclareTextSymbol{\textthreeoldstyle}{UT1}{51}
\DeclareTextSymbol{\textfouroldstyle}{UT1}{52}
\DeclareTextSymbol{\textfiveoldstyle}{UT1}{53}
\DeclareTextSymbol{\textsixoldstyle}{UT1}{54}
\DeclareTextSymbol{\textsevenoldstyle}{UT1}{55}
\DeclareTextSymbol{\texteightoldstyle}{UT1}{56}
\DeclareTextSymbol{\textnineoldstyle}{UT1}{57}
\DeclareTextCommand{\textlangle}{UT1}{\ensuremath{\langle}}
\DeclareTextCommand{\textminus}{UT1}{\ensuremath{-}}
\DeclareTextCommand{\textrangle}{UT1}{\ensuremath{\rangle}}
\DeclareTextCommand{\textmho}{UT1}{\ensuremath{\mho}} %%% TO BE FIXED
\DeclareTextSymbol{\textbigcircle}{UT1}{79}
\DeclareTextCommand{\textcircled}{UT1}[1]{{%
   \ooalign{%
      \hfil \raise .07ex\hbox {\upshape#1}\hfil \crcr
      \char 79   % '117 = "4F
   }%
}}
\DeclareTextSymbol{\textohm}{UT1}{"03A9}
\DeclareTextSymbol{\textlbrackdbl}{UT1}{91} %%% TO BE FIXED
\DeclareTextSymbol{\textrbrackdbl}{UT1}{93} %%% TO BE FIXED
\DeclareTextSymbol{\textuparrow}{UT1}{94} %%% TO BE FIXED
\DeclareTextSymbol{\textdownarrow}{UT1}{95} %%% TO BE FIXED
\DeclareTextSymbol{\textasciigrave}{UT1}{`\`}
\DeclareTextSymbol{\textborn}{UT1}{98} %%% TO BE FIXED
\DeclareTextSymbol{\textdivorced}{UT1}{99} %%% TO BE FIXED
\DeclareTextSymbol{\textdied}{UT1}{100} %%% TO BE FIXED
\DeclareTextSymbol{\textleaf}{UT1}{108} %%% TO BE FIXED
\DeclareTextSymbol{\textmarried}{UT1}{109} %%% TO BE FIXED
\DeclareTextSymbol{\textmusicalnote}{UT1}{110} %%% TO BE FIXED
\DeclareTextSymbol{\texttildelow}{UT1}{126} %%% TO BE FIXED
\DeclareTextSymbol{\textdblhyphenchar}{UT1}{127} %%% TO BE FIXED
\DeclareTextSymbol{\textasciibreve}{UT1}{128} %%% TO BE FIXED
\DeclareTextSymbol{\textasciicaron}{UT1}{129} %%% TO BE FIXED
\DeclareTextSymbol{\textacutedbl}{UT1}{130} %%% TO BE FIXED
\DeclareTextSymbol{\textgravedbl}{UT1}{131} %%% TO BE FIXED
\DeclareTextSymbol{\textdagger}{UT1}{"2020}
\DeclareTextSymbol{\textdaggerdbl}{UT1}{"2021}
\DeclareTextSymbol{\textbardbl}{UT1}{"2016}
\DeclareTextSymbol{\textbullet}{UT1}{"2022}
\DeclareTextSymbol{\textcelsius}{UT1}{"2103}
\DeclareTextSymbol{\textdollaroldstyle}{UT1}{"0084}
\DeclareTextSymbol{\textcentoldstyle}{UT1}{"00A2}
\DeclareTextSymbol{\textflorin}{UT1}{"0192}
\DeclareTextSymbol{\textcolonmonetary}{UT1}{141}
\DeclareTextSymbol{\textwon}{UT1}{"20A9}
\DeclareTextSymbol{\textnaira}{UT1}{"20A6}
\DeclareTextSymbol{\textguarani}{UT1}{144}
\DeclareTextSymbol{\textpeso}{UT1}{"20A7}
\DeclareTextSymbol{\textlira}{UT1}{"20A4}
\DeclareTextSymbol{\textrecipe}{UT1}{147}
\DeclareTextSymbol{\textinterrobang}{UT1}{"203D}
\DeclareTextSymbol{\textinterrobangdown}{UT1}{149}
\DeclareTextSymbol{\textdong}{UT1}{"20AB}
\DeclareTextSymbol{\texttrademark}{UT1}{"2122}
\DeclareTextSymbol{\textpilcrow}{UT1}{"00B6}
\DeclareTextSymbol{\textbaht}{UT1}{"0E3F}
\DeclareTextSymbol{\textnumero}{UT1}{"2116}
\DeclareTextSymbol{\textdiscount}{UT1}{156}
\DeclareTextSymbol{\textestimated}{UT1}{"212E}
\DeclareTextSymbol{\textopenbullet}{UT1}{158}
\DeclareTextSymbol{\textservicemark}{UT1}{"2120}
\DeclareTextSymbol{\textlquill}{UT1}{"2045}
\DeclareTextSymbol{\textrquill}{UT1}{"2046}
\DeclareTextSymbol{\textcent}{UT1}{"00A2}
\DeclareTextSymbol{\textsterling}{UT1}{"00A3}
\DeclareTextSymbol{\textcurrency}{UT1}{"00A4}
\DeclareTextSymbol{\textyen}{UT1}{"00A5}
\DeclareTextSymbol{\textbrokenbar}{UT1}{"00A6}
\DeclareTextSymbol{\textsection}{UT1}{"00A7}
\DeclareTextSymbol{\textasciidieresis}{UT1}{"0308}
\DeclareTextSymbol{\textcopyright}{UT1}{"00A9}
\DeclareTextSymbol{\textordfeminine}{UT1}{"00AA}
\DeclareTextSymbol{\textcopyleft}{UT1}{"0088}
\DeclareTextSymbol{\textlnot}{UT1}{"00AC}
\DeclareTextSymbol{\textcircledP}{UT1}{"2117}
\DeclareTextSymbol{\textregistered}{UT1}{"00AE}
\DeclareTextSymbol{\textasciimacron}{UT1}{"0304}
\DeclareTextSymbol{\textdegree}{UT1}{"00B0}
\DeclareTextCommand{\textpm}{UT1}{\ensuremath{\pm}}
\DeclareTextCommand{\texttwosuperior}{UT1}{\ensuremath{{}^{\text{2}}}}
\DeclareTextCommand{\textthreesuperior}{UT1}{\ensuremath{{}^{\text{3}}}}
\DeclareTextSymbol{\textasciiacute}{UT1}{"0301}
\DeclareTextSymbol{\textmu}{UT1}{"03BC} % micro sign
\DeclareTextSymbol{\P}{UT1}{"00B6}
\DeclareTextSymbol{\textparagraph}{UT1}{"00B6}
\DeclareTextCommand{\textperiodcentered}{UT1}{\ensuremath{\cdot}}
\DeclareTextSymbol{\textreferencemark}{UT1}{"203B}
\DeclareTextCommand{\textonesuperior}{UT1}{\ensuremath{{}^{\text{1}}}}
\DeclareTextSymbol{\textordmasculine}{UT1}{"00BA}
\DeclareTextCommand{\textsurd}{UT1}{\ensuremath{\sqrt{}}}
\DeclareTextCommand{\textonequarter}{UT1}{\ensuremath{\frac14}}
\DeclareTextCommand{\textonehalf}{UT1}{\ensuremath{\frac12}}
\DeclareTextCommand{\textthreequarters}{UT1}{\ensuremath{\frac34}}
\DeclareTextSymbol{\texteuro}{UT1}{"20AC}
\DeclareTextCommand{\texttimes}{UT1}{\ensuremath{\times}}
\DeclareTextCommand{\textdiv}{UT1}{\ensuremath{\div}}
\endinput
%%
%% End of file `t1enc.def'.
