%%
%% This is file `hpdftex.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `pdftex,pdfform,outlines')
%% 
%% File: hyperref.dtx Copyright 1995-2001 Sebastian Rahtz,
%% RCS: $Id: hyperref.dtx 6.71 2000/10/04 rahtz Exp rahtz $
%%
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%%
%% It may be distributed under the conditions of the LaTeX Project Public
%% License, either version 1.2 of this license or (at your option) any
%% later version.  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%%
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%%
\ProvidesFile{hpdftex.def}
  [2003/11/30 v6.74m
  Hyperref driver for pdfTeX]
\let\Hy@PutCatalog\pdfcatalog
\ifHy@pagelabels
  \def\HyPL@StorePageLabel#1{%
    \toks@\expandafter{\HyPL@Labels}%
    \xdef\HyPL@Labels{%
      \the\toks@
      \the\Hy@abspage\space<< #1 >> %
    }%
  }
  \AtEndDocument{\clearpage\HyPL@SetPageLabels}
\fi
\def\setpdflinkmargin#1{\pdflinkmargin#1}
\ifx\pdfstartlink\@undefined% less than version 14
  \let\pdfstartlink\pdfannotlink
  \let\pdflinkmargin\@tempdima
  \let\pdfxform\pdfform
  \let\pdflastxform\pdflastform
  \let\pdfrefxform\pdfrefform
\else
  \pdflinkmargin1pt
\fi
\providecommand\@pdfview{XYZ}
\def\new@pdflink#1{%
  \ifHy@verbose
    \typeout{pdftex: define anchor at line \the\inputlineno: #1}%
  \fi
  \Hy@SaveLastskip
  \pdfdest name {#1}\@pdfview
  \Hy@RestoreLastskip
}
\let\pdf@endanchor\@empty
\providecommand\@pdfborder{0 0 1}
\def\Hy@undefinedname{UNDEFINED}
\def\find@pdflink#1#2{%
  \leavevmode
  \protected@edef\Hy@testname{#2}%
  \ifx\Hy@testname\@empty
    \let\Hy@testname\Hy@undefinedname
  \fi
  \pdfstartlink
    attr{%
      /Border[\@pdfborder]%
      /H\@pdfhighlight
      /C[\CurrentBorderColor]%
    }%
    goto name {\Hy@testname}%
  \Hy@colorlink{\csname @#1color\endcsname}%
}
\def\close@pdflink{\Hy@endcolorlink\pdfendlink}
\def\hyper@anchor#1{\new@pdflink{#1}\anchor@spot\pdf@endanchor}
\def\hyper@anchorstart#1{\new@pdflink{#1}\Hy@activeanchortrue}
\def\hyper@anchorend{\pdf@endanchor\Hy@activeanchorfalse}
\def\hyper@linkstart#1#2{%
  \edef\CurrentBorderColor{\csname @#1bordercolor\endcsname}%
  \find@pdflink{#1}{#2}}
\def\hyper@linkend{\close@pdflink}
\def\hyper@link#1#2#3{%
  \edef\CurrentBorderColor{\csname @#1bordercolor\endcsname}%
  \find@pdflink{#1}{#2}#3\close@pdflink
}
\def\CurrentBorderColor{\@linkbordercolor}
\def\hyper@linkurl#1#2{%
  \bgroup
    \hyper@chars
    \leavevmode
    \pdfstartlink
      attr{%
        /Border[\@pdfborder]%
        /H\@pdfhighlight
        /C[\@urlbordercolor]%
      }%
      user{%
       /Subtype/Link%
       /A<<%
         /Type/Action%
         /S/URI%
         /URI(#2)%
       >>%
      }%
    \Hy@colorlink{\@urlcolor}#1%
    \close@pdflink
  \egroup
}
\def\hyper@linkfile#1#2#3{% anchor text, filename, linkname
  \bgroup
    \leavevmode
    \pdfstartlink
      attr{%
        /Border[\@pdfborder]%
        /H\@pdfhighlight
        /C[\@filebordercolor]%
      }%
      user {%
        /Subtype/Link%
        /A<<%
          /F(#2)%
          /S/GoToR%
          \ifHy@newwindow /NewWindow true \fi
          \ifx\\#3\\%
            /D[0 \@pdfstartview]%
          \else
            /D(#3)%
          \fi
        >>%
      }%
    \Hy@colorlink{\@filecolor}#1%
    \close@pdflink
  \egroup
}
\def\@hyper@launch run:#1\\#2#3{% filename, anchor text linkname
  \bgroup
    \leavevmode
    \pdfstartlink
      attr{%
        /Border[\@pdfborder]%
        /H\@pdfhighlight
        /C[\@runbordercolor]%
      }%
      user {%
        /Subtype/Link%
        /A<<%
          /F(#1)%
          /S/Launch%
          \ifHy@newwindow /NewWindow true \fi
          \ifx\\#3\\%
          \else
            /Win<</P(#3)/F(#1)>>%
          \fi
        >>%
      }%
    \Hy@colorlink{\@filecolor}#2%
    \close@pdflink
  \egroup
}
\def\@pdfproducer{pdfTeX}
\ifx\eTeXversion\@undefined
\else
  \ifx\eTeXversion\relax
  \else
    \ifnum\eTeXversion>0 %
      \def\@pdfproducer{pdfeTeX}
    \fi
  \fi
\fi
\ifx\pdftexversion\@undefined
\else
  \ifnum\pdftexversion<100 %
    \edef\@pdfproducer{%
      \@pdfproducer
      \the\pdftexversion.\pdftexrevision
    }
  \else
    \edef\@pdfproducer{%
      \@pdfproducer-%
      \expandafter\@car\the\pdftexversion\@empty\@nil.%
      \expandafter\@cdr\the\pdftexversion\@empty\@nil
      \pdftexrevision
    }
  \fi
\fi
\def\PDF@SetupDoc{%
  \ifx\@pdfpagescrop\@empty
  \else
    \edef\process@me{%
      \pdfpagesattr={%
        /CropBox[\@pdfpagescrop]%
        \expandafter\ifx\expandafter\\\the\pdfpagesattr\\%
        \else
          ^^J\the\pdfpagesattr
        \fi
      }%
    }%
    \process@me
  \fi
  \pdfcatalog{%
    /PageMode \@pdfpagemode
    \ifx\@baseurl\@empty
    \else
      /URI<</Base(\@baseurl)>>
    \fi
  }%
  \ifx\@pdfstartview\@empty
  \else
    openaction goto page \@pdfstartpage {\@pdfstartview}%
  \fi
  \edef\Hy@temp{%
    \ifHy@toolbar\else /HideToolbar true\fi
    \ifHy@menubar\else /HideMenubar true\fi
    \ifHy@windowui\else /HideWindowUI true\fi
    \ifHy@fitwindow /FitWindow true\fi
    \ifHy@centerwindow /CenterWindow true\fi
    \ifHy@displaydoctitle /DisplayDocTitle true\fi
    \ifx\@pdfnonfullscreenpagemode\@empty
    \else
      /NonFullScreenPageMode\@pdfnonfullscreenpagemode
    \fi
  }%
  \pdfcatalog{%
    \ifx\Hy@temp\@empty
    \else
      /ViewerPreferences<<\Hy@temp>>%
    \fi
    \ifx\pdf@pagelayout\@empty
    \else
      /PageLayout/\pdf@pagelayout\space
    \fi
  }%
}
\def\PDF@FinishDoc{%
  \Hy@UseMaketitleInfos
  \pdfinfo{%
    /Author(\@pdfauthor)%
    /Title(\@pdftitle)%
    /Subject(\@pdfsubject)%
    /Creator(\@pdfcreator)%
    /Producer(\@pdfproducer)%
    /Keywords(\@pdfkeywords)%
  }%
  \Hy@DisableOption{pdfauthor}%
  \Hy@DisableOption{pdftitle}%
  \Hy@DisableOption{pdfsubject}%
  \Hy@DisableOption{pdfcreator}%
  \Hy@DisableOption{pdfproducer}%
  \Hy@DisableOption{pdfkeywords}%
}
\def\hyper@pagetransition{%
  \ifx\@pdfpagetransition\relax
  \else
    \expandafter\Hy@RemoveTransPageAttr\the\pdfpageattr^^J/Trans{}>>\END
    \ifx\@pdfpagetransition\@empty
    \else
      \edef\@processme{%
        \global\pdfpageattr{%
          \the\pdfpageattr
          ^^J/Trans << /S /\@pdfpagetransition\space >>%
        }%
      }%
      \@processme
    \fi
  \fi
}
\gdef\Hy@RemoveTransPageAttr#1^^J/Trans#2#3>>#4\END{%
  \ifx\\#2\\%
    \global\pdfpageattr{#1}%
  \else
    \Hy@RemoveTransPageAttr#1#4\END
  \fi
}
\def\hyper@pageduration{%
  \ifx\@pdfpageduration\relax
  \else
    \expandafter\Hy@RemoveDurPageAttr\the\pdfpageattr^^J/Dur{} \END
    \ifx\@pdfpageduration\@empty
    \else
      \edef\@processme{%
        \global\pdfpageattr{%
          \the\pdfpageattr
          ^^J/Dur \@pdfpageduration\space
        }%
      }%
      \@processme
    \fi
  \fi
}
\gdef\Hy@RemoveDurPageAttr#1^^J/Dur#2#3 #4\END{%
  \ifx\\#2\\%
    \global\pdfpageattr{#1}%
  \else
    \Hy@RemoveDurPageAttr#1#4\END
  \fi
}
\def\hyper@pagehidden{%
  \ifHy@useHidKey
    \expandafter\Hy@RemoveHidPageAttr\the\pdfpageattr^^J/Hid{} \END
    \ifHy@pdfpagehidden
      \edef\@processme{%
        \global\pdfpageattr{%
          \the\pdfpageattr
          ^^J/Hid true % SPACE
        }%
      }%
      \@processme
    \fi
  \fi
}
\gdef\Hy@RemoveHidPageAttr#1^^J/Hid#2#3 #4\END{%
  \ifx\\#2\\%
    \global\pdfpageattr{#1}%
  \else
    \Hy@RemoveHidPageAttr#1#4\END
  \fi
}
\pdfoutput=1
\pdfcompresslevel=9
\AtBeginDocument{%
  \ifHy@setpagesize
    \expandafter\@firstofone
  \else
    \expandafter\@gobble
  \fi
  {%
    \@ifclassloaded{seminar}{%
      \setlength{\pdfhorigin}{1truein}%
      \setlength{\pdfvorigin}{1truein}%
      \ifportrait
        \ifdim\paperwidth=\z@
        \else
          \setlength{\pdfpagewidth}{\strip@pt\paperwidth truept}%
        \fi
        \ifdim\paperheight=\z@
        \else
          \setlength{\pdfpageheight}{\strip@pt\paperheight truept}%
        \fi
      \else
        \ifdim\paperheight=\z@
        \else
          \setlength{\pdfpagewidth}{\strip@pt\paperheight truept}%
        \fi
        \ifdim\paperwidth=\z@
        \else
          \setlength{\pdfpageheight}{\strip@pt\paperwidth truept}%
        \fi
      \fi
    }{%
      \@ifundefined{stockwidth}{%
        \ifdim\paperwidth=\z@
        \else
          \setlength{\pdfpagewidth}{\paperwidth}%
        \fi
        \ifdim\paperheight=\z@
        \else
          \setlength{\pdfpageheight}{\paperheight}%
        \fi
      }{%
        \ifdim\stockwidth=\z@
        \else
          \setlength{\pdfpagewidth}{\stockwidth}%
        \fi
        \ifdim\stockheight=\z@
        \else
          \setlength{\pdfpageheight}{\stockheight}%
        \fi
      }%
    }%
  }%
  \Hy@DisableOption{setpagesize}%
}
\def\Acrobatmenu#1#2{%
  \leavevmode
  \pdfstartlink
    attr{%
      /Border [\@pdfborder]
      /H \@pdfhighlight\space
      /C [\@menubordercolor]%
    }%
    user{
      /Subtype /Link
      /A <<
        /S /Named /N /#1
      >>
    }%
  \Hy@colorlink{\@menucolor}#2\close@pdflink
}
\def\@Gauge[#1]#2#3#4{% parameters, label, minimum, maximum
  \typeout{Sorry, pdftex does not support FORM gauges}%
}
\RequirePackage{pifont}%
\def\MakeFieldObject#1#2{\sbox0{#1}%
  \immediate\pdfxform0 %
  \expandafter\edef\csname #2Object\endcsname{%
    \the\pdflastxform\space 0 R%
  }%
}%
\def\@Form[#1]{%
  \@ifundefined{textcolor}{\let\textcolor\@gobble}{}%
  \setkeys{Form}{#1}%
  \ifnum\pdftexversion>13
    \pdfrefobj\OBJ@pdfdocencoding
    \pdfrefobj\OBJ@ZaDb
    \pdfrefobj\OBJ@Helv
    \pdfrefobj\OBJ@acroform
  \fi
  \pdfcatalog{/AcroForm \OBJ@acroform\space 0 R}%
  \MakeFieldObject{\ding{123}}{Ding}%
  \MakeFieldObject{\fbox{\textcolor{yellow}{\textsf{Submit}}}}{Submit}%
  \MakeFieldObject{\fbox{\textcolor{yellow}{\textsf{SubmitP}}}}{SubmitP}%
}
\def\@endForm{}
\def\@TextField[#1]#2{% parameters, label
  \def\Fld@name{#2}%
  \def\Fld@default{}%
  \let\Fld@value\@empty
  \def\Fld@width{\DefaultWidthofText}%
  \def\Fld@height{\DefaultHeightofText}%
  \ifFld@multiline
    \begingroup
      \dimen@=\DefaultHeightofText
      \dimen@=4\dimen@
      \edef\x{\endgroup
        \def\noexpand\Fld@height{\the\dimen@}%
      }%
    \x
  \fi
  \bgroup
    \Field@toks={ }%
    \setkeys{Field}{#1}%
    \ifFld@hidden\def\Fld@width{1sp}\fi
    \ifx\Fld@value\@empty\def\Fld@value{\Fld@default}\fi
    \LayoutTextField{#2}{%
    \pdfstartlink user {\PDFForm@Text}%
    \MakeTextField{\Fld@width}{\Fld@height}\pdfendlink}%
  \egroup
}
\def\@ChoiceMenu[#1]#2#3{% parameters, label, choices
  \def\Fld@name{#2}%
  \def\Fld@default{}%
  \def\Fld@width{\DefaultWidthofChoiceMenu}%
  \def\Fld@height{\DefaultHeightofChoiceMenu}%
  \bgroup
    \Fld@menulength=0
    \@tempdima\z@
    \@for\@curropt:=#3\do{%
      \expandafter\Fld@checkequals\@curropt==\\%
      \Hy@StepCount\Fld@menulength
      \settowidth{\@tempdimb}{\@currDisplay}%
      \ifdim\@tempdimb>\@tempdima\@tempdima\@tempdimb\fi
    }%
    \advance\@tempdima by 15\p@
    \Field@toks={ }%
    \setkeys{Field}{#1}%
    \ifFld@hidden\def\Fld@width{1sp}\fi
    \LayoutChoiceField{#2}{%
      \ifFld@radio
        \@@Radio{#3}%
      \else
        {%
          \ifdim\Fld@width<\@tempdima
            \ifdim\@tempdima<1cm\@tempdima1cm\fi
            \edef\Fld@width{\the\@tempdima}%
          \fi
          \def\Fld@flags{}%
          \ifFld@combo\def\Fld@flags{/Ff 917504}\fi
          \ifFld@popdown\def\Fld@flags{/Ff 131072}\fi
          \ifx\Fld@flags\@empty
            \@tempdima=\the\Fld@menulength\Fld@charsize
            \advance\@tempdima by \Fld@borderwidth bp
            \advance\@tempdima by \Fld@borderwidth bp
            \edef\Fld@height{\the\@tempdima}%
          \fi
          \@@Listbox{#3}%
        }%
      \fi
    }%
  \egroup
}
\def\@@Radio#1{%
  \Fld@listcount=0
  \@for\@curropt:=#1\do{%
    \expandafter\Fld@checkequals\@curropt==\\%
    \Hy@StepCount\Fld@listcount
    \@currDisplay\space
    \leavevmode
    \pdfstartlink user {%
      \PDFForm@Radio
      /AP <<
        /N <<
          /\@currValue\space \DingObject
        >>
      >>
    }%
    \MakeRadioField{\Fld@width}{\Fld@height}\pdfendlink
    \space% deliberate space between radio buttons
  }%
}
\newcount\Fld@listcount
\def\@@Listbox#1{%
  \Choice@toks={ }%
  \Fld@listcount=0
  \@for\@curropt:=#1\do{%
    \expandafter\Fld@checkequals\@curropt==\\%
    \Hy@StepCount\Fld@listcount
    \edef\@processme{%
      \Choice@toks{\the\Choice@toks [(\@currValue) (\@currDisplay)]}%
    }\@processme
  }%
  \leavevmode
  \pdfstartlink user {\PDFForm@List}%
  \MakeChoiceField{\Fld@width}{\Fld@height}%
  \pdfendlink
}
\def\@PushButton[#1]#2{% parameters, label
  \def\Fld@name{#2}%
  \bgroup
    \Field@toks={ }%
    \setkeys{Field}{#1}%
    \ifFld@hidden\def\Fld@width{1sp}\fi
    \LayoutPushButtonField{%
      \leavevmode
      \pdfstartlink user {\PDFForm@Push}%
      \MakeButtonField{#2}%
      \pdfendlink
    }%
  \egroup
}
\def\@Submit[#1]#2{%
  \Field@toks={ }%
  \def\Fld@width{\DefaultWidthofSubmit}%
  \def\Fld@height{\DefaultHeightofSubmit}%
  \bgroup
    \def\Fld@name{Submit}%
    \setkeys{Field}{#1}%
    \ifFld@hidden\def\Fld@width{1sp}\fi
    \leavevmode
    \pdfstartlink user {%
      \PDFForm@Submit
      /AP << /N \SubmitObject\space /D \SubmitPObject >>
    }%
    \MakeButtonField{#2}%
    \pdfendlink
  \egroup
}
\def\@Reset[#1]#2{%
  \Field@toks={ }%
  \def\Fld@width{\DefaultWidthofReset}%
  \def\Fld@height{\DefaultHeightofReset}%
  \bgroup
    \def\Fld@name{Reset}%
    \setkeys{Field}{#1}%
    \ifFld@hidden\def\Fld@width{1sp}\fi
    \leavevmode
    \pdfstartlink user {\PDFForm@Reset}%
    \MakeButtonField{#2}%
    \pdfendlink
  \egroup
}
\def\@CheckBox[#1]#2{% parameters, label
  \def\Fld@name{#2}%
  \def\Fld@default{0}%
  \bgroup
    \def\Fld@width{\DefaultWidthofCheckBox}%
    \def\Fld@height{\DefaultHeightofCheckBox}%
    \Field@toks={ }%
    \setkeys{Field}{#1}%
    \ifFld@hidden\def\Fld@width{1sp}\fi
    \LayoutCheckField{#2}{%
      \pdfstartlink user {\PDFForm@Check}%
      \MakeCheckField{\Fld@width}{\Fld@height}%
      \pdfendlink
    }%
  \egroup
}
\pdfobj { << /Type /Encoding /Differences [ 24 /breve /caron
/circumflex /dotaccent /hungarumlaut /ogonek /ring /tilde 39
/quotesingle 96 /grave 128 /bullet /dagger /daggerdbl /ellipsis
/emdash /endash /florin /fraction /guilsinglleft /guilsinglright
/minus /perthousand /quotedblbase /quotedblleft /quotedblright
/quoteleft /quoteright /quotesinglbase /trademark /fi /fl /Lslash /OE
/Scaron /Ydieresis /Zcaron /dotlessi /lslash /oe /scaron /zcaron 164
/currency 166 /brokenbar 168 /dieresis /copyright /ordfeminine 172
/logicalnot /.notdef /registered /macron /degree /plusminus
/twosuperior /threesuperior /acute /mu 183 /periodcentered /cedilla
/onesuperior /ordmasculine 188 /onequarter /onehalf /threequarters 192
/Agrave /Aacute /Acircumflex /Atilde /Adieresis /Aring /AE /Ccedilla
/Egrave /Eacute /Ecircumflex /Edieresis /Igrave /Iacute /Icircumflex
/Idieresis /Eth /Ntilde /Ograve /Oacute /Ocircumflex /Otilde
/Odieresis /multiply /Oslash /Ugrave /Uacute /Ucircumflex /Udieresis
/Yacute /Thorn /germandbls /agrave /aacute /acircumflex /atilde
/adieresis /aring /ae /ccedilla /egrave /eacute /ecircumflex
/edieresis /igrave /iacute /icircumflex /idieresis /eth /ntilde
/ograve /oacute /ocircumflex /otilde /odieresis /divide /oslash
/ugrave /uacute /ucircumflex /udieresis /yacute /thorn /ydieresis ] >>
}
\edef\OBJ@pdfdocencoding{\the\pdflastobj}
\pdfobj {
  <<
   /Type /Font
   /Subtype /Type1
   /Name /ZaDb
   /BaseFont /ZapfDingbats
>>
}
\edef\OBJ@ZaDb{\the\pdflastobj}
\pdfobj {  <<
  /Type /Font
  /Subtype /Type1
  /Name /Helv
  /BaseFont /Helvetica
  /Encoding \OBJ@pdfdocencoding\space 0 R
  >>
}
\edef\OBJ@Helv{\the\pdflastobj}
\pdfobj {
  <<
    /Fields []
    /DR <<
      /Font << /ZaDb \OBJ@ZaDb\space 0 R /Helv \OBJ@Helv\space0 R >>
    >>
    /DA (/Helv 10 Tf 0 g )
    /NeedAppearances true
  >>
}
\edef\OBJ@acroform{\the\pdflastobj}
\def\PDFForm@Check{%
  /Subtype /Widget
  \ifFld@hidden /F 6 \else /F 4 \fi
  /T (\Fld@name)
  /Q \Fld@align\space
  /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
  /MK <<
    /BC [\Fld@bordercolor]
    \ifx\Fld@bcolor\@empty
    \else
      /BG [\Fld@bcolor]
    \fi
    /CA (\Fld@cbsymbol)
  >>
  /DA (/ZaDb \strip@pt\Fld@charsize\space Tf \Fld@color\space rg)
  /FT /Btn
  /H /P
  \ifFld@checked /V /Yes \else /V /Off \fi
}
\def\PDFForm@Push{%
  /Subtype /Widget
  \ifFld@hidden /F 6 \else /F 4 \fi
  /T (\Fld@name)
  /FT /Btn
  /Ff 65540
  /H /P
  /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
  /MK <<
    /BC [\Fld@bordercolor]
  >>
  /A << /S /JavaScript /JS (\Fld@onclick;) >>
}
\def\Fld@additionalactions{%
  /AA <<
    \ifx\Fld@keystroke@code\@empty
    \else
      /K << /S /JavaScript /JS (\Fld@keystroke@code) >>
    \fi
    \ifx\Fld@format@code\@empty
    \else
      /F << /S /JavaScript /JS (\Fld@format@code) >>
    \fi
    \ifx\Fld@validate@code\@empty
    \else
      /V << /S /JavaScript /JS (\Fld@validate@code) >>
    \fi
    \ifx\Fld@calculate@code\@empty
    \else
      /C << /S /JavaScript /JS (\Fld@calculate@code) >>
    \fi
    \ifx\Fld@onfocus@code\@empty
    \else
      /Fo << /S /JavaScript /JS (\Fld@onfocus@code) >>
    \fi
    \ifx\Fld@onblur@code\@empty
    \else
      /Bl << /S /JavaScript /JS (\Fld@onblur@code) >>
    \fi
    \ifx\Fld@onmousedown@code\@empty
    \else
      /D << /S /JavaScript /JS (\Fld@onmousedown@code) >>
    \fi
    \ifx\Fld@onmouseup@code\@empty
    \else
      /U << /S /JavaScript /JS (\Fld@onmouseup@code) >>
    \fi
    \ifx\Fld@onenter@code\@empty
    \else
      /E << /S /JavaScript /JS (\Fld@onenter@code) >>
    \fi
    \ifx\Fld@onexit@code\@empty
    \else
      /X << /S /JavaScript /JS (\Fld@onexit@code) >>
    \fi
  >>
}
\def\PDFForm@List{%
  /Subtype /Widget
  \ifFld@hidden /F 6 \else /F 4 \fi
  /T (\Fld@name)
  /FT /Ch
  /Q \Fld@align\space
  /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
  /MK <<
    /BC [\Fld@bordercolor]
    \ifx\Fld@bcolor\@empty
    \else
      /BG [\Fld@bcolor]
    \fi
  >>
  /DA (/Helv \strip@pt\Fld@charsize\space Tf \Fld@color\space rg )
  /Opt [\the\Choice@toks]
  /DV (\Fld@default)
  \Fld@additionalactions
  \Fld@flags
}
\def\PDFForm@Radio{%
  /Subtype /Widget
  \ifFld@hidden /F 6 \else /F 4 \fi
  /T (\Fld@name)
  /FT /Btn
  /Ff 49152
  /H /P
  /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
  /MK <<
    /BC [\Fld@bordercolor]
    \ifx\Fld@bcolor\@empty
    \else
      /BG [\Fld@bcolor]
    \fi
    /CA (H)
  >>
  /DA (/ZaDb \strip@pt\Fld@charsize\space Tf \Fld@color\space rg)
  \ifx\@currValue\Fld@default
    /V /\Fld@default\space
  \else
    /V /Off
  \fi
  \Fld@additionalactions
}
\def\PDFForm@Text{%
  /Subtype /Widget
  \ifFld@hidden /F 6 \else /F 4 \fi
  /T (\Fld@name)
  /Q \Fld@align\space
  /FT /Tx
  /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
  /MK <<
    /BC [\Fld@bordercolor]
    \ifx\Fld@bcolor\@empty
    \else
      /BG [\Fld@bcolor]
    \fi
  >>
  /DA (/Helv \strip@pt\Fld@charsize\space Tf \Fld@color\space rg )
  /DV (\Fld@default)
  /V (\Fld@value)
  \Fld@additionalactions
  \ifFld@multiline
    \ifFld@readonly /Ff 4097 \else /Ff 4096 \fi
  \else
    \ifFld@password
      \ifFld@readonly /Ff 8193 \else /Ff 8192 \fi
    \else
      \ifFld@readonly /Ff 1 \fi
    \fi
  \fi
  \ifnum\Fld@maxlen>0/MaxLen \Fld@maxlen \fi
}
\def\PDFForm@Submit{%
  /Subtype /Widget
  \ifFld@hidden /F 6 \else /F 4 \fi
  /T (\Fld@name)
  /FT /Btn
  /Ff 65540
  /H /P
  /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
  /MK <<
    /BC [\Fld@bordercolor]
  >>
  /A <<
    /S /SubmitForm
    /F <<
      /FS /URL
      /F (\Form@action)
    >>
    \ifForm@html /Flags 4 \fi
  >>
}
\def\PDFForm@Reset{%
  /Subtype /Widget
  \ifFld@hidden /F 6 \else /F 4 \fi
  /T (\Fld@name)
  /FT /Btn
  /H /P
  /DA (/Helv \strip@pt\Fld@charsize\space Tf 0 0 1 rg)
  /Ff 65540
  /MK <<
    /BC [\Fld@bordercolor]
  >>
  /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
  /A << /S /ResetForm >>
}
\newwrite\@outlinefile
\def\Hy@writebookmark#1#2#3#4#5{% section number, text, label, level, file
 \ifx\WriteBookmarks\relax%
 \else
  \ifnum#4>\c@tocdepth
  \else
   \@@writetorep{#1}{#2}{#3}{#4}{#5}%
  \fi
 \fi}
\def\Hy@currentbookmarklevel{0}
\def\Hy@numberline#1{#1 }
\def\@@writetorep#1#2#3#4#5{%
  \begingroup
    \edef\Hy@tempa{#5}%
    \ifx\Hy@tempa\Hy@bookmarkstype
      \edef\Hy@level{#4}%
      \ifx\Hy@levelcheck Y%
        \@tempcnta\Hy@level\relax
        \advance\@tempcnta by -1
        \ifnum\Hy@currentbookmarklevel<\@tempcnta
          \advance\@tempcnta by -\Hy@currentbookmarklevel\relax
          \advance\@tempcnta by 1
          \Hy@Warning{%
            Difference (\the\@tempcnta) between bookmark levels is %
            greater \MessageBreak than one, level fixed%
          }%
          \@tempcnta\Hy@currentbookmarklevel
          \advance\@tempcnta by 1
          \edef\Hy@level{\the\@tempcnta}%
        \fi
      \else
        \global\let\Hy@levelcheck Y%
      \fi
      \global\let\Hy@currentbookmarklevel\Hy@level
      \@tempcnta\Hy@level\relax
      \expandafter\xdef\csname Parent\Hy@level\endcsname{#3}%
      \advance\@tempcnta by -1
      \edef\Hy@tempa{#3}%
      \edef\Hy@tempb{\csname Parent\the\@tempcnta\endcsname}%
      \ifx\Hy@tempa\Hy@tempb
        \Hy@Warning{%
          The anchor of a bookmark and its parent's must not%
          \MessageBreak be the same. Added a new anchor%
        }%
        \phantomsection
      \fi
      \ifHy@bookmarksnumbered
        \let\numberline\Hy@numberline
      \else
        \let\numberline\@gobble
      \fi
      \pdfstringdef\Hy@tempa{#2}%
      \protected@write\@outlinefile{}{%
        \protect\BOOKMARK
          [\Hy@level][\@bookmarkopenstatus{\Hy@level}]{#3}%
          {\Hy@tempa}{\Hy@tempb}%
      }%
    \fi
  \endgroup
}
\newcommand{\currentpdfbookmark}{%
  \pdfbookmark[\Hy@currentbookmarklevel]%
}
\newcommand{\subpdfbookmark}{%
  \@tempcnta\Hy@currentbookmarklevel
  \Hy@StepCount\@tempcnta
  \expandafter\pdfbookmark\expandafter[\the\@tempcnta]%
}
\newcommand{\belowpdfbookmark}[2]{%
  \@tempcnta\Hy@currentbookmarklevel
  \Hy@StepCount\@tempcnta
  \expandafter\pdfbookmark\expandafter[\the\@tempcnta]{#1}{#2}%
  \advance\@tempcnta by -1
  \xdef\Hy@currentbookmarklevel{\the\@tempcnta}%
}
\renewcommand\pdfbookmark[3][0]{%
  \Hy@writebookmark{}{#2}{#3.#1}{#1}{toc}%
  \hyper@anchorstart{#3.#1}\hyper@anchorend
}
\def\BOOKMARK{\@ifnextchar[{\@BOOKMARK}{\@@BOOKMARK[1][-]}}
\def\@BOOKMARK[#1]{\@ifnextchar[{\@@BOOKMARK[#1]}{\@@BOOKMARK[#1][-]}}
\def\ReadBookmarks{%
  \begingroup
    \escapechar=`\\%
    \let\escapechar\@gobble %
    \def\@@BOOKMARK [##1][##2]##3##4##5{\calc@bm@number{##5}}%
    \InputIfFileExists{\jobname.out}{}{}%
    \ifx\WriteBookmarks\relax
      \global\let\WriteBookmarks\relax
    \fi
    \def\@@BOOKMARK[##1][##2]##3##4##5{%
      \def\Hy@temp{##4}%
      \pdfoutline goto
        name{##3}%
        count ##2\check@bm@number{##3}{%
          \expandafter\strip@prefix\meaning\Hy@temp
        }%
   }%
   {%
    \def\WriteBookmarks{0}%
    \InputIfFileExists{\jobname.out}{}{}%
   }%
   %{\escapechar\m@ne\InputIfFileExists{\jobname.out}{}{}}%
   \ifx\WriteBookmarks\relax\else
     \if@filesw\immediate\openout\@outlinefile=\jobname.out
      \ifHy@typexml
       \immediate\write\@outlinefile{<relaxxml>\relax}%
      \fi
     \fi
   \fi
   \endgroup
}
\def\check@bm@number#1{%
  \expandafter\ifx\csname B_#1\endcsname\relax
    0%
  \else
    \csname B_#1\endcsname
  \fi
}
\def\calc@bm@number#1{%
  \@tempcnta=\check@bm@number{#1}\relax
  \advance\@tempcnta by1
  \expandafter\xdef\csname B_#1\endcsname{\the\@tempcnta}%
}
\ifHy@implicit
\else
  \def\@begindvi{%
    \unvbox\@begindvibox
    \HyPL@EveryPage
    \global\let\@begindvi\HyPL@EveryPage
  }%
  \expandafter\endinput
\fi
\let\H@old@ssect\@ssect
\def\@ssect#1#2#3#4#5{%
  \H@old@ssect{#1}{#2}{#3}{#4}{#5}%
  \phantomsection
}
\let\H@old@schapter\@schapter
\def\@schapter#1{%
  \H@old@schapter{#1}%
  \begingroup
    \let\@mkboth\@gobbletwo
    \Hy@GlobalStepCount\Hy@linkcounter
    \xdef\@currentHref{\Hy@chapapp*.\the\Hy@linkcounter}%
    \Hy@raisedlink{\hyper@anchorstart{\@currentHref}\hyper@anchorend}%
  \endgroup
}
\@ifundefined{@chapter}{}{%
  \let\Hy@org@chapter\@chapter
  \def\@chapter{%
    \def\Hy@next{%
      \Hy@GlobalStepCount\Hy@linkcounter
      \xdef\@currentHref{\Hy@chapapp*.\the\Hy@linkcounter}%
      \Hy@raisedlink{\hyper@anchorstart{\@currentHref}\hyper@anchorend}%
    }%
    \ifnum\c@secnumdepth>\m@ne
      \@ifundefined{if@mainmatter}%
      \iftrue{\csname if@mainmatter\endcsname}
        \let\Hy@next\relax
      \fi
    \fi
    \Hy@next
    \Hy@org@chapter
  }%
}
\let\H@old@spart\@spart
\def\@spart#1{%
  \H@old@spart{#1}%
  \Hy@GlobalStepCount\Hy@linkcounter
  \xdef\@currentHref{part*.\the\Hy@linkcounter}%
  \Hy@raisedlink{\hyper@anchorstart{\@currentHref}\hyper@anchorend}%
}
\let\H@old@sect\@sect
\def\@sect#1#2#3#4#5#6[#7]#8{%
  \ifnum #2>\c@secnumdepth
    \Hy@GlobalStepCount\Hy@linkcounter
    \xdef\@currentHref{section*.\the\Hy@linkcounter}%
  \fi
  \H@old@sect{#1}{#2}{#3}{#4}{#5}{#6}[{#7}]{#8}%
  \ifnum #2>\c@secnumdepth
    \Hy@raisedlink{\hyper@anchorstart{\@currentHref}\hyper@anchorend}%
  \fi
}
\expandafter\def\csname Parent-4\endcsname{}
\expandafter\def\csname Parent-3\endcsname{}
\expandafter\def\csname Parent-2\endcsname{}
\expandafter\def\csname Parent-1\endcsname{}
\expandafter\def\csname Parent0\endcsname{}
\expandafter\def\csname Parent1\endcsname{}
\expandafter\def\csname Parent2\endcsname{}
\expandafter\def\csname Parent3\endcsname{}
\expandafter\def\csname Parent4\endcsname{}
\def\Hy@tempa{%
  \def\@addchap[##1]##2{%
    \typeout{##2}%
    \if@twoside
      \@mkboth{##1}{}%
    \else
      \@mkboth{}{##1}%
    \fi
    \addtocontents{lof}{\protect\addvspace{10\p@}}%
    \addtocontents{lot}{\protect\addvspace{10\p@}}%
    \Hy@GlobalStepCount\Hy@linkcounter
    \xdef\@currentHref{\Hy@chapapp*.\the\Hy@linkcounter}%
    \Hy@raisedlink{\hyper@anchorstart{\@currentHref}\hyper@anchorend}%
    \if@twocolumn
       \@topnewpage[\@makeschapterhead{##2}]%
    \else
       \@makeschapterhead{##2}%
       \@afterheading
    \fi
    \addcontentsline{toc}{chapter}{##1}%
  }%
}
\@ifclassloaded{scrbook}{%
  \@ifclasslater{scrbook}{2001/01/01}{%
    \let\Hy@tempa\@empty
  }{}%
}{%
  \@ifclassloaded{scrreprt}{%
    \@ifclasslater{scrreprt}{2001/01/01}{%
      \let\Hy@tempa\@empty
    }{}%
  }{%
    \let\Hy@tempa\@empty
  }%
}%
\Hy@tempa
\endinput
%%
%% End of file `hpdftex.def'.
