% Copyright 2000 Vladimir Volovich <vvv@vsu.ru>
\ProvidesFile{utfcyr.def}[2000/08/19 v0.1 cyrillic definitions for utf-8]

\UnicodeCharacter{x0300}{\`}
\UnicodeCharacter{x0301}{\'}
\UnicodeCharacter{x0302}{\^}
\UnicodeCharacter{x0303}{\~}
\UnicodeCharacter{x0304}{\=}
\UnicodeCharacter{x0306}{\u}
\UnicodeCharacter{x0307}{\.}
\UnicodeCharacter{x0308}{\"}
\UnicodeCharacter{x030A}{\r}
\UnicodeCharacter{x030B}{\H}
\UnicodeCharacter{x030C}{\v}
\UnicodeCharacter{x030F}{\C}
\UnicodeCharacter{x0311}{\f}
\UnicodeCharacter{x0323}{\d}
\UnicodeCharacter{x0327}{\c}
\UnicodeCharacter{x0328}{\k}
\UnicodeCharacter{x0331}{\b}
\UnicodeCharacter{x0400}{\`\CYRE}
\UnicodeCharacter{x0401}{\CYRYO}
\UnicodeCharacter{x0402}{\CYRDJE}
\UnicodeCharacter{x0403}{\'\CYRG}
\UnicodeCharacter{x0404}{\CYRIE}
\UnicodeCharacter{x0405}{\CYRDZE}
\UnicodeCharacter{x0406}{\CYRII}
\UnicodeCharacter{x0407}{\CYRYI}
\UnicodeCharacter{x0408}{\CYRJE}
\UnicodeCharacter{x0409}{\CYRLJE}
\UnicodeCharacter{x040A}{\CYRNJE}
\UnicodeCharacter{x040B}{\CYRTSHE}
\UnicodeCharacter{x040C}{\'\CYRK}
\UnicodeCharacter{x040D}{\`\CYRI}
\UnicodeCharacter{x040E}{\CYRUSHRT}
\UnicodeCharacter{x040F}{\CYRDZHE}
\UnicodeCharacter{x0410}{\CYRA}
\UnicodeCharacter{x0411}{\CYRB}
\UnicodeCharacter{x0412}{\CYRV}
\UnicodeCharacter{x0413}{\CYRG}
\UnicodeCharacter{x0414}{\CYRD}
\UnicodeCharacter{x0415}{\CYRE}
\UnicodeCharacter{x0416}{\CYRZH}
\UnicodeCharacter{x0417}{\CYRZ}
\UnicodeCharacter{x0418}{\CYRI}
\UnicodeCharacter{x0419}{\CYRISHRT}
\UnicodeCharacter{x041A}{\CYRK}
\UnicodeCharacter{x041B}{\CYRL}
\UnicodeCharacter{x041C}{\CYRM}
\UnicodeCharacter{x041D}{\CYRN}
\UnicodeCharacter{x041E}{\CYRO}
\UnicodeCharacter{x041F}{\CYRP}
\UnicodeCharacter{x0420}{\CYRR}
\UnicodeCharacter{x0421}{\CYRS}
\UnicodeCharacter{x0422}{\CYRT}
\UnicodeCharacter{x0423}{\CYRU}
\UnicodeCharacter{x0424}{\CYRF}
\UnicodeCharacter{x0425}{\CYRH}
\UnicodeCharacter{x0426}{\CYRC}
\UnicodeCharacter{x0427}{\CYRCH}
\UnicodeCharacter{x0428}{\CYRSH}
\UnicodeCharacter{x0429}{\CYRSHCH}
\UnicodeCharacter{x042A}{\CYRHRDSN}
\UnicodeCharacter{x042B}{\CYRERY}
\UnicodeCharacter{x042C}{\CYRSFTSN}
\UnicodeCharacter{x042D}{\CYREREV}
\UnicodeCharacter{x042E}{\CYRYU}
\UnicodeCharacter{x042F}{\CYRYA}
\UnicodeCharacter{x0430}{\cyra}
\UnicodeCharacter{x0431}{\cyrb}
\UnicodeCharacter{x0432}{\cyrv}
\UnicodeCharacter{x0433}{\cyrg}
\UnicodeCharacter{x0434}{\cyrd}
\UnicodeCharacter{x0435}{\cyre}
\UnicodeCharacter{x0436}{\cyrzh}
\UnicodeCharacter{x0437}{\cyrz}
\UnicodeCharacter{x0438}{\cyri}
\UnicodeCharacter{x0439}{\cyrishrt}
\UnicodeCharacter{x043A}{\cyrk}
\UnicodeCharacter{x043B}{\cyrl}
\UnicodeCharacter{x043C}{\cyrm}
\UnicodeCharacter{x043D}{\cyrn}
\UnicodeCharacter{x043E}{\cyro}
\UnicodeCharacter{x043F}{\cyrp}
\UnicodeCharacter{x0440}{\cyrr}
\UnicodeCharacter{x0441}{\cyrs}
\UnicodeCharacter{x0442}{\cyrt}
\UnicodeCharacter{x0443}{\cyru}
\UnicodeCharacter{x0444}{\cyrf}
\UnicodeCharacter{x0445}{\cyrh}
\UnicodeCharacter{x0446}{\cyrc}
\UnicodeCharacter{x0447}{\cyrch}
\UnicodeCharacter{x0448}{\cyrsh}
\UnicodeCharacter{x0449}{\cyrshch}
\UnicodeCharacter{x044A}{\cyrhrdsn}
\UnicodeCharacter{x044B}{\cyrery}
\UnicodeCharacter{x044C}{\cyrsftsn}
\UnicodeCharacter{x044D}{\cyrerev}
\UnicodeCharacter{x044E}{\cyryu}
\UnicodeCharacter{x044F}{\cyrya}
\UnicodeCharacter{x0450}{\`\cyre}
\UnicodeCharacter{x0451}{\cyryo}
\UnicodeCharacter{x0452}{\cyrdje}
\UnicodeCharacter{x0453}{\'\cyrg}
\UnicodeCharacter{x0454}{\cyrie}
\UnicodeCharacter{x0455}{\cyrdze}
\UnicodeCharacter{x0456}{\cyrii}
\UnicodeCharacter{x0457}{\cyryi}
\UnicodeCharacter{x0458}{\cyrje}
\UnicodeCharacter{x0459}{\cyrlje}
\UnicodeCharacter{x045A}{\cyrnje}
\UnicodeCharacter{x045B}{\cyrtshe}
\UnicodeCharacter{x045C}{\'\cyrk}
\UnicodeCharacter{x045D}{\`\cyri}
\UnicodeCharacter{x045E}{\cyrushrt}
\UnicodeCharacter{x045F}{\cyrdzhe}
\UnicodeCharacter{x0460}{\CYROMEGA}
\UnicodeCharacter{x0461}{\cyromega}
\UnicodeCharacter{x0462}{\CYRYAT}
\UnicodeCharacter{x0463}{\cyryat}
\UnicodeCharacter{x0464}{\CYRIOTE}
\UnicodeCharacter{x0465}{\cyriote}
\UnicodeCharacter{x0466}{\CYRLYUS}
\UnicodeCharacter{x0467}{\cyrlyus}
\UnicodeCharacter{x0468}{\CYRIOTLYUS}
\UnicodeCharacter{x0469}{\cyriotlyus}
\UnicodeCharacter{x046A}{\CYRBYUS}
\UnicodeCharacter{x046B}{\cyrbyus}
\UnicodeCharacter{x046C}{\CYRIOTBYUS}
\UnicodeCharacter{x046D}{\cyriotbyus}
\UnicodeCharacter{x046E}{\CYRKSI}
\UnicodeCharacter{x046F}{\cyrksi}
\UnicodeCharacter{x0470}{\CYRPSI}
\UnicodeCharacter{x0471}{\cyrpsi}
\UnicodeCharacter{x0472}{\CYRFITA}
\UnicodeCharacter{x0473}{\cyrfita}
\UnicodeCharacter{x0474}{\CYRIZH}
\UnicodeCharacter{x0475}{\cyrizh}
\UnicodeCharacter{x0476}{\C\CYRIZH}
\UnicodeCharacter{x0477}{\C\cyrizh}
\UnicodeCharacter{x0478}{\CYRUK}
\UnicodeCharacter{x0479}{\cyruk}
\UnicodeCharacter{x047A}{\CYROMEGARND}
\UnicodeCharacter{x047B}{\cyromegarnd}
\UnicodeCharacter{x047C}{\CYROMEGATITLO}
\UnicodeCharacter{x047D}{\cyromegatitlo}
\UnicodeCharacter{x047E}{\CYROT}
\UnicodeCharacter{x047F}{\cyrot}
\UnicodeCharacter{x0480}{\CYRKOPPA}
\UnicodeCharacter{x0481}{\cyrkoppa}
\UnicodeCharacter{x0482}{\cyrthousands}
\UnicodeCharacter{x0488}{\cyrhundredthousands}
\UnicodeCharacter{x0489}{\cyrmillions}
\UnicodeCharacter{x048C}{\CYRSEMISFTSN}
\UnicodeCharacter{x048D}{\cyrsemisftsn}
\UnicodeCharacter{x048E}{\CYRRTICK}
\UnicodeCharacter{x048F}{\cyrrtick}
\UnicodeCharacter{x0490}{\CYRGUP}
\UnicodeCharacter{x0491}{\cyrgup}
\UnicodeCharacter{x0492}{\CYRGHCRS}
\UnicodeCharacter{x0493}{\cyrghcrs}
\UnicodeCharacter{x0494}{\CYRGHK}
\UnicodeCharacter{x0495}{\cyrghk}
\UnicodeCharacter{x0496}{\CYRZHDSC}
\UnicodeCharacter{x0497}{\cyrzhdsc}
\UnicodeCharacter{x0498}{\CYRZDSC}
\UnicodeCharacter{x0499}{\cyrzdsc}
\UnicodeCharacter{x049A}{\CYRKDSC}
\UnicodeCharacter{x049B}{\cyrkdsc}
\UnicodeCharacter{x049C}{\CYRKVCRS}
\UnicodeCharacter{x049D}{\cyrkvcrs}
\UnicodeCharacter{x049E}{\CYRKHCRS}
\UnicodeCharacter{x049F}{\cyrkhcrs}
\UnicodeCharacter{x04A0}{\CYRKBEAK}
\UnicodeCharacter{x04A1}{\cyrkbeak}
\UnicodeCharacter{x04A2}{\CYRNDSC}
\UnicodeCharacter{x04A3}{\cyrndsc}
\UnicodeCharacter{x04A4}{\CYRNG}
\UnicodeCharacter{x04A5}{\cyrng}
\UnicodeCharacter{x04A6}{\CYRPHK}
\UnicodeCharacter{x04A7}{\cyrphk}
\UnicodeCharacter{x04A8}{\CYRABHHA}
\UnicodeCharacter{x04A9}{\cyrabhha}
\UnicodeCharacter{x04AA}{\CYRSDSC}
\UnicodeCharacter{x04AB}{\cyrsdsc}
\UnicodeCharacter{x04AC}{\CYRTDSC}
\UnicodeCharacter{x04AD}{\cyrtdsc}
\UnicodeCharacter{x04AE}{\CYRY}
\UnicodeCharacter{x04AF}{\cyry}
\UnicodeCharacter{x04B0}{\CYRYHCRS}
\UnicodeCharacter{x04B1}{\cyryhcrs}
\UnicodeCharacter{x04B2}{\CYRHDSC}
\UnicodeCharacter{x04B3}{\cyrhdsc}
\UnicodeCharacter{x04B4}{\CYRTETSE}
\UnicodeCharacter{x04B5}{\cyrtetse}
\UnicodeCharacter{x04B6}{\CYRCHRDSC}
\UnicodeCharacter{x04B7}{\cyrchrdsc}
\UnicodeCharacter{x04B8}{\CYRCHVCRS}
\UnicodeCharacter{x04B9}{\cyrchvcrs}
\UnicodeCharacter{x04BA}{\CYRSHHA}
\UnicodeCharacter{x04BB}{\cyrshha}
\UnicodeCharacter{x04BC}{\CYRABHCH}
\UnicodeCharacter{x04BD}{\cyrabhch}
\UnicodeCharacter{x04BE}{\CYRABHCHDSC}
\UnicodeCharacter{x04BF}{\cyrabhchdsc}
\UnicodeCharacter{x04C0}{\CYRpalochka}
\UnicodeCharacter{x04C1}{\U\CYRZH}
\UnicodeCharacter{x04C2}{\U\cyrzh}
\UnicodeCharacter{x04C3}{\CYRKHK}
\UnicodeCharacter{x04C4}{\cyrkhk}
\UnicodeCharacter{x04C7}{\CYRNHK}
\UnicodeCharacter{x04C8}{\cyrnhk}
\UnicodeCharacter{x04CB}{\CYRCHLDSC}
\UnicodeCharacter{x04CC}{\cyrchldsc}
\UnicodeCharacter{x04D0}{\U\CYRA}
\UnicodeCharacter{x04D1}{\U\cyra}
\UnicodeCharacter{x04D2}{\"\CYRA}
\UnicodeCharacter{x04D3}{\"\cyra}
\UnicodeCharacter{x04D4}{\CYRAE}
\UnicodeCharacter{x04D5}{\cyrae}
\UnicodeCharacter{x04D6}{\U\CYRE}
\UnicodeCharacter{x04D7}{\U\cyre}
\UnicodeCharacter{x04D8}{\CYRSCHWA}
\UnicodeCharacter{x04D9}{\cyrschwa}
\UnicodeCharacter{x04DA}{\"\CYRSCHWA}
\UnicodeCharacter{x04DB}{\"\cyrschwa}
\UnicodeCharacter{x04DC}{\"\CYRZH}
\UnicodeCharacter{x04DD}{\"\cyrzh}
\UnicodeCharacter{x04DE}{\"\CYRZ}
\UnicodeCharacter{x04DF}{\"\cyrz}
\UnicodeCharacter{x04E0}{\CYRABHDZE}
\UnicodeCharacter{x04E1}{\cyrabhdze}
\UnicodeCharacter{x04E2}{\=\CYRI}
\UnicodeCharacter{x04E3}{\=\cyri}
\UnicodeCharacter{x04E4}{\"\CYRI}
\UnicodeCharacter{x04E5}{\"\cyri}
\UnicodeCharacter{x04E6}{\"\CYRO}
\UnicodeCharacter{x04E7}{\"\cyro}
\UnicodeCharacter{x04E8}{\CYROTLD}
\UnicodeCharacter{x04E9}{\cyrotld}
\UnicodeCharacter{x04EA}{\"\CYROTLD}
\UnicodeCharacter{x04EB}{\"\cyrotld}
\UnicodeCharacter{x04EC}{\"\CYREREV}
\UnicodeCharacter{x04ED}{\"\cyrerev}
\UnicodeCharacter{x04EE}{\=\CYRU}
\UnicodeCharacter{x04EF}{\=\cyru}
\UnicodeCharacter{x04F0}{\"\CYRU}
\UnicodeCharacter{x04F1}{\"\cyru}
\UnicodeCharacter{x04F2}{\H\CYRU}
\UnicodeCharacter{x04F3}{\H\cyru}
\UnicodeCharacter{x04F4}{\"\CYRCH}
\UnicodeCharacter{x04F5}{\"\cyrch}
\UnicodeCharacter{x04F8}{\"\CYRERY}
\UnicodeCharacter{x04F9}{\"\cyrery}
%\UnicodeCharacter{x2116}{\textnumero}
%\UnicodeCharacter{x2329}{\cyrlangle}
%\UnicodeCharacter{x232A}{\cyrrangle}
%\UnicodeCharacter{xF6C4}{\cyrvarg}
%\UnicodeCharacter{xF6C5}{\cyrvarb}
%\UnicodeCharacter{xF6C6}{\cyrvard}
%\UnicodeCharacter{xF6C7}{\cyrvarp}
%\UnicodeCharacter{xF6C8}{\cyrvart}

\endinput
