%%
%% This is file `prlyx.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% preview.dtx  (with options: `lyx')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from prlyx.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file preview.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
%%\iffalse
%%     preview.dtx for extracting previews from LaTeX documents.  Part of
%%     the preview-latex package.
%%     Copyright (C) 2001, 2002, 2003 David Kastrup
%%
%%     This program is free software; you can redistribute it and/or modify
%%     it under the terms of the GNU General Public License as published by
%%     the Free Software Foundation; either version 2 of the License, or
%%     (at your option) any later version.
%%
%%     This program is distributed in the hope that it will be useful,
%%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%%     GNU General Public License for more details.
%%
%%     You should have received a copy of the GNU General Public License
%%     along with this program; if not, write to the
%%     Free Software Foundation, Inc., 59 Temple Place, Suite 330,
%%     Boston, MA 02111-1307  USA
%%\fi
\ifPreview\else\expandafter\endinput\fi
\pr@loadcfg{prlyx}
\g@addto@macro\pr@ship@end{\typeout{Preview:
  Snippet \number\pr@snippet\space
  \number\ht\pr@box\space \number\dp\pr@box \space\number\wd\pr@box}}
\endinput
%%
%% End of file `prlyx.def'.
