%%
%% This is file `pd1enc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `pd1enc')
%% 
%% File: hyperref.dtx Copyright 1995-2001 Sebastian Rahtz,
%% RCS: $Id: hyperref.dtx 6.71 2000/10/04 rahtz Exp rahtz $
%%
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%%
%% It may be distributed under the conditions of the LaTeX Project Public
%% License, either version 1.2 of this license or (at your option) any
%% later version.  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%%
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%%
\ProvidesFile{pd1enc.def}
  [2003/11/30 v6.74m
  Hyperref: PDFDocEncoding definition (HO)]
\DeclareFontEncoding{PD1}{}{}
\DeclareTextCommand{\textLF}{PD1}{\012} % line feed
\DeclareTextCommand{\textCR}{PD1}{\015} % carriage return
\DeclareTextCommand{\textHT}{PD1}{\011} % horizontal tab
\DeclareTextCommand{\textBS}{PD1}{\010} % backspace
\DeclareTextCommand{\textFF}{PD1}{\014} % formfeed
\DeclareTextAccent{\`}{PD1}{\textgrave}
\DeclareTextAccent{\'}{PD1}{\textacute}
\DeclareTextAccent{\^}{PD1}{\textcircumflex}
\DeclareTextAccent{\~}{PD1}{\texttilde}
\DeclareTextAccent{\"}{PD1}{\textdieresis}
\DeclareTextAccent{\r}{PD1}{\textring}
\DeclareTextAccent{\v}{PD1}{\textcaron}
\DeclareTextAccent{\.}{PD1}{\textdotaccent}
\DeclareTextAccent{\c}{PD1}{\textcedilla}
\DeclareTextCompositeCommand{\`}{PD1}{\@empty}{\textgrave}
\DeclareTextCompositeCommand{\'}{PD1}{\@empty}{\textacute}
\DeclareTextCompositeCommand{\^}{PD1}{\@empty}{\textcircumflex}
\DeclareTextCompositeCommand{\~}{PD1}{\@empty}{\texttilde}
\DeclareTextCompositeCommand{\"}{PD1}{\@empty}{\textdieresis}
\DeclareTextCompositeCommand{\r}{PD1}{\@empty}{\textring}
\DeclareTextCompositeCommand{\v}{PD1}{\@empty}{\textcaron}
\DeclareTextCompositeCommand{\.}{PD1}{\@empty}{\textdotaccent}
\DeclareTextCompositeCommand{\c}{PD1}{\@empty}{\textcedilla}
\DeclareTextCommand{\textbreve}{PD1}{\030} % breve
\DeclareTextCommand{\textcaron}{PD1}{\031} % caron
\DeclareTextCommand{\textcircumflex}{PD1}{\032} % circumflex
\DeclareTextCommand{\textdotaccent}{PD1}{\033} % dotaccent
\DeclareTextCommand{\texthungarumlaut}{PD1}{\034} % hungarumlaut
\DeclareTextCommand{\textogonek}{PD1}{\035} % ogonek
\DeclareTextCommand{\textring}{PD1}{\036} % ring
\DeclareTextCommand{\texttilde}{PD1}{\037} % tilde
\DeclareTextCommand{\textquotedbl}{PD1}{\string"} % quotedbl \042
\DeclareTextCommand{\textnumbersign}{PD1}{\043} % numbersign
\DeclareTextCommand{\textdollar}{PD1}{\044} % dollar
\DeclareTextCommand{\textpercent}{PD1}{\045} % percent
\DeclareTextCommand{\textampersand}{PD1}{\046} % ampersand
\DeclareTextCommand{\textparenleft}{PD1}{\string\(} % parenleft \050
\DeclareTextCommand{\textparenright}{PD1}{\string\)} % parenright \051
\DeclareTextCommand{\textless}{PD1}{<} % less \074
\DeclareTextCommand{\textgreater}{PD1}{>} % greater \076
\DeclareTextCommand{\textbackslash}{PD1}{\134} % backslash
\DeclareTextCommand{\textasciicircum}{PD1}{\136} % asciicircum
\DeclareTextCommand{\textunderscore}{PD1}{\137} % underscore
\DeclareTextCommand{\textgrave}{PD1}{\140} % grave
\DeclareTextCompositeCommand{\.}{PD1}{i}{i} % i
\DeclareTextCommand{\textbraceleft}{PD1}{\173} % braceleft
\DeclareTextCommand{\textbar}{PD1}{|} % bar
\DeclareTextCommand{\textbraceright}{PD1}{\175} % braceright
\DeclareTextCommand{\textasciitilde}{PD1}{\176} % asciitilde
\DeclareTextCommand{\textbullet}{PD1}{\200} % bullet
\DeclareTextCommand{\textdagger}{PD1}{\201} % dagger
\DeclareTextCommand{\textdaggerdbl}{PD1}{\202} % daggerdbl
\DeclareTextCommand{\textellipsis}{PD1}{\203} % ellipsis
\DeclareTextCommand{\textemdash}{PD1}{\204} % emdash
\DeclareTextCommand{\textendash}{PD1}{\205} % endash
\DeclareTextCommand{\textflorin}{PD1}{\206} % florin
\DeclareTextCommand{\textfractionmark}{PD1}{/} % fraction, \207
\DeclareTextCommand{\guilsinglleft}{PD1}{\210} % guilsinglleft
\DeclareTextCommand{\guilsinglright}{PD1}{\211} % guilsinglright
\DeclareTextCommand{\textminus}{PD1}{-} % minus, \212
\DeclareTextCommand{\textperthousand}{PD1}{\213} % perthousand
\DeclareTextCommand{\quotedblbase}{PD1}{\214} % quotedblbase
\DeclareTextCommand{\textquotedblleft}{PD1}{\215} % quotedblleft
\DeclareTextCommand{\textquotedblright}{PD1}{\216} % quotedblright
\DeclareTextCommand{\textquoteleft}{PD1}{\217} % quoteleft
\DeclareTextCommand{\textquoteright}{PD1}{\220} % quoteright
\DeclareTextCommand{\quotesinglbase}{PD1}{\221} % quotesinglbase
\DeclareTextCommand{\texttrademark}{PD1}{\222} % trademark
\DeclareTextCommand{\textfi}{PD1}{fi} % fi ?? \223
\DeclareTextCommand{\textfl}{PD1}{fl} % fl ?? \224
\DeclareTextCommand{\L}{PD1}{L} % Lslash, \225
\DeclareTextCommand{\OE}{PD1}{\226} % OE
\DeclareTextCompositeCommand{\v}{PD1}{S}{\227} % Scaron
\DeclareTextCompositeCommand{\"}{PD1}{Y}{\230} % Ydieresis
\DeclareTextCommand{\IJ}{PD1}{\230}
\DeclareTextCompositeCommand{\v}{PD1}{Z}{Z} % Zcaron, \231
\DeclareTextCommand{\i}{PD1}{i} % dotlessi, \232
\DeclareTextCommand{\l}{PD1}{l} % lslash, \233
\DeclareTextCommand{\oe}{PD1}{\234} % oe
\DeclareTextCompositeCommand{\v}{PD1}{s}{\235} % scaron
\DeclareTextCompositeCommand{\v}{PD1}{z}{z} % zcaron, 236
\DeclareTextCommand{\texteuro}{PD1}{\240} % Euro
\DeclareTextCommand{\textexclamdown}{PD1}{\241} % exclamdown
\DeclareTextCommand{\textcent}{PD1}{\242} % cent
\DeclareTextCommand{\textsterling}{PD1}{\243} % sterling
\DeclareTextCommand{\textcurrency}{PD1}{\244} % currency
\DeclareTextCommand{\textyen}{PD1}{\245} % yen
\DeclareTextCommand{\textbrokenbar}{PD1}{\246} % brokenbar
\DeclareTextCommand{\textsection}{PD1}{\247} % section
\DeclareTextCommand{\textdieresis}{PD1}{\250} % dieresis
\DeclareTextCommand{\textcopyright}{PD1}{\251} % copyright
\DeclareTextCommand{\textordfeminine}{PD1}{\252} % ordfeminine
\DeclareTextCommand{\guillemotleft}{PD1}{\253} % guillemotleft
\DeclareTextCommand{\textlogicalnot}{PD1}{\254} % logicalnot
\DeclareTextCommand{\textregistered}{PD1}{\256} % registered
\DeclareTextCommand{\textmacron}{PD1}{\257} % macron
\DeclareTextCommand{\textdegree}{PD1}{\260} % degree
\DeclareTextCommand{\textplusminus}{PD1}{\261} % plusminus
\DeclareTextCommand{\texttwosuperior}{PD1}{\262} % twosuperior
\DeclareTextCommand{\textthreesuperior}{PD1}{\263} % threesuperior
\DeclareTextCommand{\textacute}{PD1}{\264} % acute
\DeclareTextCommand{\textmu}{PD1}{\265} % mu
\DeclareTextCommand{\textparagraph}{PD1}{\266} % paragraph
\DeclareTextCommand{\textperiodcentered}{PD1}{\267} % periodcentered
\DeclareTextCommand{\textcedilla}{PD1}{\270} % cedilla
\DeclareTextCommand{\textonesuperior}{PD1}{\271} % onesuperior
\DeclareTextCommand{\textordmasculine}{PD1}{\272} % ordmasculine
\DeclareTextCommand{\guillemotright}{PD1}{\273} % guillemotright
\DeclareTextCommand{\textonequarter}{PD1}{\274} % onequarter
\DeclareTextCommand{\textonehalf}{PD1}{\275} % onehalf
\DeclareTextCommand{\textthreequarters}{PD1}{\276} % threequarters
\DeclareTextCommand{\textquestiondown}{PD1}{\277} % questiondown
\DeclareTextCompositeCommand{\`}{PD1}{A}{\300} % Agrave
\DeclareTextCompositeCommand{\'}{PD1}{A}{\301} % Aacute
\DeclareTextCompositeCommand{\^}{PD1}{A}{\302} % Acircumflex
\DeclareTextCompositeCommand{\~}{PD1}{A}{\303} % Atilde
\DeclareTextCompositeCommand{\"}{PD1}{A}{\304} % Adieresis
\DeclareTextCompositeCommand{\r}{PD1}{A}{\305} % Aring
\DeclareTextCommand{\AE}{PD1}{\306} % AE
\DeclareTextCompositeCommand{\c}{PD1}{C}{\307} % Ccedilla
\DeclareTextCompositeCommand{\`}{PD1}{E}{\310} % Egrave
\DeclareTextCompositeCommand{\'}{PD1}{E}{\311} % Eacute
\DeclareTextCompositeCommand{\^}{PD1}{E}{\312} % Ecircumflex
\DeclareTextCompositeCommand{\"}{PD1}{E}{\313} % Edieresis
\DeclareTextCompositeCommand{\`}{PD1}{I}{\314} % Igrave
\DeclareTextCompositeCommand{\'}{PD1}{I}{\315} % Iacute
\DeclareTextCompositeCommand{\^}{PD1}{I}{\316} % Icircumflex
\DeclareTextCompositeCommand{\"}{PD1}{I}{\317} % Idieresis
\DeclareTextCommand{\DH}{PD1}{\320} % Eth
\DeclareTextCommand{\DJ}{PD1}{\320} % Eth
\DeclareTextCompositeCommand{\~}{PD1}{N}{\321} % Ntilde
\DeclareTextCompositeCommand{\`}{PD1}{O}{\322} % Ograve
\DeclareTextCompositeCommand{\'}{PD1}{O}{\323} % Oacute
\DeclareTextCompositeCommand{\^}{PD1}{O}{\324} % Ocircumflex
\DeclareTextCompositeCommand{\~}{PD1}{O}{\325} % Otilde
\DeclareTextCompositeCommand{\"}{PD1}{O}{\326} % Odieresis
\DeclareTextCommand{\textmultiply}{PD1}{\327} % multiply
\DeclareTextCommand{\O}{PD1}{\330} % Oslash
\DeclareTextCompositeCommand{\`}{PD1}{U}{\331} % Ugrave
\DeclareTextCompositeCommand{\'}{PD1}{U}{\332} % Uacute
\DeclareTextCompositeCommand{\^}{PD1}{U}{\333} % Ucircumflex
\DeclareTextCompositeCommand{\"}{PD1}{U}{\334} % Udieresis
\DeclareTextCompositeCommand{\'}{PD1}{Y}{\335} % Yacute
\DeclareTextCommand{\TH}{PD1}{\336} % Thorn
\DeclareTextCommand{\ss}{PD1}{\337} % germandbls
\DeclareTextCompositeCommand{\`}{PD1}{a}{\340} % agrave
\DeclareTextCompositeCommand{\'}{PD1}{a}{\341} % aacute
\DeclareTextCompositeCommand{\^}{PD1}{a}{\342} % acircumflex
\DeclareTextCompositeCommand{\~}{PD1}{a}{\343} % atilde
\DeclareTextCompositeCommand{\"}{PD1}{a}{\344} % adieresis
\DeclareTextCompositeCommand{\r}{PD1}{a}{\345} % aring
\DeclareTextCommand{\ae}{PD1}{\346} % ae
\DeclareTextCompositeCommand{\c}{PD1}{c}{\347} % ccedilla
\DeclareTextCompositeCommand{\`}{PD1}{e}{\350} % egrave
\DeclareTextCompositeCommand{\'}{PD1}{e}{\351} % eacute
\DeclareTextCompositeCommand{\^}{PD1}{e}{\352} % ecircumflex
\DeclareTextCompositeCommand{\"}{PD1}{e}{\353} % edieresis
\DeclareTextCompositeCommand{\`}{PD1}{i}{\354} % igrave
\DeclareTextCompositeCommand{\`}{PD1}{\i}{\354} % igrave
\DeclareTextCompositeCommand{\'}{PD1}{i}{\355} % iacute
\DeclareTextCompositeCommand{\'}{PD1}{\i}{\355} % iacute
\DeclareTextCompositeCommand{\^}{PD1}{i}{\356} % icircumflex
\DeclareTextCompositeCommand{\^}{PD1}{\i}{\356} % icircumflex
\DeclareTextCompositeCommand{\"}{PD1}{i}{\357} % idieresis
\DeclareTextCompositeCommand{\"}{PD1}{\i}{\357} % idieresis
\DeclareTextCommand{\dh}{PD1}{\360} % eth
\DeclareTextCompositeCommand{\~}{PD1}{n}{\361} % ntilde
\DeclareTextCompositeCommand{\`}{PD1}{o}{\362} % ograve
\DeclareTextCompositeCommand{\'}{PD1}{o}{\363} % oacute
\DeclareTextCompositeCommand{\^}{PD1}{o}{\364} % ocircumflex
\DeclareTextCompositeCommand{\~}{PD1}{o}{\365} % otilde
\DeclareTextCompositeCommand{\"}{PD1}{o}{\366} % odieresis
\DeclareTextCommand{\textdivide}{PD1}{\367} % divide
\DeclareTextCommand{\o}{PD1}{\370} % oslash
\DeclareTextCompositeCommand{\`}{PD1}{u}{\371} % ugrave
\DeclareTextCompositeCommand{\'}{PD1}{u}{\372} % uacute
\DeclareTextCompositeCommand{\^}{PD1}{u}{\373} % ucircumflex
\DeclareTextCompositeCommand{\"}{PD1}{u}{\374} % udieresis
\DeclareTextCompositeCommand{\'}{PD1}{y}{\375} % yacute
\DeclareTextCommand{\th}{PD1}{\376} % thorn
\DeclareTextCompositeCommand{\"}{PD1}{y}{\377} % ydieresis
\DeclareTextCommand{\ij}{PD1}{\377}
\DeclareTextCommand{\SS}{PD1}{SS}
\DeclareTextCommand{\textcelsius}{PD1}{\textdegree C}
\DeclareTextCommand{\textglqq}{PD1}{\quotedblbase}
\DeclareTextCommand{\textgrqq}{PD1}{\textquotedblleft}
\DeclareTextCommand{\textglq}{PD1}{\quotesinglbase}
\DeclareTextCommand{\textgrq}{PD1}{\textquoteleft}
\DeclareTextCommand{\textflqq}{PD1}{\guillemotleft}
\DeclareTextCommand{\textfrqq}{PD1}{\guillemotright}
\DeclareTextCommand{\textflq}{PD1}{\guilsinglleft}
\DeclareTextCommand{\textfrq}{PD1}{\guilsinglright}
\DeclareTextCommand{\textneg}{PD1}{\textlogicalnot}
\DeclareTextCommand{\texttimes}{PD1}{\textmultiply}
\DeclareTextCommand{\textdiv}{PD1}{\textdivide}
\DeclareTextCommand{\textpm}{PD1}{\textplusminus}
\DeclareTextCommand{\textcdot}{PD1}{\textperiodcentered}
\DeclareTextCommand{\textbeta}{PD1}{\ss}
\DeclareTextCompositeCommand{\k}{PD1}{a}{a} % aogonek
\DeclareTextCompositeCommand{\'}{PD1}{c}{c} % cacute
\DeclareTextCompositeCommand{\k}{PD1}{e}{e} % eogonek
\DeclareTextCompositeCommand{\'}{PD1}{n}{n} % nacute
\DeclareTextCompositeCommand{\'}{PD1}{s}{s} % sacute
\DeclareTextCompositeCommand{\'}{PD1}{z}{z} % zacute
\DeclareTextCompositeCommand{\.}{PD1}{z}{z} % zdot
\DeclareTextCompositeCommand{\k}{PD1}{A}{A} % Aogonek
\DeclareTextCompositeCommand{\'}{PD1}{C}{C} % Cacute
\DeclareTextCompositeCommand{\k}{PD1}{E}{E} % Eogonek
\DeclareTextCompositeCommand{\'}{PD1}{N}{N} % Nacute
\DeclareTextCompositeCommand{\'}{PD1}{S}{S} % Sacute
\DeclareTextCompositeCommand{\'}{PD1}{Z}{Z} % Zacute
\DeclareTextCompositeCommand{\.}{PD1}{Z}{Z} % Zdot
\endinput
%%
%% End of file `pd1enc.def'.
