\DeclareTextAccent{\h}{PD1}{\texthookabove}
\DeclareTextAccent{\d}{PD1}{\textdotbelow}
\DeclareTextCompositeCommand{\h}{PD1}{\@empty}{\texthookabove}
\DeclareTextCompositeCommand{\d}{PD1}{\@empty}{\textdotbelow}
\DeclareTextCommand{\texthookabove}{PD1}{\@empty}
\DeclareTextCommand{\textdotbelow}{PD1}{\@empty}

\DeclareTextCommand{\ABREVE}{PD1}{A}
\DeclareTextCommand{\ACIRCUMFLEX}{PD1}{A}
\DeclareTextCommand{\Abreve}{PD1}{A}
\DeclareTextCommand{\Acircumflex}{PD1}{A}
\DeclareTextCommand{\ECIRCUMFLEX}{PD1}{E}
\DeclareTextCommand{\Ecircumflex}{PD1}{E}
\DeclareTextCommand{\OCIRCUMFLEX}{PD1}{O}
\DeclareTextCommand{\OHORN}{PD1}{O}
\DeclareTextCommand{\Ocircumflex}{PD1}{O}
\DeclareTextCommand{\Ohorn}{PD1}{O}
\DeclareTextCommand{\UHORN}{PD1}{U}
\DeclareTextCommand{\Uhorn}{PD1}{U}
\DeclareTextCommand{\abreve}{PD1}{a}
\DeclareTextCommand{\acircumflex}{PD1}{a}
\DeclareTextCommand{\dj}{PD1}{d}
\DeclareTextCommand{\ecircumflex}{PD1}{e}
\DeclareTextCommand{\ocircumflex}{PD1}{o}
\DeclareTextCommand{\ohorn}{PD1}{o}
\DeclareTextCommand{\uhorn}{PD1}{u}


\DeclareTextComposite{\'}{PD1}{\ABREVE}{`A}
\DeclareTextComposite{\'}{PD1}{\ACIRCUMFLEX}{`A}
\DeclareTextComposite{\'}{PD1}{\Abreve}{`A}
\DeclareTextComposite{\'}{PD1}{\Acircumflex}{`A}
\DeclareTextComposite{\'}{PD1}{\ECIRCUMFLEX}{`E}
\DeclareTextComposite{\'}{PD1}{\Ecircumflex}{`E}
\DeclareTextComposite{\'}{PD1}{\OCIRCUMFLEX}{`O}
\DeclareTextComposite{\'}{PD1}{\OHORN}{`O}
\DeclareTextComposite{\'}{PD1}{\Ocircumflex}{`O}
\DeclareTextComposite{\'}{PD1}{\Ohorn}{`O}
\DeclareTextComposite{\'}{PD1}{\UHORN}{`U}
\DeclareTextComposite{\'}{PD1}{\Uhorn}{`U}
\DeclareTextComposite{\'}{PD1}{\abreve}{`a}
\DeclareTextComposite{\'}{PD1}{\acircumflex}{`a}
\DeclareTextComposite{\'}{PD1}{\ecircumflex}{`e}
\DeclareTextComposite{\'}{PD1}{\ocircumflex}{`o}
\DeclareTextComposite{\'}{PD1}{\ohorn}{`o}
\DeclareTextComposite{\'}{PD1}{\uhorn}{`u}
\DeclareTextComposite{\`}{PD1}{Y}{`Y}
\DeclareTextComposite{\`}{PD1}{\ABREVE}{`A}
\DeclareTextComposite{\`}{PD1}{\ACIRCUMFLEX}{`A}
\DeclareTextComposite{\`}{PD1}{\Abreve}{`A}
\DeclareTextComposite{\`}{PD1}{\Acircumflex}{`A}
\DeclareTextComposite{\`}{PD1}{\ECIRCUMFLEX}{`E}
\DeclareTextComposite{\`}{PD1}{\Ecircumflex}{`E}
\DeclareTextComposite{\`}{PD1}{\OCIRCUMFLEX}{`O}
\DeclareTextComposite{\`}{PD1}{\OHORN}{`O}
\DeclareTextComposite{\`}{PD1}{\Ocircumflex}{`O}
\DeclareTextComposite{\`}{PD1}{\Ohorn}{`O}
\DeclareTextComposite{\`}{PD1}{\UHORN}{`U}
\DeclareTextComposite{\`}{PD1}{\Uhorn}{`U}
\DeclareTextComposite{\`}{PD1}{\abreve}{`a}
\DeclareTextComposite{\`}{PD1}{\acircumflex}{`a}
\DeclareTextComposite{\`}{PD1}{\ecircumflex}{`e}
\DeclareTextComposite{\`}{PD1}{\ocircumflex}{`o}
\DeclareTextComposite{\`}{PD1}{\ohorn}{`o}
\DeclareTextComposite{\`}{PD1}{\uhorn}{`u}
\DeclareTextComposite{\`}{PD1}{y}{`y}
\DeclareTextComposite{\d}{PD1}{A}{`A}
\DeclareTextComposite{\d}{PD1}{E}{`E}
\DeclareTextComposite{\d}{PD1}{I}{`I}
\DeclareTextComposite{\d}{PD1}{O}{`O}
\DeclareTextComposite{\d}{PD1}{U}{`U}
\DeclareTextComposite{\d}{PD1}{Y}{`Y}
\DeclareTextComposite{\d}{PD1}{\Abreve}{`A}
\DeclareTextComposite{\d}{PD1}{\Acircumflex}{`A}
\DeclareTextComposite{\d}{PD1}{\Ecircumflex}{`E}
\DeclareTextComposite{\d}{PD1}{\Ocircumflex}{`O}
\DeclareTextComposite{\d}{PD1}{\Ohorn}{`O}
\DeclareTextComposite{\d}{PD1}{\Uhorn}{`U}
\DeclareTextComposite{\d}{PD1}{\abreve}{`a}
\DeclareTextComposite{\d}{PD1}{\acircumflex}{`a}
\DeclareTextComposite{\d}{PD1}{\ecircumflex}{`e}
\DeclareTextComposite{\d}{PD1}{\ocircumflex}{`o}
\DeclareTextComposite{\d}{PD1}{\ohorn}{`o}
\DeclareTextComposite{\d}{PD1}{\uhorn}{`u}
\DeclareTextComposite{\d}{PD1}{a}{`a}
\DeclareTextComposite{\d}{PD1}{e}{`e}
\DeclareTextComposite{\d}{PD1}{i}{`i}
\DeclareTextComposite{\d}{PD1}{o}{`o}
\DeclareTextComposite{\d}{PD1}{u}{`u}
\DeclareTextComposite{\d}{PD1}{y}{`y}
\DeclareTextComposite{\h}{PD1}{A}{`A}
\DeclareTextComposite{\h}{PD1}{E}{`E}
\DeclareTextComposite{\h}{PD1}{I}{`I}
\DeclareTextComposite{\h}{PD1}{O}{`O}
\DeclareTextComposite{\h}{PD1}{U}{`U}
\DeclareTextComposite{\h}{PD1}{Y}{`Y}
\DeclareTextComposite{\h}{PD1}{\Abreve}{`A}
\DeclareTextComposite{\h}{PD1}{\Acircumflex}{`A}
\DeclareTextComposite{\h}{PD1}{\Ecircumflex}{`E}
\DeclareTextComposite{\h}{PD1}{\Ocircumflex}{`O}
\DeclareTextComposite{\h}{PD1}{\Ohorn}{`O}
\DeclareTextComposite{\h}{PD1}{\Uhorn}{`U}
\DeclareTextComposite{\h}{PD1}{\abreve}{`a}
\DeclareTextComposite{\h}{PD1}{\acircumflex}{`a}
\DeclareTextComposite{\h}{PD1}{\ecircumflex}{`e}
\DeclareTextComposite{\h}{PD1}{\ocircumflex}{`o}
\DeclareTextComposite{\h}{PD1}{\ohorn}{`o}
\DeclareTextComposite{\h}{PD1}{\uhorn}{`u}
\DeclareTextComposite{\h}{PD1}{a}{`a}
\DeclareTextComposite{\h}{PD1}{e}{`e}
\DeclareTextComposite{\h}{PD1}{i}{`i}
\DeclareTextComposite{\h}{PD1}{o}{`o}
\DeclareTextComposite{\h}{PD1}{u}{`u}
\DeclareTextComposite{\h}{PD1}{y}{`y}
\DeclareTextComposite{\~}{PD1}{E}{`E}
\DeclareTextComposite{\~}{PD1}{I}{`I}
\DeclareTextComposite{\~}{PD1}{U}{`U}
\DeclareTextComposite{\~}{PD1}{Y}{`Y}
\DeclareTextComposite{\~}{PD1}{\ABREVE}{`A}
\DeclareTextComposite{\~}{PD1}{\ACIRCUMFLEX}{`A}
\DeclareTextComposite{\~}{PD1}{\Abreve}{`A}
\DeclareTextComposite{\~}{PD1}{\Acircumflex}{`A}
\DeclareTextComposite{\~}{PD1}{\ECIRCUMFLEX}{`E}
\DeclareTextComposite{\~}{PD1}{\Ecircumflex}{`E}
\DeclareTextComposite{\~}{PD1}{\OCIRCUMFLEX}{`O}
\DeclareTextComposite{\~}{PD1}{\OHORN}{`O}
\DeclareTextComposite{\~}{PD1}{\Ocircumflex}{`O}
\DeclareTextComposite{\~}{PD1}{\Ohorn}{`O}
\DeclareTextComposite{\~}{PD1}{\UHORN}{`U}
\DeclareTextComposite{\~}{PD1}{\Uhorn}{`U}
\DeclareTextComposite{\~}{PD1}{\abreve}{`a}
\DeclareTextComposite{\~}{PD1}{\acircumflex}{`a}
\DeclareTextComposite{\~}{PD1}{\ecircumflex}{`e}
\DeclareTextComposite{\~}{PD1}{\i}{`i}
\DeclareTextComposite{\~}{PD1}{\ocircumflex}{`o}
\DeclareTextComposite{\~}{PD1}{\ohorn}{`o}
\DeclareTextComposite{\~}{PD1}{\uhorn}{`u}
\DeclareTextComposite{\~}{PD1}{e}{`e}
\DeclareTextComposite{\~}{PD1}{i}{`i}
\DeclareTextComposite{\~}{PD1}{u}{`u}
\DeclareTextComposite{\~}{PD1}{y}{`y}
