%%
%% This is file `hdvips.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `dvips')
%% 
%% File: hyperref.dtx Copyright 1995-2001 Sebastian Rahtz,
%% RCS: $Id: hyperref.dtx 6.71 2000/10/04 rahtz Exp rahtz $
%%
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%%
%% It may be distributed under the conditions of the LaTeX Project Public
%% License, either version 1.2 of this license or (at your option) any
%% later version.  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%%
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%%
\ProvidesFile{hdvips.def}
  [2003/11/30 v6.74m
  Hyperref driver for dvips]
\input{pdfmark.def}%
\def\@pdfproducer{dvips + Distiller}
\def\literalps@out#1{\special{ps:SDict begin #1 end}}%
\def\headerps@out#1{\special{! #1}}%
\providecommand\@pdfborder{0 0 12}
\providecommand\@pdfview{XYZ}
\providecommand\@pdfviewparams{ H.V}
\AtBeginDvi{%
  \headerps@out{%
    /DvipsToPDF { 72.27 mul Resolution div } def
    /PDFToDvips { 72.27 div Resolution mul } def
    /HyperBorder  { 1 PDFToDvips } def
    /H.V {pdf@hoff pdf@voff null} def
    /H.B {/Rect[pdf@llx pdf@lly pdf@urx pdf@ury]} def
    /H.S {
      currentpoint
      HyperBorder add /pdf@lly exch def
      dup DvipsToPDF  /pdf@hoff exch def
      HyperBorder sub /pdf@llx exch def
    } def
    /H.L {
      2 sub dup
      /HyperBasePt exch def
      PDFToDvips /HyperBaseDvips exch def
      currentpoint
      HyperBaseDvips sub /pdf@ury exch def
      /pdf@urx exch def
    } def
    /H.A {
      H.L
      currentpoint exch pop
      vsize 72 sub exch DvipsToPDF
      HyperBasePt sub % baseline skip
      sub /pdf@voff exch def
    } def
    /H.R {
      currentpoint
      HyperBorder sub /pdf@ury exch def
      HyperBorder add /pdf@urx exch def
      currentpoint exch pop vsize 72 sub
      exch DvipsToPDF sub /pdf@voff exch def
    } def
    systemdict
    /pdfmark known not
    {userdict /pdfmark systemdict /cleartomark get put} if
  }%
}
\AfterBeginDocument{%
  \ifx\special@paper\@empty\else
    \ifHy@setpagesize
      \special{papersize=\special@paper}%
    \fi
    \Hy@DisableOption{setpagesize}%
  \fi
}
\endinput
%%
%% End of file `hdvips.def'.
