%%
%% This is file `lgrenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% greek.fdd  (with options: `LGRenc')
%% This is a generated file.
%% 
%% Copyright 1989-2004 Johannes L. Braams and any individual authors
%% listed elsewhere in this file.  All rights reserved.
%% 
%% This file was generated from file(s) of the Babel system.
%% ---------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2003/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainer of this work is Johannes Braams.
%% 
%% This file may only be distributed together with a copy of the Babel
%% system. You may however distribute the Babel system without
%% such generated files.
%% 
%% The list of all files belonging to the Babel distribution is
%% given in the file `manifest.bbl'. See also `legal.bbl for additional
%% information.
%% 
%% In particular, permission is granted to customize the declarations in
%% this file to serve the needs of your installation.
%% 
%% However, NO PERMISSION is granted to distribute a modified version
%% of this file under its original name.
%% 
\ProvidesFile{lgrenc.def}
         [2001/01/30 v2.2e %
  Greek Encoding]
\DeclareFontEncoding{LGR}{}{}
\DeclareFontSubstitution{LGR}{cmr}{m}{n}
\DeclareErrorFont{LGR}{cmr}{m}{n}{10}
\ProvideTextCommand{\textcopyright}{LGR}{%
  \textcircled{\textlatin{c}}}
\ProvideTextCommand{\textregistered}{LGR}{%
  \textcircled{\textlatin{\textsc r}}}
\ProvideTextCommand{\texttrademark}{LGR}{%
  \textsuperscript{\textlatin{TM}}}
\ProvideTextCommand{\SS}{LGR}{%
  \textlatin{SS}}
\endinput
%%
%% End of file `lgrenc.def'.
