%%
%% This is file `mnk.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyinpenc.dtx  (with options: `MNK')
%% This file is a generated file from the sources of the `cyrillic' bundle
%% in the LaTeX2e distribution.
%% 
%% This is a generated file.
%% 
%% Copyright 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the Standard LaTeX `Cyrillic Bundle'.
%% -----------------------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2003/12/01 or later.
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% `Cyrillic Bundle'. You may however distribute the LaTeX `Cyrillic
%% Bundle' without such generated files.
%% 
%% The list of all files belonging to the `Cyrillic Bundle' is
%% given in the file `manifest.txt'.
%% 
% (C) Copyright 1999 by Oliver Corff.
\ProvidesFile{mnk.def}
  [1999/11/16 v1.0d Input encoding file]
\makeatletter
\DeclareInputText{128}{\CYRA}
\DeclareInputText{129}{\CYRB}
\DeclareInputText{130}{\CYRV}
\DeclareInputText{131}{\CYRG}
\DeclareInputText{132}{\CYRD}
\DeclareInputText{133}{\CYRE}
\DeclareInputText{134}{\CYRYO}
\DeclareInputText{135}{\CYRZH}
\DeclareInputText{136}{\CYRZ}
\DeclareInputText{137}{\CYRI}
\DeclareInputText{138}{\CYRISHRT}
\DeclareInputText{139}{\CYRK}
\DeclareInputText{140}{\CYRL}
\DeclareInputText{141}{\CYRM}
\DeclareInputText{142}{\CYRN}
\DeclareInputText{143}{\CYRO}
\DeclareInputText{144}{\CYROTLD}
\DeclareInputText{145}{\CYRP}
\DeclareInputText{146}{\CYRR}
\DeclareInputText{147}{\CYRS}
\DeclareInputText{148}{\CYRT}
\DeclareInputText{149}{\CYRU}
\DeclareInputText{150}{\CYRY}
\DeclareInputText{151}{\CYRF}
\DeclareInputText{152}{\CYRH}
\DeclareInputText{153}{\CYRC}
\DeclareInputText{154}{\CYRCH}
\DeclareInputText{155}{\CYRSH}
\DeclareInputText{156}{\CYRSHCH}
\DeclareInputText{157}{\CYRHRDSN}
\DeclareInputText{158}{\CYRERY}
\DeclareInputText{159}{\CYRSFTSN}
\DeclareInputText{160}{\CYREREV}
\DeclareInputText{161}{\CYRYU}
\DeclareInputText{162}{\CYRYA}
\DeclareInputText{163}{\cyra}
\DeclareInputText{164}{\cyrb}
\DeclareInputText{165}{\cyrv}
\DeclareInputText{166}{\cyrg}
\DeclareInputText{167}{\cyrd}
\DeclareInputText{168}{\cyre}
\DeclareInputText{169}{\cyryo}
\DeclareInputText{170}{\cyrzh}
\DeclareInputText{173}{\cyrz}
\DeclareInputText{224}{\cyri}
\DeclareInputText{225}{\cyrishrt}
\DeclareInputText{226}{\cyrk}
\DeclareInputText{227}{\cyrl}
\DeclareInputText{228}{\cyrm}
\DeclareInputText{229}{\cyrn}
\DeclareInputText{230}{\cyro}
\DeclareInputText{231}{\cyrotld}
\DeclareInputText{232}{\cyrp}
\DeclareInputText{233}{\cyrr}
\DeclareInputText{234}{\cyrs}
\DeclareInputText{235}{\cyrt}
\DeclareInputText{236}{\cyru}
\DeclareInputText{237}{\cyry}
\DeclareInputText{238}{\cyrf}
\DeclareInputText{239}{\cyrh}
\DeclareInputText{240}{\cyrc}
\DeclareInputText{241}{\cyrch}
\DeclareInputText{242}{\cyrsh}
\DeclareInputText{243}{\cyrshch}
\DeclareInputText{244}{\cyrhrdsn}
\DeclareInputText{245}{\cyrery}
\DeclareInputText{248}{\cyrsftsn}
\DeclareInputText{252}{\cyrerev}
\DeclareInputText{253}{\cyryu}
\DeclareInputText{254}{\cyrya}
\makeatother
\endinput
%%
%% End of file `mnk.def'.
