%%
%% This is file `atari.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% umlaute.dtx  (with options: `atari')
%% 
%% Copyright (C) 1994-95 Harald Axel Sommerfeldt
%% 
\ProvidesFile{atari.def}[1995/02/03 %
  Input encoding file (Harald_Sommerfeldt@w.maus.de)]
\chardef\atcode=\catcode`\@
\catcode`\@=11
\providecommand*{\@as@active}[1]{%
  \ifx\protect\relax\else\ifx\protect\empty\else%
  \expandafter\expandafter\expandafter\protect\fi\fi%
  \as@active{#1}}
\providecommand*{\as@active}[1]{\csname @as@@#1\endcsname}
\def\@as@@aa{\aa}\def\@as@@AA{\AA}
\def\@as@@ae{\ae}\def\@as@@AE{\AE}
\def\@as@@ic{\^{\i}}\def\@as@@IC{\^I}
\def\@as@@id{\'{\i}}\def\@as@@ID{\'I}
\def\@as@@ig{\`{\i}}\def\@as@@IG{\`I}
\def\@as@@iq{\"{\i}}\def\@as@@IQ{\"I}
\def\@as@@o{\o}\def\@as@@O{\O}
\def\@as@@ss{\ss}\def\@as@@SS{\SS}
\def\@as@@oe{\oe}\def\@as@@OE{\OE}
\def\@as@@dh{\dh}\def\@as@@DH{\DH}
\def\@as@@th{\th}\def\@as@@TH{\TH}
\ProvideTextCommandDefault{\textonequarter}{$\frac14$}
\ProvideTextCommandDefault{\textonehalf}{$\frac12$}
\ProvideTextCommandDefault{\textthreequarters}{$\frac34$}
\ProvideTextCommandDefault{\texttrademark}{$^\mathrm{TM}$}
\def\as@msa#1{{\fontencoding{U}\fontfamily{msa}\selectfont\char#1}}
\ProvideTextCommandDefault{\textblacksquare}{\as@msa{4}}
\ProvideTextCommandDefault{\textyen}{\as@msa{85}}
\ProvideTextCommandDefault{\textulcorner}{\as@msa{112}}
\ProvideTextCommandDefault{\texturcorner}{\as@msa{113}}
\ProvideTextCommandDefault{\textregistered}{\as@msa{114}}
\ProvideTextCommandDefault{\textllcorner}{\as@msa{120}}
\ProvideTextCommandDefault{\textlrcorner}{\as@msa{121}}
\def\as@wasy#1{{\fontencoding{U}\fontfamily{wasy}\selectfont\char#1}}
\ProvideTextCommandDefault{\textcurrency}{\as@wasy{27}}
\ProvideTextCommandDefault{\textcent}{\as@wasy{103}}
\ProvideTextCommandDefault{\textpermil}{\as@wasy{104}}
\ProvideTextCommandDefault{\textbrokenbar}{\as@wasy{124}}
\providecommand*{\mathbullet}{{{}^\bullet}}
\providecommand*{\mathdegree}{{{}^\circ}}
\providecommand*{\mathordmasculine}{{{}^a}}
\providecommand*{\mathordfeminine}{{{}^o}}
\providecommand*{\mathonesuperior}{{{}^1}}
\providecommand*{\mathtwosuperior}{{{}^2}}
\providecommand*{\maththreesuperior}{{{}^3}}
\providecommand*{\DeclareInputTextEx}[4]{%
  \DeclareInputText{#1}{#2}%
  \lccode#1=#3\uccode#1=#4}
\providecommand*{\DeclareInputMathEx}[2]{%
  \DeclareInputMath{#1}{#2}%
  \lccode#1=#1\uccode#1=#1}
\DeclareInputTextEx{"80}{\c C}{"87}{"80}
\DeclareInputTextEx{"81}{\"u}{"81}{"9A}
\DeclareInputTextEx{"82}{\'e}{"82}{"90}
\DeclareInputTextEx{"83}{\^a}{"83}{"0C0}
\DeclareInputTextEx{"84}{\"a}{"84}{"8E}
\DeclareInputTextEx{"85}{\`a}{"85}{"0B6}
\DeclareInputTextEx{"86}{\@as@active{aa}}{"86}{"8F}
\DeclareInputTextEx{"87}{\c c}{"87}{"80}
\DeclareInputTextEx{"88}{\^e}{"88}{"0C1}
\DeclareInputTextEx{"89}{\"e}{"89}{"0C2}
\DeclareInputTextEx{"8A}{\`e}{"8A}{"0C3}
\DeclareInputTextEx{"8B}{\@as@active{iq}}{"8B}{"0C4}
\DeclareInputTextEx{"8C}{\@as@active{ic}}{"8C}{"0C5}
\DeclareInputTextEx{"8D}{\@as@active{ig}}{"8D}{"0C6}
\DeclareInputTextEx{"8E}{\"A}{"84}{"8E}
\DeclareInputTextEx{"8F}{\@as@active{AA}}{"86}{"8F}
\DeclareInputTextEx{"90}{\'E}{"82}{"90}
\DeclareInputTextEx{"91}{\@as@active{ae}}{"91}{"92}
\DeclareInputTextEx{"92}{\@as@active{AE}}{"91}{"92}
\DeclareInputTextEx{"93}{\^o}{"93}{"0C7}
\DeclareInputTextEx{"94}{\"o}{"94}{"99}
\DeclareInputTextEx{"95}{\`o}{"95}{"0C8}
\DeclareInputTextEx{"96}{\^u}{"96}{"0C9}
\DeclareInputTextEx{"97}{\`u}{"97}{"0CA}
\DeclareInputTextEx{"98}{\"y}{"98}{"0CB}
\DeclareInputTextEx{"99}{\"O}{"94}{"99}
\DeclareInputTextEx{"9A}{\"U}{"81}{"9A}
\DeclareInputTextEx{"9B}{\textcent}{"9B}{"9B}
\DeclareInputTextEx{"9C}{\textsterling}{"9C}{"9C}
\DeclareInputTextEx{"9D}{\textyen}{"9D}{"9D}
\DeclareInputTextEx{"9E}{\@as@active{ss}}{"9E}{"0CC}
\DeclareInputTextEx{"9F}{\NotImplemented}{"9F}{"9F} % holl. Gulden
\DeclareInputTextEx{"0A0}{\'a}{"0A0}{"0CD}
\DeclareInputTextEx{"0A1}{\@as@active{id}}{"0A1}{"0CE}
\DeclareInputTextEx{"0A2}{\'o}{"0A2}{"0CF}
\DeclareInputTextEx{"0A3}{\'u}{"0A3}{"0D0}
\DeclareInputTextEx{"0A4}{\~n}{"0A4}{"0A5}
\DeclareInputTextEx{"0A5}{\~N}{"0A4}{"0A5}
\DeclareInputMathEx{"0A6}{\mathordmasculine}
\DeclareInputMathEx{"0A7}{\mathordfeminine}
\DeclareInputTextEx{"0A8}{\textquestiondown}{"0A8}{"0A8}
\DeclareInputMathEx{"0A9}{\invneg} % wasysym
\DeclareInputMathEx{"0AA}{\neg}
\DeclareInputTextEx{"0AB}{\textonehalf}{"0AB}{"0AB}
\DeclareInputTextEx{"0AC}{\textonequarter}{"0AC}{"0AC}
\DeclareInputTextEx{"0AD}{\textexclamdown}{"0AD}{"0AD}
\DeclareInputTextEx{"0AE}{\guillemotleft}{"0AE}{"0AE}
\DeclareInputTextEx{"0AF}{\guillemotright}{"0AF}{"0AF}
\DeclareInputTextEx{"0B0}{\~a}{"0B0}{"0B7}
\DeclareInputTextEx{"0B1}{\~o}{"0B1}{"0B8}
\DeclareInputTextEx{"0B2}{\@as@active{O}}{"0B3}{"0B2}
\DeclareInputTextEx{"0B3}{\@as@active{o}}{"0B3}{"0B2}
\DeclareInputTextEx{"0B4}{\@as@active{oe}}{"0B4}{"0B5}
\DeclareInputTextEx{"0B5}{\@as@active{OE}}{"0B4}{"0B5}
\DeclareInputTextEx{"0B6}{\`A}{"85}{"0B6}
\DeclareInputTextEx{"0B7}{\~A}{"0B0}{"0B7}
\DeclareInputTextEx{"0B8}{\~O}{"0B1}{"0B8}
\DeclareInputTextEx{"0B9}{\"{}}{"0B9}{"0B9}
\DeclareInputTextEx{"0BA}{\'{}}{"0BA}{"0BA}
\DeclareInputTextEx{"0BB}{\dag}{"0BB}{"0BB}
\DeclareInputTextEx{"0BC}{\P}{"0BC}{"0BC}
\DeclareInputTextEx{"0BD}{\copyright}{"0BD}{"0BD}
\DeclareInputTextEx{"0BE}{\textregistered}{"0BE}{"0BE}
\DeclareInputTextEx{"0BF}{\texttrademark}{"0BF}{"0BF}
\DeclareInputTextEx{"0C0}{\^A}{"83}{"0C0}
\DeclareInputTextEx{"0C1}{\^E}{"88}{"0C1}
\DeclareInputTextEx{"0C2}{\"E}{"89}{"0C2}
\DeclareInputTextEx{"0C3}{\`E}{"8A}{"0C3}
\DeclareInputTextEx{"0C4}{\@as@active{IQ}}{"8B}{"0C4}
\DeclareInputTextEx{"0C5}{\@as@active{IC}}{"8C}{"0C5}
\DeclareInputTextEx{"0C6}{\@as@active{IG}}{"8D}{"0C6}
\DeclareInputTextEx{"0C7}{\^O}{"93}{"0C7}
\DeclareInputTextEx{"0C8}{\`O}{"95}{"0C8}
\DeclareInputTextEx{"0C9}{\^U}{"96}{"0C9}
\DeclareInputTextEx{"0CA}{\`U}{"97}{"0CA}
\DeclareInputTextEx{"0CB}{\"Y}{"98}{"0CB}
\DeclareInputTextEx{"0CC}{\@as@active{SS}}{"9E}{"0CC}
\DeclareInputTextEx{"0CD}{\'A}{"0A0}{"0CD}
\DeclareInputTextEx{"0CE}{\@as@active{ID}}{"0A1}{"0CE}
\DeclareInputTextEx{"0CF}{\'O}{"0A2}{"0CF}
\DeclareInputTextEx{"0D0}{\'U}{"0A3}{"0D0}
\DeclareInputTextEx{"0D1}{\NotImplemented}{"0D1}{"0D1}
\DeclareInputTextEx{"0D2}{\NotImplemented}{"0D2}{"0D2}
\DeclareInputTextEx{"0D3}{\NotImplemented}{"0D3}{"0D3}
\DeclareInputTextEx{"0D4}{\NotImplemented}{"0D4}{"0D4}
\DeclareInputTextEx{"0D5}{\NotImplemented}{"0D5}{"0D5}
\DeclareInputTextEx{"0D6}{\NotImplemented}{"0D6}{"0D6}
\DeclareInputTextEx{"0D7}{\NotImplemented}{"0D7}{"0D7}
\DeclareInputTextEx{"0D8}{\NotImplemented}{"0D8}{"0D8}
\DeclareInputTextEx{"0D9}{\NotImplemented}{"0D9}{"0D9}
\DeclareInputTextEx{"0DA}{\NotImplemented}{"0DA}{"0DA}
\DeclareInputTextEx{"0DB}{\NotImplemented}{"0DB}{"0DB}
\DeclareInputTextEx{"0DC}{\NotImplemented}{"0DC}{"0DC}
\DeclareInputTextEx{"0DD}{\S}{"0DD}{"0DD}
\DeclareInputTextEx{"0DE}{\^{}}{"0DE}{"0DE}
\DeclareInputMathEx{"0DF}{\infty}
\DeclareInputMathEx{"0E0}{\alpha}
\DeclareInputMathEx{"0E1}{\beta}
\DeclareInputMathEx{"0E2}{\Gamma}
\DeclareInputMathEx{"0E3}{\pi}
\DeclareInputMathEx{"0E4}{\Sigma}
\DeclareInputMathEx{"0E5}{\sigma}
\DeclareInputMathEx{"0E6}{\mu}
\DeclareInputMathEx{"0E7}{\tau}
\DeclareInputMathEx{"0E8}{\Phi}
\DeclareInputMathEx{"0E9}{\Theta}
\DeclareInputMathEx{"0EA}{\Omega}
\DeclareInputMathEx{"0EB}{\delta}
\DeclareInputMathEx{"0EC}{\varoint} % wasysym
\DeclareInputMathEx{"0ED}{\NotImplemented}
\DeclareInputMathEx{"0EE}{\NotImplemented}
\DeclareInputMathEx{"0EF}{\NotImplemented}
\DeclareInputMathEx{"0F0}{\equiv}
\DeclareInputMathEx{"0F1}{\pm}
\DeclareInputMathEx{"0F2}{\ge}
\DeclareInputMathEx{"0F3}{\le}
\DeclareInputMathEx{"0F4}{\NotImplemented}
\DeclareInputMathEx{"0F5}{\NotImplemented}
\DeclareInputMathEx{"0F6}{\div}
\DeclareInputMathEx{"0F7}{\approx}
\DeclareInputMathEx{"0F8}{\mathdegree}
\DeclareInputMathEx{"0F9}{\mathbullet}
\DeclareInputMathEx{"0FA}{\cdot}
\DeclareInputMathEx{"0FB}{\protect\sqrt{}}
\DeclareInputMathEx{"0FC}{\NotImplemented}
\DeclareInputMathEx{"0FD}{\mathtwosuperior}
\DeclareInputMathEx{"0FE}{\maththreesuperior}
\DeclareInputTextEx{"0FF}{\={}}{"0FF}{"0FF}
\catcode`\@=\atcode
\endinput
%%
%% End of file `atari.def'.
