%%
%% This is file `truetex.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% drivers.dtx  (with options: `truetex,color4,nops')
%% 
%% drivers.dtx Copyright (C) 1994      David Carlisle Sebastian Rahtz
%%             Copyright (C) 1995 1996 1997 1998 1999 David Carlisle
%%
%% This file is part of the Standard LaTeX `Graphics Bundle'.
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%%
\ProvidesFile{truetex.def}
        [1999/02/16 v3.0i Driver-dependant file (DPC,SPQR)]
\def\c@lor@arg#1{%
  \dimen@#1\p@
  \ifdim\dimen@<\z@\dimen@\maxdimen\fi
  \ifdim\dimen@>\p@
    \PackageError{color}{Argument `#1' not in range [0,1]}\@ehd
  \fi}
\def\color@gray#1#2{%
  \c@lor@arg{#2}%
  \c@lor@rgb@RGB\@tempa
  \edef#1{\@tempa\@tempa\@tempa}%
  }
\def\color@cmyk#1#2{\c@lor@@cmyk#2\@@#1}
\def\c@lor@@cmyk#1,#2,#3,#4\@@#5{%
  \c@lor@arg{#4}%
    \dimen@ii#4\p@
  \c@lor@arg{#1}%
  \c@lor@cmyk@RGB\@tempa
  \c@lor@arg{#2}%
  \c@lor@cmyk@RGB\@tempb
  \c@lor@arg{#3}%
  \c@lor@cmyk@RGB\@tempc
  \edef#5{\@tempa\@tempb\@tempc}%
  }
\def\c@lor@cmyk@RGB#1{%
  \advance\dimen@-\p@
  \advance\dimen@\dimen@ii
  \dimen@-\@cclv\dimen@
  \divide\dimen@\p@
  \count@\ifdim\dimen@<\z@\z@\else\dimen@\fi
  \edef#1{\the\count@\space}}
\def\color@rgb#1#2{\c@lor@@rgb#2\@@#1}
\def\c@lor@@rgb#1,#2,#3\@@#4{%
  \c@lor@arg{#1}%
  \c@lor@rgb@RGB\@tempa
  \c@lor@arg{#2}%
  \c@lor@rgb@RGB\@tempb
  \c@lor@arg{#3}%
  \c@lor@rgb@RGB\@tempc
  \edef#4{\@tempa\@tempb\@tempc}%
  }
\def\c@lor@rgb@RGB#1{%
  \dimen@\@cclv\dimen@
  \count@\dimen@
  \divide\count@\p@
  \edef#1{\the\count@\space}}
\def\color@RGB#1#2{\c@lor@@RGB#2\@@#1}
\def\c@lor@@RGB#1,#2,#3\@@#4{%
  \edef#4{#1 #2 #3}%
  }
\def\color@named#1#2{\c@lor@@named#2,,\@@#1}
\def\c@lor@@named#1,#2,#3\@@#4{%
  \@ifundefined{col@#1}%
    {\PackageError{color}{Undefined color `#1'}\@ehd}%
  {\edef#4{\csname col@#1\endcsname}}%
  }
\def\c@lor@to@ps#1#2 #3 #4\@@{%
  #1#2 255 div #3 255 div #4 255 div setrgbcolor}
\def\current@color{0 0 0}
\def\set@color{%
  \special{textcolor: \current@color}\aftergroup\reset@color}
\def\reset@color{\special{textcolor: \current@color}}
\def\set@page@color{%
  \c@lor@special\sixt@@n{background color ignored: \current@color}}
\def\define@color@named#1#2{%
  \expandafter\edef\csname col@#1\endcsname{#2}}
\def\Ginclude@eps#1{%
 \message{<#1>}%
  \bgroup
  \def\@tempa{!}%
  \dimen@\Gin@req@width
  \dimen@ii.1bp%
  \divide\dimen@\dimen@ii
  \@tempdima\Gin@req@height
  \divide\@tempdima\dimen@ii
    \special{PSfile="#1"\space
      llx=\Gin@llx\space
      lly=\Gin@lly\space
      urx=\Gin@urx\space
      ury=\Gin@ury\space
      \ifx\Gin@scalex\@tempa\else rwi=\number\dimen@\space\fi
      \ifx\Gin@scaley\@tempa\else rhi=\number\@tempdima\space\fi
      \ifGin@clip clip\fi}%
  \egroup}
\def\Ginclude@bmp#1{%
 \message{<#1>}%
 \special{bmpfile #1}}
\def\Ginclude@tiff#1{%
 \message{<#1>}%
 \special{tifffile #1}}
\def\Gin@extensions{.eps,.ps}
\@namedef{Gin@rule@.ps}#1{{eps}{.ps}{#1}}
\@namedef{Gin@rule@.eps}#1{{eps}{.eps}{#1}}
\@namedef{Gin@rule@.tif}#1{{tiff}{}{#1}}
\@namedef{Gin@rule@.bmp}#1{{bmp}{}{#1}}
\@namedef{Gin@rule@*}#1{{eps}{\Gin@ext}{#1}}
\def\Gin@PS@raw#1{}
\def\Gin@PS@restored#1{}
\def\Gin@PS@literal@header#1{}
\def\Gin@PS@file@header#1{}
\endinput
%%
%% End of file `truetex.def'.
