%%
%% This is file `hvtexmrk.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `vtexpdfmark')
%% 
%% File: hyperref.dtx Copyright 1995-2001 Sebastian Rahtz,
%% RCS: $Id: hyperref.dtx 6.71 2000/10/04 rahtz Exp rahtz $
%%
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%%
%% It may be distributed under the conditions of the LaTeX Project Public
%% License, either version 1.2 of this license or (at your option) any
%% later version.  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%%
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%%
\ProvidesFile{hvtexmrk.def}
  [2003/11/30 v6.74m
 Hyperref driver for VTeX in PDF/PS mode (pdfmark specials)]
\input{pdfmark.def}%
\ifnum\OpMode=\@ne
  \def\@pdfproducer{VTeX}
\else
  \def\@pdfproducer{VTeX + Distiller}
\fi
\def\literalps@out#1{\special{pS:#1}}%
\def\headerps@out#1{\immediate\special{pS:#1}}%
\providecommand\@pdfborder{0 0 1}
\providecommand\@pdfview{XYZ}
\providecommand\@pdfviewparams{ H.V}
\AtBeginDvi{%
  \headerps@out{%
    /vsize {\Hy@pageheight} def
    /HyperBorder {1} def
    /H.V {pdf@hoff pdf@voff null} def
    /H.B {/Rect[pdf@llx pdf@lly pdf@urx pdf@ury]} def
    /H.S {
      currentpoint
      HyperBorder sub
      /pdf@lly exch def
      dup 72 add /pdf@hoff exch def
      HyperBorder sub
      /pdf@llx exch def
    } def
    /H.L {
      2 sub
      /HyperBasePt exch def
      currentpoint
      HyperBasePt add HyperBorder add
      /pdf@ury exch def
      HyperBorder add
      /pdf@urx exch def
    } def
    /H.A {
      H.L
      currentpoint exch pop
      vsize 72 sub exch
      HyperBasePt add add
      /pdf@voff exch def
    } def
    /H.R {
      currentpoint
      HyperBorder add
      /pdf@ury exch def
      HyperBorder add
      /pdf@urx exch def
      currentpoint exch pop vsize 72 sub add
      /pdf@voff exch def
    } def
  }%
}
\endinput
%%
%% End of file `hvtexmrk.def'.
