% This is the file tcvn.def which provides TCVN input encoding for
% Vietnamese.
%
% written by Werner Lemberg <wl@gnu.org> and
%            Han The Thanh <thanh@fi.muni.cz>

\ProvidesFile{tcvn.def}[2000/01/28 v1.0 TCVN Vietnamese input encoding]

\makeatletter

\DeclareInputText{1}{\@tabacckludge'U}
\DeclareInputText{2}{\d U}
\DeclareInputText{4}{\@tabacckludge`\Uhorn}
\DeclareInputText{5}{\h\Uhorn}
\DeclareInputText{6}{\~\Uhorn}
\DeclareInputText{17}{\@tabacckludge'\Uhorn}
\DeclareInputText{18}{\d\Uhorn}
\DeclareInputText{19}{\@tabacckludge`Y}
\DeclareInputText{20}{\h Y}
\DeclareInputText{21}{\~Y}
\DeclareInputText{22}{\@tabacckludge'Y}
\DeclareInputText{23}{\d Y}

\DeclareInputText{128}{\@tabacckludge`A}
\DeclareInputText{129}{\h A}
\DeclareInputText{130}{\~A}
\DeclareInputText{131}{\@tabacckludge'A}
\DeclareInputText{132}{\d A}
\DeclareInputText{133}{\d\Abreve}
\DeclareInputText{134}{\d\Acircumflex}
\DeclareInputText{135}{\@tabacckludge`E}
\DeclareInputText{136}{\h E}
\DeclareInputText{137}{\~E}
\DeclareInputText{138}{\@tabacckludge'E}
\DeclareInputText{139}{\d E}
\DeclareInputText{140}{\d\Ecircumflex}
\DeclareInputText{141}{\@tabacckludge`I}
\DeclareInputText{142}{\h I}
\DeclareInputText{143}{\~I}

\DeclareInputText{144}{\@tabacckludge'I}
\DeclareInputText{145}{\d I}
\DeclareInputText{146}{\@tabacckludge`O}
\DeclareInputText{147}{\h O}
\DeclareInputText{148}{\~O}
\DeclareInputText{149}{\@tabacckludge'O}
\DeclareInputText{150}{\d O}
\DeclareInputText{151}{\d\Ocircumflex}
\DeclareInputText{152}{\@tabacckludge`\Ohorn}
\DeclareInputText{153}{\h\Ohorn}
\DeclareInputText{154}{\~\Ohorn}
\DeclareInputText{155}{\@tabacckludge'\Ohorn}
\DeclareInputText{156}{\d\Ohorn}
\DeclareInputText{157}{\@tabacckludge`U}
\DeclareInputText{158}{\h U}
\DeclareInputText{159}{\~U}

\DeclareInputText{161}{\Abreve}
\DeclareInputText{162}{\Acircumflex}
\DeclareInputText{163}{\Ecircumflex}
\DeclareInputText{164}{\Ocircumflex}
\DeclareInputText{165}{\Ohorn}
\DeclareInputText{166}{\Uhorn}
\DeclareInputText{167}{\DJ}
\DeclareInputText{168}{\abreve}
\DeclareInputText{169}{\acircumflex}
\DeclareInputText{170}{\ecircumflex}
\DeclareInputText{171}{\ocircumflex}
\DeclareInputText{172}{\ohorn}
\DeclareInputText{173}{\uhorn}
\DeclareInputText{174}{\dj}
\DeclareInputText{175}{\@tabacckludge`\Abreve}

\DeclareInputText{181}{\@tabacckludge`a}
\DeclareInputText{182}{\h a}
\DeclareInputText{183}{\~a}
\DeclareInputText{184}{\@tabacckludge'a}
\DeclareInputText{185}{\d a}
\DeclareInputText{186}{\h\Abreve}
\DeclareInputText{187}{\@tabacckludge`\abreve}
\DeclareInputText{188}{\h\abreve}
\DeclareInputText{189}{\~\abreve}
\DeclareInputText{190}{\@tabacckludge'\abreve}
\DeclareInputText{191}{\~\Abreve}

\DeclareInputText{192}{\@tabacckludge'\Abreve}
\DeclareInputText{193}{\@tabacckludge`\Acircumflex}
\DeclareInputText{194}{\h\Acircumflex}
\DeclareInputText{195}{\~\Acircumflex}
\DeclareInputText{196}{\@tabacckludge'\Acircumflex}
\DeclareInputText{197}{\@tabacckludge`\Ecircumflex}
\DeclareInputText{198}{\d\abreve}
\DeclareInputText{199}{\@tabacckludge`\acircumflex}
\DeclareInputText{200}{\h\acircumflex}
\DeclareInputText{201}{\~\acircumflex}
\DeclareInputText{202}{\@tabacckludge'\acircumflex}
\DeclareInputText{203}{\d\acircumflex}
\DeclareInputText{204}{\@tabacckludge`e}
\DeclareInputText{205}{\h\Ecircumflex}
\DeclareInputText{206}{\h e}
\DeclareInputText{207}{\~e}

\DeclareInputText{208}{\@tabacckludge'e}
\DeclareInputText{209}{\d e}
\DeclareInputText{210}{\@tabacckludge`\ecircumflex}
\DeclareInputText{211}{\h\ecircumflex}
\DeclareInputText{212}{\~\ecircumflex}
\DeclareInputText{213}{\@tabacckludge'\ecircumflex}
\DeclareInputText{214}{\d\ecircumflex}
\DeclareInputText{215}{\@tabacckludge`i}
\DeclareInputText{216}{\h i}
\DeclareInputText{217}{\~\Ecircumflex}
\DeclareInputText{218}{\@tabacckludge'\Ecircumflex}
\DeclareInputText{219}{\@tabacckludge`\Ocircumflex}
\DeclareInputText{220}{\~i}
\DeclareInputText{221}{\@tabacckludge'i}
\DeclareInputText{222}{\d i}
\DeclareInputText{223}{\@tabacckludge`o}

\DeclareInputText{224}{\h\Ocircumflex}
\DeclareInputText{225}{\h o}
\DeclareInputText{226}{\~o}
\DeclareInputText{227}{\@tabacckludge'o}
\DeclareInputText{228}{\d o}
\DeclareInputText{229}{\@tabacckludge`\ocircumflex}
\DeclareInputText{230}{\h\ocircumflex}
\DeclareInputText{231}{\~\ocircumflex}
\DeclareInputText{232}{\@tabacckludge'\ocircumflex}
\DeclareInputText{233}{\d\ocircumflex}
\DeclareInputText{234}{\@tabacckludge`\ohorn}
\DeclareInputText{235}{\h\ohorn}
\DeclareInputText{236}{\~\ohorn}
\DeclareInputText{237}{\@tabacckludge'\ohorn}
\DeclareInputText{238}{\d\ohorn}
\DeclareInputText{239}{\@tabacckludge`u}

\DeclareInputText{240}{\~\Ocircumflex}
\DeclareInputText{241}{\h u}
\DeclareInputText{242}{\~u}
\DeclareInputText{243}{\@tabacckludge'u}
\DeclareInputText{244}{\d u}
\DeclareInputText{245}{\@tabacckludge`\uhorn}
\DeclareInputText{246}{\h\uhorn}
\DeclareInputText{247}{\~\uhorn}
\DeclareInputText{248}{\@tabacckludge'\uhorn}
\DeclareInputText{249}{\d\uhorn}
\DeclareInputText{250}{\@tabacckludge`y}
\DeclareInputText{251}{\h y}
\DeclareInputText{252}{\~y}
\DeclareInputText{253}{\@tabacckludge'y}
\DeclareInputText{254}{\d y}
\DeclareInputText{255}{\@tabacckludge'\Ocircumflex}

\makeatother

\endinput

% end of tcvn.def
