%
% Copyright 1997, 1998, 1999 David Carlisle
%
\ProvidesFile{ly1enc.def}[1999/05/21 v0.6 TeX 'n ANSI encoding (DPC)]
\DeclareFontEncoding{LY1}{}{}

\DeclareErrorFont{LY1}{ptm}{m}{n}{10}		% argh!
\DeclareFontSubstitution{LY1}{ptm}{m}{n}	% argh!

%
% notdef                                       0
% \DeclareTextSymbol{\textEuro}{LY1}          {1}
\DeclareTextSymbol{\texteuro}{LY1}            {1}
% notdef                                       2
% notdef                                       3
\DeclareTextSymbol{\textfractionsolidus}{LY1} {4}
\DeclareTextAccent{\.}{LY1}                   {5}
\DeclareTextAccent{\H}{LY1}                   {6}
\DeclareTextCommand{\k}{LY1}[1]
           {\oalign{\null#1\crcr\hidewidth\char7}}
% fl                                           8
% notdef                                       9
% notdef                                      10
% ff                                          11
% fi                                          12
% notdef                                      13
% ffi                                         14
% ffl                                         15
\DeclareTextSymbol{\i}{LY1}                  {16}
\DeclareTextCommand{\j}{LY1}
  {\TextSymbolUnavailable\j j}%               17
\DeclareTextAccent{\`}{LY1}                  {18}
\DeclareTextAccent{\'}{LY1}                  {19}
\DeclareTextAccent{\v}{LY1}                  {20}
\DeclareTextAccent{\u}{LY1}                  {21}
\DeclareTextAccent{\=}{LY1}                  {22}
\DeclareTextCommand{\b}{LY1}[1]
   {{\o@lign{\relax#1\crcr\hidewidth\sh@ft{29}%
     \vbox to.2ex{\hbox{\char22}\vss}\hidewidth}}}
\renewcommand\aa{\r{a}}% not needed with recent LaTeX releases
\renewcommand\AA{\r{A}}% not needed with recent LaTeX releases
\DeclareTextAccent{\r}{LY1}                  {23}
\DeclareTextCommand{\c}{LY1}[1]{%
    \setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent24 #1%
                \else{\ooalign{\hidewidth\char24%
     \hidewidth\crcr\unhbox\z@}}\fi}
\DeclareTextSymbol{\ss}{LY1}                 {25}
% \ae (but use 230)                           26
\DeclareTextSymbol{\oe}{LY1}                 {27}
% \o (but use 248)                            28
% \AE (but use 198)                           29
\DeclareTextSymbol{\OE}{LY1}                 {30}
% \O (but use 216)                           {31}
% \DeclareTextSymbol{\textblank}{LY1}        {32}
\DeclareTextSymbol{\textspace}{LY1}          {32}
% !                                           33
\DeclareTextSymbol{\textquotedbl}{LY1}       {34}
% \#                                          35
\DeclareTextSymbol{\textdollar}{LY1}         {36}
% \%                                          37
% \&                                          38
\DeclareTextSymbol{\textquoteright}{LY1}     {39}
% (                                           40
% )                                           41
% *                                           42
% +                                           43
% ,                                           44
% -                                           45
% .                                           46
\DeclareTextCommand{\d}{LY1}[1]
   {{\o@lign{\relax#1\crcr\hidewidth\sh@ft{10}.\hidewidth}}}
% /                                           47
% 0-9                                      48-57
% :                                           58
% ;                                           59
\DeclareTextSymbol{\textless}{LY1}           {60}
% =                                           61
\DeclareTextSymbol{\textgreater}{LY1}        {62}
% ?                                           63
% @                                           64
% A-Z                                      65-90
% [                                           91
\DeclareTextSymbol{\textbackslash}{LY1}      {92}
% ]                                           93
\DeclareTextAccent{\^}{LY1}                  {94}
\DeclareTextSymbol{\textunderscore}{LY1}     {95}
\DeclareTextSymbol{\textquoteleft}{LY1}      {96}
% a-z                                     97-122
\DeclareTextSymbol{\textbraceleft}{LY1}     {123}
\DeclareTextSymbol{\textbar}{LY1}           {124}
\DeclareTextSymbol{\textbraceright}{LY1}    {125}
\DeclareTextAccent{\~}{LY1}                 {126}
% \" but use 168                             127
\DeclareTextSymbol{\L}{LY1}                 {128}
\DeclareTextSymbol{\textquotesingle}{LY1}   {129}
\DeclareTextSymbol{\quotesinglbase}{LY1}    {130}
\DeclareTextSymbol{\textquotesinglbase}{LY1}{130}
\DeclareTextSymbol{\textflorin}{LY1}        {131}
\DeclareTextSymbol{\textquotedblbase}{LY1}  {132}
\DeclareTextSymbol{\quotedblbase}{LY1}      {132}
\DeclareTextSymbol{\textellipsis}{LY1}      {133}
\DeclareTextSymbol{\textdagger}{LY1}        {134}
\DeclareTextSymbol{\textdaggerdbl}{LY1}     {135}
% \^ (again)                                 136
\DeclareTextSymbol{\textperthousand}{LY1}   {137}
\DeclareTextComposite{\v}{LY1}{S}           {138}
\DeclareTextSymbol{\guilsinglleft}{LY1}     {139}
% OE (again)                                 140
\DeclareTextComposite{\v}{LY1}{Z}           {141}
\DeclareTextSymbol{\textasciicircum}{LY1}   {142}
\DeclareTextSymbol{\textminus}{LY1}         {143}
\DeclareTextSymbol{\l}{LY1}                 {144}
% quoteleft (again)                          145
% quoteright (again)                         146
\DeclareTextSymbol{\textquotedblleft}{LY1}  {147}
\DeclareTextSymbol{\textquotedblright}{LY1} {148}
\DeclareTextSymbol{\textbullet}{LY1}        {149}
\DeclareTextSymbol{\textendash}{LY1}        {150}
\DeclareTextSymbol{\textemdash}{LY1}        {151}
% tilde (again)                              152
\DeclareTextSymbol{\texttrademark}{LY1}     {153}
\DeclareTextComposite{\v}{LY1}{s}           {154}
\DeclareTextSymbol{\guilsinglright}{LY1}    {155}
% oe (again)                                 156
\DeclareTextComposite{\v}{LY1}{z}           {157}
\DeclareTextSymbol{\textasciitilde}{LY1}    {158}
\DeclareTextAccent{\"}{LY1}                 {168}% moved before \"{Y}
\DeclareTextComposite{\"}{LY1}{Y}           {159}
% \DeclareTextSymbol{\textnbspace}{LY1}     {160}
\DeclareTextSymbol{\textexclamdown}{LY1}    {161}
\DeclareTextSymbol{\textcent}{LY1}          {162}
\DeclareTextSymbol{\textsterling}{LY1}      {163}
\DeclareTextSymbol{\textcurrency}{LY1}      {164}
\DeclareTextSymbol{\textyen}{LY1}           {165}
\DeclareTextSymbol{\textbrokenbar}{LY1}     {166}
\DeclareTextSymbol{\textsection}{LY1}       {167}
%\DeclareTextAccent{\"}{LY1}                {168}% declared earlier
\DeclareTextSymbol{\textcopyright}{LY1}     {169}
\DeclareTextSymbol{\copyright}{LY1}         {169}% Plain TeX name
\DeclareTextSymbol{\textordfeminine}{LY1}   {170}
\DeclareTextSymbol{\guillemotleft}{LY1}     {171}
\DeclareTextSymbol{\textlogicalnot}{LY1}    {172}
% \DeclareTextSymbol{\textsfthyphen}{LY1}   {173}
\DeclareTextSymbol{\textregistered}{LY1}    {174}
% macron (again)                             175
\DeclareTextSymbol{\textdegree}{LY1}        {176}
% \DeclareTextSymbol{\textpm}{LY1}          {177}
\DeclareTextSymbol{\textplusminus}{LY1}     {177}
\DeclareTextSymbol{\texttwosuperior}{LY1}   {178}
\DeclareTextSymbol{\textthreesuperior}{LY1} {179}
% acute (again)                              180
\DeclareTextSymbol{\textmu}{LY1}            {181}
\DeclareTextSymbol{\textparagraph}{LY1}     {182}
\DeclareTextSymbol{\textperiodcentered}{LY1}{183}
% cedilla (again)                            184
\DeclareTextSymbol{\textonesuperior}{LY1}   {185}
\DeclareTextSymbol{\textordmasculine}{LY1}  {186}
\DeclareTextSymbol{\guillemotright}{LY1}    {187}
\DeclareTextSymbol{\textonequarter}{LY1}    {188}
\DeclareTextSymbol{\textonehalf}{LY1}       {189}
\DeclareTextSymbol{\textthreequarters}{LY1} {190}
\DeclareTextSymbol{\textquestiondown}{LY1}  {191}
\DeclareTextComposite{\`}{LY1}{A}           {192}
\DeclareTextComposite{\'}{LY1}{A}           {193}
\DeclareTextComposite{\^}{LY1}{A}           {194}
\DeclareTextComposite{\~}{LY1}{A}           {195}
\DeclareTextComposite{\"}{LY1}{A}           {196}
\DeclareTextComposite{\r}{LY1}{A}           {197}
\DeclareTextSymbol{\AE}{LY1}                {198}
\DeclareTextComposite{\c}{LY1}{C}           {199}
\DeclareTextComposite{\`}{LY1}{E}           {200}
\DeclareTextComposite{\'}{LY1}{E}           {201}
\DeclareTextComposite{\^}{LY1}{E}           {202}
\DeclareTextComposite{\"}{LY1}{E}           {203}
\DeclareTextComposite{\`}{LY1}{I}           {204}
\DeclareTextComposite{\'}{LY1}{I}           {205}
\DeclareTextComposite{\^}{LY1}{I}           {206}
\DeclareTextComposite{\"}{LY1}{I}           {207}
\DeclareTextSymbol{\DH}{LY1}                {208}
\DeclareTextComposite{\~}{LY1}{N}           {209}
\DeclareTextComposite{\`}{LY1}{O}           {210}
\DeclareTextComposite{\'}{LY1}{O}           {211}
\DeclareTextComposite{\^}{LY1}{O}           {212}
\DeclareTextComposite{\~}{LY1}{O}           {213}
\DeclareTextComposite{\"}{LY1}{O}           {214}
% \DeclareTextSymbol{\texttimes}{LY1}       {215}
\DeclareTextSymbol{\textmultiply}{LY1}      {215}
\DeclareTextSymbol{\O}{LY1}                 {216}
\DeclareTextComposite{\`}{LY1}{U}           {217}
\DeclareTextComposite{\'}{LY1}{U}           {218}
\DeclareTextComposite{\^}{LY1}{U}           {219}
\DeclareTextComposite{\"}{LY1}{U}           {220}
\DeclareTextComposite{\'}{LY1}{Y}           {221}
\DeclareTextSymbol{\TH}{LY1}                {222}
% ss (again)                                 223
\DeclareTextComposite{\`}{LY1}{a}           {224}
\DeclareTextComposite{\'}{LY1}{a}           {225}
\DeclareTextComposite{\^}{LY1}{a}           {226}
\DeclareTextComposite{\~}{LY1}{a}           {227}
\DeclareTextComposite{\"}{LY1}{a}           {228}
\DeclareTextComposite{\r}{LY1}{a}           {229}
\DeclareTextSymbol{\ae}{LY1}                {230}
\DeclareTextComposite{\c}{LY1}{c}           {231}
\DeclareTextComposite{\`}{LY1}{e}           {232}
\DeclareTextComposite{\'}{LY1}{e}           {233}
\DeclareTextComposite{\^}{LY1}{e}           {234}
\DeclareTextComposite{\"}{LY1}{e}           {235}
\DeclareTextComposite{\`}{LY1}{i}           {236}
\DeclareTextComposite{\`}{LY1}{\i}          {236}% again
\DeclareTextComposite{\'}{LY1}{i}           {237}
\DeclareTextComposite{\'}{LY1}{\i}          {237}% again
\DeclareTextComposite{\^}{LY1}{i}           {238}
\DeclareTextComposite{\^}{LY1}{\i}          {238}% again
\DeclareTextComposite{\"}{LY1}{i}           {239}
\DeclareTextComposite{\"}{LY1}{\i}          {239}% again
\DeclareTextSymbol{\dh}{LY1}                {240}
\DeclareTextComposite{\~}{LY1}{n}           {241}
\DeclareTextComposite{\`}{LY1}{o}           {242}
\DeclareTextComposite{\'}{LY1}{o}           {243}
\DeclareTextComposite{\^}{LY1}{o}           {244}
\DeclareTextComposite{\~}{LY1}{o}           {245}
\DeclareTextComposite{\"}{LY1}{o}           {246}
% \DeclareTextSymbol{\textdiv}{LY1}         {247}
\DeclareTextSymbol{\textdivide}{LY1}        {247}
\DeclareTextSymbol{\o}{LY1}                 {248}
\DeclareTextComposite{\`}{LY1}{u}           {249}
\DeclareTextComposite{\'}{LY1}{u}           {250}
\DeclareTextComposite{\^}{LY1}{u}           {251}
\DeclareTextComposite{\"}{LY1}{u}           {252}
\DeclareTextComposite{\'}{LY1}{y}           {253}
\DeclareTextSymbol{\th}{LY1}                {254}
\DeclareTextComposite{\"}{LY1}{y}           {255}
\endinput
%%
%% End of file `ly1enc.def'.