%%
%% This is file `Mac_CE.def',
%% 
%% Author: Michal Malek
%%  email: Michal.Malek@math.slu.cz
%% 
%% 
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
  \ProvidesFile{Mac_CE.def}
   [2001/06/05 v0.90 Input encoding file for Macintosh Central European Roman encoding]

\makeatletter
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textbrokenbar}
   {\TextSymbolUnavailable\textbrokenbar}
\ProvideTextCommandDefault{\textperthousand}
   {\TextSymbolUnavailable\textperthousand}
\DeclareInputText{128}{\"A}
\DeclareInputText{129}{\=A}
\DeclareInputText{130}{\=a}
\DeclareInputText{131}{\@tabacckludge'E}
\DeclareInputText{132}{\k A}
\DeclareInputText{133}{\"O}
\DeclareInputText{134}{\"U}
\DeclareInputText{135}{\@tabacckludge'a}
\DeclareInputText{136}{\k a}
\DeclareInputText{137}{\v C}
\DeclareInputText{138}{\"a}
\DeclareInputText{139}{\v c}
\DeclareInputText{140}{\@tabacckludge`C}
\DeclareInputText{141}{\@tabacckludge`c}
\DeclareInputText{142}{\@tabacckludge'e}
\DeclareInputText{143}{\@tabacckludge'Z}
\DeclareInputText{144}{\@tabacckludge'z}
\DeclareInputText{145}{\v D}
\DeclareInputText{146}{\@tabacckludge'\i}
\DeclareInputText{147}{\v d}
\DeclareInputText{148}{\=E}
\DeclareInputText{149}{\=e}
\DeclareInputText{150}{\.E}
\DeclareInputText{151}{\@tabacckludge'o}
\DeclareInputText{152}{\.e}
\DeclareInputText{153}{\^e}
\DeclareInputText{154}{\"o}
\DeclareInputText{155}{\~o}
\DeclareInputText{156}{\@tabacckludge'u}
\DeclareInputText{157}{\v E}
\DeclareInputText{158}{\v e}
\DeclareInputText{159}{\"u}
\DeclareInputText{160}{\dagg}
\DeclareInputText{161}{\textdegree}
\DeclareInputText{162}{\k E}
\DeclareInputText{163}{\textcurrency}
\DeclareInputText{164}{\S}
\DeclareInputText{165}{\bullet}
\DeclareInputText{166}{\P}
\DeclareInputText{167}{\ss}
\DeclareInputText{168}{{}}
\DeclareInputText{169}{\copyright}
\DeclareInputText{170}{\ensuremath{^{\hbox{TM}}}}
\DeclareInputText{171}{\k e}
\DeclareInputText{172}{\"{}}
\DeclareInputText{173}{\ensuremath{\neq}}
\DeclareInputText{174}{\@tabacckludge'g}
\DeclareInputText{175}{\k I}
\DeclareInputText{176}{\k i}
\DeclareInputText{177}{\=I}
\DeclareInputText{178}{\ensuremath{\leq}}
\DeclareInputText{179}{\ensuremath{\geq}}
\DeclareInputText{180}{\=\i}
\DeclareInputText{181}{\c K}
\DeclareInputText{182}{\ensuremath{\partial}}
\DeclareInputText{183}{\ensuremath{\sum}}
\DeclareInputText{184}{\l}
\DeclareInputText{185}{\c L}
\DeclareInputText{186}{\c l}
\DeclareInputText{187}{\v L}
\DeclareInputText{188}{\v l}
\DeclareInputText{189}{\@tabacckludge'L}
\DeclareInputText{190}{\@tabacckludge'l}
\DeclareInputText{191}{\c N}
\DeclareInputText{192}{\c n}
\DeclareInputText{193}{\@tabacckludge'N}
\DeclareInputText{194}{{}}
\DeclareInputText{195}{{}}
\DeclareInputText{196}{\@tabacckludge'n}
\DeclareInputText{197}{\v N}
\DeclareInputText{198}{\ensuremath{\Delta}}
\DeclareInputText{199}{{}}
\DeclareInputText{200}{{}}
\DeclareInputText{201}{\dots}
\DeclareInputText{202}{{ }}
\DeclareInputText{203}{\v n}
\DeclareInputText{204}{\H O}
\DeclareInputText{205}{\~O}
\DeclareInputText{206}{\H o}
\DeclareInputText{207}{\=0}
\DeclareInputText{208}{\textendash}
\DeclareInputText{209}{\textemdash}
\DeclareInputText{210}{\textquotedblleft}
\DeclareInputText{211}{\textquotedblright}
\DeclareInputText{212}{\textquoteleft}
\DeclareInputText{213}{\textquoteright}
\DeclareInputText{214}{{:}}
\DeclareInputText{215}{\ensuremath{\diamond}}
\DeclareInputText{216}{\=o}
\DeclareInputText{217}{\@tabacckludge'R}
\DeclareInputText{218}{\@tabacckludge'r}
\DeclareInputText{219}{\v R}
\DeclareInputText{220}{{}}
\DeclareInputText{221}{{}}
\DeclareInputText{222}{\v r}
\DeclareInputText{223}{\c R}
\DeclareInputText{224}{\c r}
\DeclareInputText{225}{\v S}
\DeclareInputText{226}{,}
\DeclareInputText{227}{,,}
\DeclareInputText{228}{\v s}
\DeclareInputText{229}{\@tabacckludge'S}
\DeclareInputText{230}{\@tabacckludge's}
\DeclareInputText{231}{\@tabacckludge'A}
\DeclareInputText{232}{\v T}
\DeclareInputText{233}{\v t}
\DeclareInputText{234}{\@tabacckludge'I}
\DeclareInputText{235}{\v Z}
\DeclareInputText{236}{\v z}
\DeclareInputText{237}{\=U}
\DeclareInputText{238}{\@tabacckludge'O}
\DeclareInputText{239}{\^O}
\DeclareInputText{240}{\=u}
\DeclareInputText{241}{\r U}
\DeclareInputText{242}{\@tabacckludge'U}
\DeclareInputText{243}{\r u}
\DeclareInputText{244}{\H U}
\DeclareInputText{245}{\H u}
\DeclareInputText{246}{\k U}
\DeclareInputText{247}{\k u}
\DeclareInputText{248}{\@tabacckludge'Y}
\DeclareInputText{249}{\@tabacckludge'y}
\DeclareInputText{250}{k}
\DeclareInputText{251}{\.Z}
\DeclareInputText{252}{\L}
\DeclareInputText{253}{\.z}
\DeclareInputText{254}{\c G}
\DeclareInputText{255}{\v {}}
\makeatother
\endinput
%%
%% End of file `Mac_CE.def'.
