%%
%% This is file `prtightpage.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% preview.dtx  (with options: `tightpage')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from prtightpage.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file preview.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
%%\iffalse
%%     preview.dtx for extracting previews from LaTeX documents.  Part of
%%     the preview-latex package.
%%     Copyright (C) 2001, 2002, 2003 David Kastrup
%%
%%     This program is free software; you can redistribute it and/or modify
%%     it under the terms of the GNU General Public License as published by
%%     the Free Software Foundation; either version 2 of the License, or
%%     (at your option) any later version.
%%
%%     This program is distributed in the hope that it will be useful,
%%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%%     GNU General Public License for more details.
%%
%%     You should have received a copy of the GNU General Public License
%%     along with this program; if not, write to the
%%     Free Software Foundation, Inc., 59 Temple Place, Suite 330,
%%     Boston, MA 02111-1307  USA
%%\fi
\ifx\PreviewBorder\@undefined
  \newdimen\PreviewBorder
  \PreviewBorder=0.50001bp
\fi
\ifx\PreviewBbAdjust\@undefined
  \def\PreviewBbAdjust{-\PreviewBorder -\PreviewBorder
    \PreviewBorder \PreviewBorder}
\fi
\ifPreview\else\expandafter\endinput\fi
\def\pr@nextbb{\edef\next{\next\space\number\dimen@}%
  \expandafter\xdef\csname pr@bb@%
    \romannumeral\count@\endcsname{\the\dimen@}%
  \advance\count@\@ne\ifnum\count@<5
  \afterassignment\pr@nextbb\dimen@=\fi}
\ifnum\pr@graphicstype=\z@
  \ifcase \ifx\pdfoutput\@undefined \@ne\fi
    \ifnum\pdfoutput>\z@ \tw@\fi \@ne \or
    \ExecuteOptions{dvips}\relax \or
    \ExecuteOptions{pdftex}\relax\fi\fi
\global\let\pr@bbadjust\@empty
\pr@addto@front\pr@ship@end{\begingroup
  \let\next\@gobble
  \count@\@ne\afterassignment\pr@nextbb
  \dimen@\PreviewBbAdjust
  \ifx\pr@bbadjust\next
  \else \global\let\pr@bbadjust\next
  \typeout{Preview: Tightpage \pr@bbadjust}%
  \fi\endgroup}
\ifcase\pr@graphicstype
\or
  \g@addto@macro\pr@ship@end{\setbox\pr@box\hbox{%
    \special{ps::\pr@bbadjust\space\number\ht\pr@box\space
    \number\dp\pr@box\space\number\wd\pr@box}\box\pr@box}}
\or
  \g@addto@macro\pr@ship@end{{\dimen@\ht\pr@box
    \ifdim\dimen@<\z@ \dimen@\z@\fi
    \advance\dimen@\pr@bb@iv
    \dimen@ii=\dimen@
    \global\pdfvorigin\dimen@
    \dimen@\dp\pr@box
    \ifdim\dimen@<\z@ \dimen@\z@\fi
    \advance\dimen@-\pr@bb@ii
    \advance\dimen@\dimen@ii
    \global\pdfpageheight\dimen@
    \dimen@\wd\pr@box
    \ifdim\dimen@<\z@ \dimen@=\z@\fi
    \advance\dimen@-\pr@bb@i
    \advance\dimen@\pr@bb@iii
    \global\pdfpagewidth\dimen@
    \global\pdfhorigin-\pr@bb@i}}
\fi
\ifnum\pr@graphicstype=\@ne
\preview@delay{\AtBeginDvi{%
  \special{!userdict begin/bop-hook{%
     7{currentfile token not{stop}if
       65781.76 div DVImag mul}repeat
     72 add 72 2 copy gt{exch}if 4 2 roll
     neg 2 copy lt{exch}if dup 0 gt{pop 0 exch}%
     {exch dup 0 lt{pop 0}if}ifelse 720 add exch 720 add
     3 1 roll
    4{5 -1 roll add 4 1 roll}repeat
     <</PageSize[5 -1 roll 6 index sub 5 -1 roll 5 index sub]%
       /PageOffset[7 -2 roll [1 1 dtransform exch]%
       {0 ge{neg}if exch}forall]>>setpagedevice%
     //bop-hook exec}bind def end}}}
\fi
\endinput
%%
%% End of file `prtightpage.def'.
