%%
%% This is file `pppdftex.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% pdfpages.dtx  (with options: `pppdftexdef')
%% 
%% This is a package for PDFLaTeX, which makes it
%% easy to insert pages of external PDF documents.
%% 
%% This file is part of the pdfpages package.
%% 
%% Copyright (C) 2001-2003 Andreas MATTHIAS.
%% 
%% Please send error reports and suggestions for improvements to
%%   Andreas MATTHIAS <amat@kabsi.at>.
%%
\ProvidesFile{pppdftex.def}
   [2004/01/31 v0.3e
    Pdfpages driver for pdfTeX (AM)]
\ifnum\pdftexversion<100
  \PackageError{pdfpages}
         {Package pdfpages requires at least\MessageBreak
          pdfTeX version 1.00}
         {Update your TeX distribution.}
  \let\AM@endinput\relax
  \expandafter\endinput
\fi
\ifcase\pdfoutput
  \PackageError{pdfpages}
         {You produce DVI output but PDF output\MessageBreak
          is needed for package pdfpages}
         {Set output to PDF. (use: \pdfoutput = 1)}
  \let\AM@endinput\relax
  \expandafter\endinput
\fi
\begingroup
\@ifundefined{ver@pdftex.def}{%
  \PackageError{pdfpages}
         {The graphics package was loaded with driver\MessageBreak
          `\Gin@driver', which cannot be used with pdfTeX}
         {Check the driver option of the graphics package.}
  \global\let\AM@endinput\relax
  \aftergroup\endinput}{}
\endgroup
\AM@ifdriverlater{pdftex}{2000/05/12}{}{%
    \PackageError{pdfpages}
         {Your version of `pdftex.def' is too old.\MessageBreak
          There is no multipage support\MessageBreak
          in `pdftex.def' < 0.02u}
         {Please, update your `pdftex.def'!}}
\AM@ifdriverlater{pdftex}{2000/09/14}{}{%
    \PackageWarningNoLine{pdfpages}{%
         Your version of `pdftex.def' is too old.\MessageBreak
         There might be problems with\MessageBreak
         the `trim' and `clip' options.\MessageBreak
         Please, update your `pdftex.def'}}
\def\AM@getpagecount{%
  \pdfximage{\AM@currentdocname}%
  \edef\AM@pagecount{\the\pdflastximagepages}%
}
\let\AM@pagewidth\pdfpagewidth
\let\AM@pageheight\pdfpageheight
\def\AM@setpagedimen{%
  \setlength{\pdfpagewidth}{\the\wd\@tempboxa}%
  \setlength{\pdfpageheight}{\the\ht\@tempboxa}%
}
\let\AM@fitpaper@special\relax
\def\AM@findfile#1{%
  \AM@findfile@i{#1}{pdf}%
  \AM@findfile@ii{#1}%
}
\def\AM@setlscape{\pdfpageattr{/Rotate 90}}
\def\AM@linktodoc@special@begin{%
    \pdfannot width \wd\@tempboxa
              height \ht\@tempboxa
              depth \dp\@tempboxa
              {/Subtype /Link /Border [0 0 0]
               /A << /S /GoToR
                     /F (\AM@linkfilename)
                     /D [\AM@linktodoc@page@m@ne \AM@linktodocfit]
                     \ifAM@newwindow/NewWindow true\fi >>}%
}
\let\AM@linktodoc@special@end\relax
\def\AM@survey@special@begin{%
    \pdfannot width \wd\@tempboxa
              height \ht\@tempboxa
              depth \dp\@tempboxa
              {/Subtype /Link /Border [0 0 0]
               /A << /S /GoTo
                     /D (pdfpages.\AM@linktodoc@page@m@ne) >>}%
}
\let\AM@survey@special@end\relax
\def\AM@thread@special@begin{%
      \pdfthread width \wd\@tempboxa
                 height \ht\@tempboxa
                 depth \dp\@tempboxa
                 attr {/I <<\threadinfodict>>}%
                 name {\AM@threadname}%
}
\let\AM@thread@special@end\relax
\def\AM@dest@special{\pdfdest name {\AM@linkname.\AM@page} \AM@linkfit}
\def\AM@anchor@special{\pdfdest name {pdfpages.\the\count1} fit}

\endinput
%%
%% End of file `pppdftex.def'.
