%%
%% This is file `lheenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hebrew.fdd  (with options: `LHEenc')
%% 
%% This is a generated file.
%% 
%% Copyright 1997-2004 Boris Lavva and any individual authors
%% listed elsewhere in this file. All rights reserved.
%% 
%% This is a generated file.
%% 
%% Copyright 1989-2004 Johannes L. Braams and any individual authors
%% listed elsewhere in this file.  All rights reserved.
%% 
%% This file was generated from file(s) of the Babel system.
%% ---------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2003/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainer of this work is Johannes Braams.
%% 
%% This file may only be distributed together with a copy of the Babel
%% system. You may however distribute the Babel system without
%% such generated files.
%% 
%% The list of all files belonging to the Babel distribution is
%% given in the file `manifest.bbl'. See also `legal.bbl for additional
%% information.
%% 
%% In particular, permission is granted to customize the declarations in
%% this file to serve the needs of your installation.
%% 
%% However, NO PERMISSION is granted to distribute a modified version
%% of this file under its original name.
%% 
%% File `hebrew.fdd' for installing the Hebrew encodings and fonts.
%% Copyright (C) 1997 -- 2004 Boris Lavva.
%% Babel package for LaTeX version 2e
%% Copyright (C) 1989 -- 2004 by Johannes Braams,
%%                            TeXniek
%%                            All rights reserved.
\ProvidesFile{lheenc.def}
        [2004/02/20 v1.2b %
         7-bit Hebrew font encoding
         (test version: still liable to change)]
\DeclareFontEncoding{LHE}{}{}
\DeclareFontSubstitution{LHE}{cmr}{m}{n}
\DeclareErrorFont{LHE}{cmr}{m}{n}{10}
\ProvideTextCommand{\textcopyright}{LHE}{\textcircled{\@latin{c}}}
\ProvideTextCommand{\textregistered}{LHE}{\textcircled{\scshape%
                                          \@latin{r}}}
\ProvideTextCommand{\texttrademark}{LHE}{\textsuperscript{\@latin{TM}}}
\lccode``=``
\DeclareTextSymbol{\hebalef}{LHE}{96}
\DeclareTextSymbol{\hebbet}{LHE}{97}
\DeclareTextSymbol{\hebgimel}{LHE}{98}
\DeclareTextSymbol{\hebdalet}{LHE}{99}
\DeclareTextSymbol{\hebhe}{LHE}{100}
\DeclareTextSymbol{\hebvav}{LHE}{101}
\DeclareTextSymbol{\hebzayin}{LHE}{102}
\DeclareTextSymbol{\hebhet}{LHE}{103}
\DeclareTextSymbol{\hebtet}{LHE}{104}
\DeclareTextSymbol{\hebyod}{LHE}{105}
\DeclareTextSymbol{\hebfinalkaf}{LHE}{106}
\DeclareTextSymbol{\hebkaf}{LHE}{107}
\DeclareTextSymbol{\heblamed}{LHE}{108}
\DeclareTextSymbol{\hebfinalmem}{LHE}{109}
\DeclareTextSymbol{\hebmem}{LHE}{110}
\DeclareTextSymbol{\hebfinalnun}{LHE}{111}
\DeclareTextSymbol{\hebnun}{LHE}{112}
\DeclareTextSymbol{\hebsamekh}{LHE}{113}
\DeclareTextSymbol{\hebayin}{LHE}{114}
\DeclareTextSymbol{\hebfinalpe}{LHE}{115}
\DeclareTextSymbol{\hebpe}{LHE}{116}
\DeclareTextSymbol{\hebfinaltsadi}{LHE}{117}
\DeclareTextSymbol{\hebtsadi}{LHE}{118}
\DeclareTextSymbol{\hebqof}{LHE}{119}
\DeclareTextSymbol{\hebresh}{LHE}{120}
\DeclareTextSymbol{\hebshin}{LHE}{121}
\DeclareTextSymbol{\hebtav}{LHE}{122}
\let\hebsin=\hebshin
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\endinput
%%
%% End of file `lheenc.def'.
