%
% (c) Copyright  2000 Apostolos Syropoulos 
% This program can be redistributed and/or modified under the terms
% of the LaTeX Project Public License Distributed from CTAN
% archives in directory macros/latex/base/lppl.txt; either
% version 1 of the License, or any later version.
%
% Please report errors or suggestions for improvement to
%
%    Apostolos Syropoulos
%    366, 28th October Str.
%    GR-671 00 Xanthi, GREECE
%    apostolo@ocean1.ee.duth.gr or apostolo@obelix.ee.duth.gr
%
%
\ProvidesFile{iso-8859-7.def}
   [2004/09/04 v1.3 Greek input encoding file]
\message{iso-8859-7 input encoding file by Apostolos Syropoulos with modifications by C.Beccari)}
\DeclareInputText{128}{}
\DeclareInputText{129}{}
\DeclareInputText{130}{}
\DeclareInputText{131}{}
\DeclareInputText{132}{}
\DeclareInputText{133}{}
\DeclareInputText{134}{}
\DeclareInputText{135}{}
\DeclareInputText{136}{}
\DeclareInputText{137}{}
\DeclareInputText{138}{}
\DeclareInputText{139}{}
\DeclareInputText{140}{}
\DeclareInputText{141}{}
\DeclareInputText{142}{}
\DeclareInputText{143}{}
\DeclareInputText{144}{}
\DeclareInputText{145}{``}
\DeclareInputText{146}{''}
\DeclareInputText{147}{``}
\DeclareInputText{148}{''}
\DeclareInputText{149}{}
\DeclareInputText{150}{}
\DeclareInputText{151}{}
\DeclareInputText{152}{}
\DeclareInputText{153}{}
\DeclareInputText{154}{}
\DeclareInputText{155}{}
\DeclareInputText{156}{}
\DeclareInputText{157}{}
\DeclareInputText{158}{}
\DeclareInputText{159}{}
\DeclareInputText{160}{}
\DeclareInputText{161}{}
\DeclareInputText{162}{'A}
\DeclareInputText{163}{}
\DeclareInputText{164}{}
\DeclareInputText{165}{}
\DeclareInputText{166}{}
\DeclareInputText{167}{}
\DeclareInputText{168}{}
\DeclareInputText{169}{}
\DeclareInputText{170}{}
\DeclareInputText{171}{\char'173}
\DeclareInputText{172}{}
\DeclareInputText{173}{}
\DeclareInputText{174}{}
\DeclareInputText{175}{}
\DeclareInputText{176}{}
\DeclareInputText{177}{}
\DeclareInputText{178}{}
\DeclareInputText{179}{}
\DeclareInputText{180}{}
\DeclareInputText{181}{}
\DeclareInputText{182}{'A}
\DeclareInputText{183}{}
\DeclareInputText{184}{'E}
\DeclareInputText{185}{'H}
\DeclareInputText{186}{'I}
\DeclareInputText{187}{\char'175}
\DeclareInputText{188}{'O}
\DeclareInputText{189}{}
\DeclareInputText{190}{'U}
\DeclareInputText{191}{'W}
%\DeclareInputText{192}{"'i}
\chardef\idiaerac=242
\DeclareInputText{192}{\char\idiaerac}
\DeclareInputText{193}{A}
\DeclareInputText{194}{B}
\DeclareInputText{195}{G}
\DeclareInputText{196}{D}
\DeclareInputText{197}{E}
\DeclareInputText{198}{Z}
\DeclareInputText{199}{H}
\DeclareInputText{200}{J}
\DeclareInputText{201}{I}
\DeclareInputText{202}{K}
\DeclareInputText{203}{L}
\DeclareInputText{204}{M}
\DeclareInputText{205}{N}
\DeclareInputText{206}{X}
\DeclareInputText{207}{O}
\DeclareInputText{208}{P}
\DeclareInputText{209}{R}
\DeclareInputText{210}{}
\DeclareInputText{211}{S}
\DeclareInputText{212}{T}
\DeclareInputText{213}{U}
\DeclareInputText{214}{F}
\DeclareInputText{215}{Q}
\DeclareInputText{216}{Y}
\DeclareInputText{217}{W}
%\DeclareInputText{218}{"I}
%\DeclareInputText{219}{"U}
\chardef\Idiaer=219
\chardef\Udiaer=223
\DeclareInputText{218}{\char\Idiaer}
\DeclareInputText{219}{\char\Udiaer}
\DeclareInputText{220}{'a}
\DeclareInputText{221}{'e}
\DeclareInputText{222}{'h}
\DeclareInputText{223}{'i}
%\DeclareInputText{224}{"'u}
\chardef\udiaerac=246
\DeclareInputText{224}{\char\udiaerac}
\DeclareInputText{225}{a}
\DeclareInputText{226}{b}
\DeclareInputText{227}{g}
\DeclareInputText{228}{d}
\DeclareInputText{229}{e}
\DeclareInputText{230}{z}
\DeclareInputText{231}{h}
\DeclareInputText{232}{j}
\DeclareInputText{233}{i}
\DeclareInputText{234}{k}
\DeclareInputText{235}{l}
\DeclareInputText{236}{m}
\DeclareInputText{237}{n}
\DeclareInputText{238}{x}
\DeclareInputText{239}{o}
\DeclareInputText{240}{p}
\DeclareInputText{241}{r}
\DeclareInputText{242}{s}
\DeclareInputText{243}{s}
\DeclareInputText{244}{t}
\DeclareInputText{245}{u}
\DeclareInputText{246}{f}
\DeclareInputText{247}{q}
\DeclareInputText{248}{y}
\DeclareInputText{249}{w}
%\DeclareInputText{250}{"i}
%\DeclareInputText{251}{"u}
\chardef\idiaer=240
\chardef\udiaer=244
\DeclareInputText{250}{\char\idiaer}
\DeclareInputText{251}{\char\udiaer}
\DeclareInputText{252}{'o}
\DeclareInputText{253}{'u}
\DeclareInputText{254}{'w}
\DeclareInputText{255}{}
\endinput
