%%
%% This is file `hvtexhtm.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `vtexhtml')
%% 
%% File: hyperref.dtx Copyright 1995-2001 Sebastian Rahtz,
%% RCS: $Id: hyperref.dtx 6.71 2000/10/04 rahtz Exp rahtz $
%%
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%%
%% It may be distributed under the conditions of the LaTeX Project Public
%% License, either version 1.2 of this license or (at your option) any
%% later version.  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%%
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%%
\ProvidesFile{hvtexhtml.def}
  [2003/11/30 v6.74m
  Hyperref driver for VTeX in HTML mode]
\RequirePackage{vtexhtml}
\newif\if@Localurl
\def\PDF@FinishDoc{}
\def\PDF@SetupDoc{%
  \ifx\@baseurl\@empty
  \else
    \special{!direct <base href="\@baseurl">}%
  \fi
}
\def\@urltype{url}
\def\hyper@link#1#2#3{%
  \leavevmode
  \special{!direct <a href=\hyper@quote\hyper@hash#2\hyper@quote>}%
  #3%
  \special{!direct </a>}%
}
\def\hyper@linkurl#1#2{%
  \begingroup
    \hyper@chars
    \leavevmode
    \MathBSuppress=1\relax
    \special{!direct <a href=\hyper@quote#2\hyper@quote>}%
    #1%
    \MathBSuppress=0\relax
    \special{!direct </a>}%
  \endgroup
}
\def\hyper@linkfile#1#2#3{%
  \hyper@linkurl{#1}{\Hy@linkfileprefix#2\ifx\\#3\\\else\##3\fi}%
}
\def\hyper@linkstart#1#2{%
  \def\Hy@tempa{#1}\ifx\Hy@tempa\@urltype
    \@Localurltrue
    \special{!direct <a href=\hyper@quote#2\hyper@quote>}%
  \else
    \@Localurlfalse
    \begingroup
      \hyper@chars
      \special{!aref #2}%
    \endgroup
  \fi
}
\def\hyper@linkend{%
  \if@Localurl
    \special{!endaref}%
  \else
    \special{!direct </a>}%
  \fi
}
\def\hyper@anchorstart#1{%
  \Hy@SaveLastskip
  \begingroup
    \hyper@chars
    \special{!aname #1}%
    \special{!direct <a name=\hyper@quote#1\hyper@quote>}%
  \endgroup
  \Hy@activeanchortrue
}
\def\hyper@anchorend{%
  \special{!direct </a>}%
  \Hy@activeanchorfalse
  \Hy@RestoreLastskip
}
\def\hyper@anchor#1{%
  \Hy@SaveLastskip
  \begingroup
    \let\protect=\string
    \hyper@chars
    \leavevmode
    \special{!aname #1}%
    \special{!direct <a name=\hyper@quote #1\hyper@quote>}%
  \endgroup
  \Hy@activeanchortrue
  \bgroup\anchor@spot\egroup
  \special{!direct </a>}%
  \Hy@activeanchorfalse
  \Hy@RestoreLastskip
}
\def\@Form[#1]{\typeout{Sorry, TeXpider does not yet support FORMs}}
\def\@endForm{}
\def\@Gauge[#1]#2#3#4{% parameters, label, minimum, maximum
  \typeout{Sorry, TeXpider does not yet support FORM gauges}%
}
\def\@TextField[#1]#2{% parameters, label
  \typeout{Sorry, TeXpider does not yet support FORM text fields}%
  }
\def\@CheckBox[#1]#2{% parameters, label
  \typeout{Sorry, TeXpider does not yet support FORM checkboxes}%
  }
\def\@ChoiceMenu[#1]#2#3{% parameters, label, choices
  \typeout{Sorry, TeXpider does not yet support FORM choice menus}%
}
\def\@PushButton[#1]#2{% parameters, label
  \typeout{Sorry, TeXpider does not yet support FORM pushbuttons}%
}
\def\@Reset[#1]#2{\typeout{Sorry, TeXpider does not yet support FORMs}}
\def\@Submit[#1]#2{\typeout{Sorry, TeXpider does not yet support FORMs}}
\endinput
%%
%% End of file `hvtexhtm.def'.
