% Copyright 2000 Vladimir Volovich <vvv@vsu.ru>
\ProvidesFile{utflat.def}[2000/08/19 v0.1 latin definitions for utf-8]

\UnicodeCharacter{x00A0}{~}
\UnicodeCharacter{x00A1}{\textexclamdown}
\UnicodeCharacter{x00A2}{\textcent}
\UnicodeCharacter{x00A3}{\textsterling}
\UnicodeCharacter{x00A4}{\textcurrency}
\UnicodeCharacter{x00A5}{\textyen}
\UnicodeCharacter{x00A6}{\textbrokenbar}
\UnicodeCharacter{x00A7}{\textsection}
\UnicodeCharacter{x00A8}{\textasciidieresis}
\UnicodeCharacter{x00A9}{\textcopyright}
\UnicodeCharacter{x00AA}{\textordfeminine}
\UnicodeCharacter{x00AB}{\guillemotleft}
\UnicodeCharacter{x00AC}{\lnot}
\UnicodeCharacter{x00AD}{\-}
\UnicodeCharacter{x00AE}{\textregistered}
\UnicodeCharacter{x00AF}{\textasciimacron}
\UnicodeCharacter{x00B0}{\textdegree}
\UnicodeCharacter{x00B1}{\pm}
\UnicodeCharacter{x00B2}{{^2}}
\UnicodeCharacter{x00B3}{{^3}}
\UnicodeCharacter{x00B4}{\textasciiacute}
\UnicodeCharacter{x00B5}{\mathrm{\mu}}
\UnicodeCharacter{x00B6}{\textparagraph}
\UnicodeCharacter{x00B7}{\cdot}
\UnicodeCharacter{x00B8}{\c{}}
\UnicodeCharacter{x00B9}{{^1}}
\UnicodeCharacter{x00BA}{\textordmasculine}
\UnicodeCharacter{x00BB}{\guillemotright}
\UnicodeCharacter{x00BC}{\textonequarter}
\UnicodeCharacter{x00BD}{\textonehalf}
\UnicodeCharacter{x00BE}{\textthreequarters}
\UnicodeCharacter{x00BF}{\textquestiondown}
\UnicodeCharacter{x00C0}{\`{A}}
\UnicodeCharacter{x00C1}{\'{A}}
\UnicodeCharacter{x00C2}{\^{A}}
\UnicodeCharacter{x00C3}{\~{A}}
\UnicodeCharacter{x00C4}{\"{A}}
\UnicodeCharacter{x00C5}{\AA}
\UnicodeCharacter{x00C6}{\AE}
\UnicodeCharacter{x00C7}{\c{C}}
\UnicodeCharacter{x00C8}{\`{E}}
\UnicodeCharacter{x00C9}{\'{E}}
\UnicodeCharacter{x00CA}{\^{E}}
\UnicodeCharacter{x00CB}{\"{E}}
\UnicodeCharacter{x00CC}{\`{I}}
\UnicodeCharacter{x00CD}{\'{I}}
\UnicodeCharacter{x00CE}{\^{I}}
\UnicodeCharacter{x00CF}{\"{I}}
\UnicodeCharacter{x00D0}{\DH}
\UnicodeCharacter{x00D1}{\~{N}}
\UnicodeCharacter{x00D2}{\`{O}}
\UnicodeCharacter{x00D3}{\'{O}}
\UnicodeCharacter{x00D4}{\^{O}}
\UnicodeCharacter{x00D5}{\~{O}}
\UnicodeCharacter{x00D6}{\"{O}}
\UnicodeCharacter{x00D7}{\texttimes}
\UnicodeCharacter{x00D8}{\O}
\UnicodeCharacter{x00D9}{\`{U}}
\UnicodeCharacter{x00DA}{\'{U}}
\UnicodeCharacter{x00DB}{\^{U}}
\UnicodeCharacter{x00DC}{\"{U}}
\UnicodeCharacter{x00DD}{\'{Y}}
\UnicodeCharacter{x00DE}{\TH}
\UnicodeCharacter{x00DF}{\ss}
\UnicodeCharacter{x00E0}{\`{a}}
\UnicodeCharacter{x00E1}{\'{a}}
\UnicodeCharacter{x00E2}{\^{a}}
\UnicodeCharacter{x00E3}{\~{a}}
\UnicodeCharacter{x00E4}{\"{a}}
\UnicodeCharacter{x00E5}{\aa}
\UnicodeCharacter{x00E6}{\ae}
\UnicodeCharacter{x00E7}{\c{c}}
\UnicodeCharacter{x00E8}{\`{e}}
\UnicodeCharacter{x00E9}{\'{e}}
\UnicodeCharacter{x00EA}{\^{e}}
\UnicodeCharacter{x00EB}{\"{e}}
\UnicodeCharacter{x00EC}{\`{\i}}
\UnicodeCharacter{x00ED}{\'{\i}}
\UnicodeCharacter{x00EE}{\^{\i}}
\UnicodeCharacter{x00EF}{\"{\i}}
\UnicodeCharacter{x00F0}{\dh}
\UnicodeCharacter{x00F1}{\~{n}}
\UnicodeCharacter{x00F2}{\`{o}}
\UnicodeCharacter{x00F3}{\'{o}}
\UnicodeCharacter{x00F4}{\^{o}}
\UnicodeCharacter{x00F5}{\~{o}}
\UnicodeCharacter{x00F6}{\"{o}}
\UnicodeCharacter{x00F7}{\div}
\UnicodeCharacter{x00F8}{\o}
\UnicodeCharacter{x00F9}{\`{u}}
\UnicodeCharacter{x00FA}{\'{u}}
\UnicodeCharacter{x00FB}{\^{u}}
\UnicodeCharacter{x00FC}{\"{u}}
\UnicodeCharacter{x00FD}{\'{y}}
\UnicodeCharacter{x00FE}{\th}
\UnicodeCharacter{x00FF}{\"{y}}
\UnicodeCharacter{x0100}{\={A}}
\UnicodeCharacter{x0101}{\={a}}
\UnicodeCharacter{x0102}{\u{A}}
\UnicodeCharacter{x0103}{\u{a}}
\UnicodeCharacter{x0104}{\k{A}}
\UnicodeCharacter{x0105}{\k{a}}
\UnicodeCharacter{x0106}{\'{C}}
\UnicodeCharacter{x0107}{\'{c}}
\UnicodeCharacter{x0108}{\^{C}}
\UnicodeCharacter{x0109}{\^{c}}
\UnicodeCharacter{x010A}{\.{C}}
\UnicodeCharacter{x010B}{\.{c}}
\UnicodeCharacter{x010C}{\v{C}}
\UnicodeCharacter{x010D}{\v{c}}
\UnicodeCharacter{x010E}{\v{D}}
\UnicodeCharacter{x010F}{\v{d}}
\UnicodeCharacter{x0110}{\DJ}
\UnicodeCharacter{x0111}{\dj}
\UnicodeCharacter{x0112}{\={E}}
\UnicodeCharacter{x0113}{\={e}}
\UnicodeCharacter{x0114}{\u{E}}
\UnicodeCharacter{x0115}{\u{e}}
\UnicodeCharacter{x0116}{\.{E}}
\UnicodeCharacter{x0117}{\.{e}}
\UnicodeCharacter{x0118}{\k{E}}
\UnicodeCharacter{x0119}{\k{e}}
\UnicodeCharacter{x011A}{\v{E}}
\UnicodeCharacter{x011B}{\v{e}}
\UnicodeCharacter{x011C}{\^{G}}
\UnicodeCharacter{x011D}{\^{g}}
\UnicodeCharacter{x011E}{\u{G}}
\UnicodeCharacter{x011F}{\u{g}}
\UnicodeCharacter{x0120}{\.{G}}
\UnicodeCharacter{x0121}{\.{g}}
\UnicodeCharacter{x0122}{\c{G}}
\UnicodeCharacter{x0123}{\c{g}}
\UnicodeCharacter{x0124}{\^{H}}
\UnicodeCharacter{x0125}{\^{h}}
%\UnicodeCharacter{x0126}{}
%\UnicodeCharacter{x0127}{}
\UnicodeCharacter{x0128}{\~{I}}
\UnicodeCharacter{x0129}{\~{\i}}
\UnicodeCharacter{x012A}{\={I}}
\UnicodeCharacter{x012B}{\={\i}}
\UnicodeCharacter{x012C}{\u{I}}
\UnicodeCharacter{x012D}{\u{\i}}
\UnicodeCharacter{x012E}{\k{I}}
\UnicodeCharacter{x012F}{\k{i}}
\UnicodeCharacter{x0130}{\.{I}}
\UnicodeCharacter{x0131}{\i}
\UnicodeCharacter{x0132}{IJ}
\UnicodeCharacter{x0133}{ij}
\UnicodeCharacter{x0134}{\^{J}}
\UnicodeCharacter{x0135}{\^{\j}}
\UnicodeCharacter{x0136}{\c{K}}
\UnicodeCharacter{x0137}{\c{k}}
%\UnicodeCharacter{x0138}{}
\UnicodeCharacter{x0139}{\'{L}}
\UnicodeCharacter{x013A}{\'{l}}
\UnicodeCharacter{x013B}{\c{L}}
\UnicodeCharacter{x013C}{\c{l}}
\UnicodeCharacter{x013D}{\v{L}}
\UnicodeCharacter{x013E}{\v{l}}
%\UnicodeCharacter{x013F}{}
%\UnicodeCharacter{x0140}{}
\UnicodeCharacter{x0141}{\L}
\UnicodeCharacter{x0142}{\l}
\UnicodeCharacter{x0143}{\'{N}}
\UnicodeCharacter{x0144}{\'{n}}
\UnicodeCharacter{x0145}{\c{N}}
\UnicodeCharacter{x0146}{\c{n}}
\UnicodeCharacter{x0147}{\v{N}}
\UnicodeCharacter{x0148}{\v{n}}
\UnicodeCharacter{x0149}{'n}
\UnicodeCharacter{x014A}{\NG}
\UnicodeCharacter{x014B}{\ng}
\UnicodeCharacter{x014C}{\={O}}
\UnicodeCharacter{x014D}{\={o}}
\UnicodeCharacter{x014E}{\u{O}}
\UnicodeCharacter{x014F}{\u{o}}
\UnicodeCharacter{x0150}{\H{O}}
\UnicodeCharacter{x0151}{\H{o}}
\UnicodeCharacter{x0152}{\OE}
\UnicodeCharacter{x0153}{\oe}
\UnicodeCharacter{x0154}{\'{R}}
\UnicodeCharacter{x0155}{\'{r}}
\UnicodeCharacter{x0156}{\c{R}}
\UnicodeCharacter{x0157}{\c{r}}
\UnicodeCharacter{x0158}{\v{R}}
\UnicodeCharacter{x0159}{\v{r}}
\UnicodeCharacter{x015A}{\'{S}}
\UnicodeCharacter{x015B}{\'{s}}
\UnicodeCharacter{x015C}{\^{S}}
\UnicodeCharacter{x015D}{\^{s}}
\UnicodeCharacter{x015E}{\c{S}}
\UnicodeCharacter{x015F}{\c{s}}
\UnicodeCharacter{x0160}{\v{S}}
\UnicodeCharacter{x0161}{\v{s}}
\UnicodeCharacter{x0162}{\c{T}}
\UnicodeCharacter{x0163}{\c{t}}
\UnicodeCharacter{x0164}{\v{T}}
\UnicodeCharacter{x0165}{\v{t}}
%\UnicodeCharacter{x0166}{}
%\UnicodeCharacter{x0167}{}
\UnicodeCharacter{x0168}{\~{U}}
\UnicodeCharacter{x0169}{\~{u}}
\UnicodeCharacter{x016A}{\={U}}
\UnicodeCharacter{x016B}{\={u}}
\UnicodeCharacter{x016C}{\u{U}}
\UnicodeCharacter{x016D}{\u{u}}
\UnicodeCharacter{x016E}{\r{U}}
\UnicodeCharacter{x016F}{\r{u}}
\UnicodeCharacter{x0170}{\H{U}}
\UnicodeCharacter{x0171}{\H{u}}
\UnicodeCharacter{x0172}{\k{U}}
\UnicodeCharacter{x0173}{\k{u}}
\UnicodeCharacter{x0174}{\^{W}}
\UnicodeCharacter{x0175}{\^{w}}
\UnicodeCharacter{x0176}{\^{Y}}
\UnicodeCharacter{x0177}{\^{y}}
\UnicodeCharacter{x0178}{\"{Y}}
\UnicodeCharacter{x0179}{\'{Z}}
\UnicodeCharacter{x017A}{\'{z}}
\UnicodeCharacter{x017B}{\.{Z}}
\UnicodeCharacter{x017C}{\.{z}}
\UnicodeCharacter{x017D}{\v{Z}}
\UnicodeCharacter{x017E}{\v{z}}

\endinput
