% This file ``latin3eo.def' is derived from `latin3.def' and
% `latin3jk.def' from CTAN for the `inputenc' package.  It is modified
% by Sergei B. Pokrovsky <pok@iis.nsk.su> in order to enable
% hyphenation for Esperanto texts.
%
% It may be distributed under the terms of the LaTeX Project Public
% License, as described in lppl.txt in the base LaTeX distribution.
% Either version 1.0 or, at your option, any later version.

\ProvidesFile{latin3eo.def}
   [1999-08-14 v0.1 Input encoding file
                        (test version: still liable to change)]
\makeatletter
\ProvideTextCommandDefault{\textmalteseH}
   {\TextSymbolUnavailable\textmalteseH}
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{161}{\textmalteseH}
\DeclareInputText{162}{\u{}}
\DeclareInputText{163}{\textsterling}
\DeclareInputText{164}{\textcurrency}
\DeclareInputText{167}{\S}
\DeclareInputText{168}{\"{}}
\DeclareInputText{169}{\.I}
\DeclareInputText{170}{\c S}
\DeclareInputText{171}{\u G}
\DeclareInputText{173}{\-}
\DeclareInputText{175}{\.Z}
\DeclareInputText{176}{\textdegree}
\DeclareInputMath{177}{\hbar}
\DeclareInputText{178}{\texttwosuperior}
\DeclareInputText{179}{\textthreesuperior}
\DeclareInputText{180}{\@tabacckludge'{}}
\DeclareInputText{181}{\textmu}
\DeclareInputText{183}{\textperiodcentered}
\DeclareInputText{184}{\c\ }
\DeclareInputText{185}{\i}
\DeclareInputText{186}{\c s}
\DeclareInputText{187}{\u g}
\DeclareInputText{189}{\textonehalf}
\DeclareInputText{191}{\.z}
\DeclareInputText{192}{\@tabacckludge`A}
\DeclareInputText{193}{\@tabacckludge'A}
\DeclareInputText{194}{\^A}
\DeclareInputText{196}{\"A}
\DeclareInputText{197}{\.C}
\DeclareInputText{199}{\c C}
\DeclareInputText{200}{\@tabacckludge`E}
\DeclareInputText{201}{\@tabacckludge'E}
\DeclareInputText{202}{\^E}
\DeclareInputText{203}{\"E}
\DeclareInputText{204}{\@tabacckludge`I}
\DeclareInputText{205}{\@tabacckludge'I}
\DeclareInputText{206}{\^I}
\DeclareInputText{207}{\"I}
\DeclareInputText{209}{\~N}
\DeclareInputText{210}{\@tabacckludge`O}
\DeclareInputText{211}{\@tabacckludge'O}
\DeclareInputText{212}{\^O}
\DeclareInputText{213}{\.G}
\DeclareInputText{214}{\"O}
\DeclareInputText{215}{\texttimes}
\DeclareInputText{217}{\@tabacckludge`U}
\DeclareInputText{218}{\@tabacckludge'U}
\DeclareInputText{219}{\^U}
\DeclareInputText{220}{\"U}
\DeclareInputText{223}{\ss}
\DeclareInputText{224}{\@tabacckludge`a}
\DeclareInputText{225}{\@tabacckludge'a}
\DeclareInputText{226}{\^a}
\DeclareInputText{228}{\"a}
\DeclareInputText{229}{\.c}
\DeclareInputText{231}{\c c}
\DeclareInputText{232}{\@tabacckludge`e}
\DeclareInputText{233}{\@tabacckludge'e}
\DeclareInputText{234}{\^e}
\DeclareInputText{235}{\"e}
\DeclareInputText{236}{\@tabacckludge`\i}
\DeclareInputText{237}{\@tabacckludge'\i}
\DeclareInputText{238}{\^\i}
\DeclareInputText{239}{\"\i}
\DeclareInputText{241}{\~n}
\DeclareInputText{242}{\@tabacckludge`o}
\DeclareInputText{243}{\@tabacckludge'o}
\DeclareInputText{244}{\^o}
\DeclareInputText{245}{\.g}
\DeclareInputText{246}{\"o}
\DeclareInputText{247}{\textdiv}
\DeclareInputText{249}{\@tabacckludge`u}
\DeclareInputText{250}{\@tabacckludge'u}
\DeclareInputText{251}{\^u}
\DeclareInputText{252}{\"u}
\DeclareInputText{255}{\.{}}

%--- Esperanto letters, pok 1999-08-14:
\expandafter\ifx\csname charsubdef\endcsname\relax % no MLTeX?
  \DeclareInputText{198}{\^C}
  \DeclareInputText{230}{\^c}
  \DeclareInputText{216}{\^G}
  \DeclareInputText{248}{\^g}
  \DeclareInputText{166}{\^H}
  \DeclareInputText{182}{h\llap{\^{}}}
  \DeclareInputText{172}{\^J}
  \DeclareInputText{188}{\^\j}
  \DeclareInputText{222}{\^S}
  \DeclareInputText{254}{\^s}
  \DeclareInputText{221}{\u U}
  \DeclareInputText{253}{\u u}
\else
  \charsubdef 230 = 94 099 % cx
  \charsubdef 198 = 94 067 % Cx
  \charsubdef 248 = 94 103 % gx
  \charsubdef 216 = 94 071 % Gx
  \charsubdef 182 = 94 104 % hx
  \charsubdef 166 = 94 072 % Hx
  \charsubdef 188 = 94 017 % jx
  \charsubdef 172 = 94 074 % Jx
  \charsubdef 254 = 94 115 % sx
  \charsubdef 222 = 94 083 % Sx
  \charsubdef 253 = 21 117 % ux
  \charsubdef 221 = 21 085 % Ux
   
  %--- setup catcode/uccode/lccode values
  % has to be done here in order for the running page header/footer be
  % upcased correctly; note also {\^\j} <-> {\^J}
   
  \def\liter@#1 #2 {
      \catcode#1=11 \catcode#2=11 % do not break inputenc
      \uccode#1=#1  \uccode#2=#1
      \lccode#1=#2  \lccode#2=#2
  }
  \liter@ 198 230 % cx
  \liter@ 216 248 % gx
  \liter@ 166 182 % hx
  \liter@ 172 188 % jx 
  \liter@ 222 254 % sx
  \liter@ 221 253 % ux
  \let\liter@\undefined
\fi
\makeatother
\endinput

Usage:
 \documentclass{...}
 \usepackage{textcomp} % required for the characters listed below
 \usepackage[latin3eo]{inputenc}
 ...
 \begin{document}

We follow J"org Knappen in making textual the characters
\textcurrency, \textdegree, \textdiv, \textmu, \textmultiply,
\textonehalf, \textthreesuperior, \texttwosuperior
so that they can be used in verbatim environments. They are defined in
the textcomp package using the text companion font (TS1 coding).

%% End of file `latin3eo.def'.
