%% e-TeX V2.0;2

% Note: the first line of this file must match the corresponding line
% in "etex.src" and "etexdefs.lib", otherwise fallback will be used.

% This is "language.def", e-TeX's language definition file.

% It is explicitly permitted to augment this file by adding additional
% \addlanguage ... commands AFTER the first (\addlanguage {USenglish})
% which must remain as the first language added to ensure total document
% portability for pre-\language documents.  The last line of the file
% MUST be left as \uselanguage {USenglish} for the sane reason.

\addlanguage {USenglish}{hyphen}{}{2}{3} %%% This MUST be the first non-comment
                                         %%% line of the file

% Additional languages, patterns, exceptions and left- and right-hyphen
% minima may be added here, and an example is given for German.

% The five parameters for \addlanguage are:
% language, patterns file, exceptions file, left- and right-hyphen minima

%%% Next section is      E X A M P L E   O N L Y
%%% \addlanguage {German}{ghyph31}{}{2}{2}   %%% further such lines may be used;
%%% Previous section is  E X A M P L E   O N L Y

%%% No changes may be made beyond this point.

\uselanguage {USenglish}             %%% This MUST be the last line of the file.
